@@ -127,14 +127,6 @@ do
     }                                                                                                           \
 } while (0)
 
-typedef struct CODECHAL_SSEU_SETTING
-{
-    uint8_t   ui8NumSlices;
-    uint8_t   ui8NumSubSlices;
-    uint8_t   ui8NumEUs;
-    uint8_t   reserved;       // Place holder for frequency setting
-} CODECHAL_SSEU_SETTING, *PCODECHAL_SSEU_SETTING;
-
 // VP8 Coefficient Probability data
 typedef struct _CODECHAL_VP8_COEFFPROB_DATA
 {
@@ -162,131 +154,6 @@ typedef struct _CODEC_ENCODE_MBDATA_LAYOUT
     uint32_t    uiMvBottomFieldOffset;      //!< Offset to the MV data for the bottom field
 } CODEC_ENCODE_MBDATA_LAYOUT, *PCODEC_ENCODE_MBDATA_LAYOUT;
 
-/*! \brief Settings used to create the CodecHal device.
-*/
-typedef struct _CODECHAL_STANDARD_INFO
-{
-    CODECHAL_FUNCTION       CodecFunction;  //!< High level codec functionality requested.
-    uint32_t                Mode;           //!< Mode requested (high level combination between Standard and CodecFunction).
-    /*! \brief Applies to decode only, hybrid decoding requested.
-    *
-    *   Hybrid decoding uses EU kernels when FF HW is not available.
-    */
-    bool                    bIsHybridCodec;
-}CODECHAL_STANDARD_INFO, *PCODECHAL_STANDARD_INFO;
-
-//!
-//! \class CodechalResLock
-//! \brief Help function to lock the resource, the resource will be unlock automatically when this class destroy.
-//!
-class CodechalResLock
-{
-public:
-
-    //! \brief lock flag
-    enum LockFlag
-    {
-        readOnly        = 1,        //!< lock with read only
-        writeOnly       = 1 << 1,   //!< lock with write only
-        tiledAsTiled    = 1 << 2,   //!< lock tile surface as tile format
-        noOverWrite     = 1 << 3,   //!< lock with no overwrite
-        noDecompress    = 1 << 4,   //!< lock with no decompress
-        uncached        = 1 << 5,   //!< lock with uncached
-        forceCached     = 1 << 6    //!< lock with cache by force
-    };
-
-    //!
-    //! \brief    Constructor
-    //!
-    CodechalResLock (PMOS_INTERFACE osInterface, PMOS_RESOURCE resource):
-        m_os(osInterface),
-        m_res(resource),
-        m_lockedPtr(nullptr)
-    {
-    }
-
-    //!
-    //! \brief    Destructor
-    //!
-    ~CodechalResLock ()
-    {
-        if (m_os != nullptr && m_res != nullptr && m_lockedPtr != nullptr)
-        {
-            m_os->pfnUnlockResource(m_os, m_res);
-        }
-    }
-
-    //!
-    //! \brief    Lock the resource
-    //! \details  Lock the resource, will be unlock automatically when this class destroy
-    //! \param  [in] lockFlags
-    //!         Combined lock flags, reference to enum LockFlag.
-    //!
-    //! \return   void pointer
-    //!           locked pointer if success, else return null pointer
-    //!
-    void *Lock(uint32_t lockFlags)
-    {
-        if (m_os == nullptr || m_res == nullptr)
-        {
-            return nullptr;
-        }
-
-        if (m_lockedPtr == nullptr)
-        {
-            MOS_LOCK_PARAMS mosLockFlags;
-            MOS_ZeroMemory(&mosLockFlags, sizeof(MOS_LOCK_PARAMS));
-
-            if ((lockFlags & readOnly) == readOnly)
-            {
-                mosLockFlags.ReadOnly = 1;
-            }
-
-            if ((lockFlags & writeOnly) == writeOnly)
-            {
-                mosLockFlags.WriteOnly = 1;
-            }
-
-            if ((lockFlags & tiledAsTiled) == tiledAsTiled)
-            {
-                mosLockFlags.TiledAsTiled = 1;
-            }
-
-            if ((lockFlags & noOverWrite) == noOverWrite)
-            {
-                mosLockFlags.NoOverWrite = 1;
-            }
-
-            if ((lockFlags & noDecompress) == noDecompress)
-            {
-                mosLockFlags.NoDecompress = 1;
-            }
-
-            if ((lockFlags & uncached) == uncached)
-            {
-                mosLockFlags.Uncached = 1;
-            }
-
-            if ((lockFlags & forceCached) == forceCached)
-            {
-                mosLockFlags.ForceCached = 1;
-            }
-
-            m_lockedPtr = m_os->pfnLockResource(
-                m_os,
-                m_res,
-                &mosLockFlags);
-        }
-
-        return m_lockedPtr;
-    }
-
-private:
-    PMOS_INTERFACE  m_os;
-    PMOS_RESOURCE   m_res;
-    void            *m_lockedPtr;
-};
-
 #ifdef __cplusplus
 }
 #endif  // __cplusplus
