@@ -35,6 +35,7 @@
 #include <fstream>
 #include "codechal_debug.h"
 #endif
+#include "mos_os_cp_interface_specific.h"
 
 #define CODECHAL_DECODE_MPEG2_IDCTBLOCK_SIZE   64
 
@@ -1718,6 +1719,7 @@ CodechalDecodeMpeg2::CodechalDecodeMpeg2 (
 #if (_DEBUG || _RELEASE_INTERNAL)
     m_reportFrameCrc = true;
 #endif
+    m_hwInterface = hwInterface;
 }
 
 #if USE_CODECHAL_DEBUG_TOOL
