@@ -35,6 +35,7 @@
 #include <fstream>
 #include "codechal_debug.h"
 #endif
+#include "mos_os_cp_interface_specific.h"
 
 CodechalDecodeVp9 :: ~CodechalDecodeVp9 ()
 {
@@ -231,6 +232,7 @@ CodechalDecodeVp9 ::CodechalDecodeVp9(
     }
 
     m_hcpInUse = true;
+    m_hwInterface = hwInterface;
 }
 
 MOS_STATUS CodechalDecodeVp9 :: ProbBufferPartialUpdatewithDrv()
