@@ -25,6 +25,7 @@
 
 #include "codechal_memdecomp.h"
 #include "codeckrnheader.h"
+#include "mos_os_cp_interface_specific.h"
 
 //!
 //! \class MediaObjectCopyCurbe
@@ -435,7 +436,7 @@ MOS_STATUS MediaMemDecompState::MemoryDecompress(
     }
 
     uint32_t widthInBytes = GetSurfaceWidthInBytes(surfaceParams.psSurface);
-    surfaceParams.dwWidthToUse[MHW_Y_PLANE] = WIDTH_IN_DW(widthInBytes);
+    surfaceParams.dwWidthToUse[MHW_Y_PLANE] = MHW_WIDTH_IN_DW(widthInBytes);
 
     // UV Plane
     if (useUVPlane)
@@ -452,7 +453,7 @@ MOS_STATUS MediaMemDecompState::MemoryDecompress(
         surfaceParams.dwBaseAddrOffset[MHW_U_PLANE] =
             targetSurface.dwPitch *
             MOS_ALIGN_FLOOR(targetSurface.UPlaneOffset.iYOffset, MOS_YTILE_H_ALIGNMENT);
-        surfaceParams.dwWidthToUse[MHW_U_PLANE]  = WIDTH_IN_DW(widthInBytes);
+        surfaceParams.dwWidthToUse[MHW_U_PLANE]  = MHW_WIDTH_IN_DW(widthInBytes);
         surfaceParams.dwHeightToUse[MHW_U_PLANE] = surfaceParams.psSurface->dwHeight / 2;
         surfaceParams.dwYOffset[MHW_U_PLANE] =
             (targetSurface.UPlaneOffset.iYOffset % MOS_YTILE_H_ALIGNMENT);
@@ -891,6 +892,8 @@ MOS_STATUS MediaMemDecompState::Initialize(
     MhwRenderInterface              *renderInterface)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    MediaUserSettingSharedPtr   userSettingPtr = nullptr;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureData = {};
 
     MHW_FUNCTION_ENTER;
 
@@ -903,6 +906,7 @@ MOS_STATUS MediaMemDecompState::Initialize(
     m_cpInterface = cpInterface;
     m_miInterface = miInterface;
     m_renderInterface = renderInterface;
+    userSettingPtr = osInterface->pfnGetUserSettingInstance(osInterface);
 
     for (uint8_t kernelIdx = decompKernelStatePa; kernelIdx < decompKernelStateMax; kernelIdx++)
     {
@@ -940,14 +944,11 @@ MOS_STATUS MediaMemDecompState::Initialize(
     nullHWAccelerationEnable.Value = 0;
     m_disableDecodeSyncLock        = false;
 #if (_DEBUG || _RELEASE_INTERNAL)
-    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_NULL_HW_ACCELERATION_ENABLE_ID,
-        &userFeatureData,
-        m_osInterface->pOsContext);
-    nullHWAccelerationEnable.Value = userFeatureData.u32Data;
+    ReadUserSettingForDebug(
+        userSettingPtr,
+        nullHWAccelerationEnable.Value,
+        __MEDIA_USER_FEATURE_VALUE_NULL_HW_ACCELERATION_ENABLE,
+        MediaUserSetting::Group::Device);
 
     MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
     MOS_UserFeature_ReadValue_ID(
