@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2020, Intel Corporation
+* Copyright (c) 2011-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -81,8 +81,6 @@
 #define CODECHAL_VDENC_AVC_POS_MULT_VBR                     100
 #define CODECHAL_VDENC_AVC_NEG_MULT_VBR                     -50
 
-#define CODECHAL_ENCODE_VDENC_BRC_CONST_BUFFER_NUM          (NUM_PIC_TYPES + 1) //!< For each frame type + 1 for ref B
-
 #define __CODEGEN_BITFIELD(l, h) (h) - (l) + 1
 //!
 //! \brief CODECHAL_VDENC_STREAMIN_STATE
@@ -615,7 +613,7 @@ public:
     //! \return   bool
     //!           true if native ROI, otherwise false
     //!
-    bool ProcessRoiDeltaQp();
+    virtual bool ProcessRoiDeltaQp();
 
     //!
     //! \brief    Add store HUC_ERROR_STATUS register command in the command buffer
@@ -775,6 +773,47 @@ public:
     //!
     virtual MOS_STATUS ExecuteMeKernel();
 
+    virtual bool IsMBBRCControlEnabled();
+
+    MOS_STATUS SetCommonSliceState(
+        CODECHAL_ENCODE_AVC_PACK_SLC_HEADER_PARAMS &packSlcHeaderParams,
+        MHW_VDBOX_AVC_SLICE_STATE &                 sliceState);
+
+    MOS_STATUS SetSliceState(
+        CODECHAL_ENCODE_AVC_PACK_SLC_HEADER_PARAMS &packSlcHeaderParams,
+        MHW_VDBOX_AVC_SLICE_STATE &                 sliceState,
+        uint16_t                                    slcIdx);
+
+    //!
+    //! \brief    Get AVC VDenc frame level status extention
+    //!
+    //! \param    [in] cmdBuffer
+    //!           Point to MOS_COMMAND_BUFFER
+    //!           [in] StatusReportFeedbackNumber
+    //!           Status report number
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS GetAvcVdencFrameLevelStatusExt(uint32_t StatusReportFeedbackNumber, MOS_COMMAND_BUFFER *cmdBuffer)
+    {
+        return MOS_STATUS_SUCCESS;
+    };
+
+    //!
+    //! \brief    Get AVC VDenc MB level status extention
+    //!
+    //! \param    [in] encodeStatusReport
+    //!           Point to EncodeStatusReport
+    //!           [in] StatusReportFeedbackNumber
+    //!           Status report number
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS GetAvcVdencMBLevelStatusExt(uint32_t StatusReportFeedbackNumber, uint8_t SliceType)
+    {
+        return MOS_STATUS_SUCCESS;
+    };
+
 protected:
     // AvcGeneraicState functions
     //!
@@ -918,6 +957,8 @@ protected:
 
     virtual uint32_t GetBRCCostantDataSize() { return sizeof(AVCVdencBRCCostantData); }
 
+    virtual uint32_t GetVdencBRCImgStateBufferSize() { return MOS_ALIGN_CEIL(m_hwInterface->m_vdencBrcImgStateBufferSize, CODECHAL_PAGE_SIZE); }
+
     virtual MOS_STATUS FillHucConstData(uint8_t *data, uint8_t picType);
 
     //!
@@ -937,6 +978,27 @@ protected:
         PMOS_RESOURCE       presSliceSizeStreamoutBuffer,
         PMOS_COMMAND_BUFFER cmdBuffer) override;
 
+    virtual MOS_STATUS AddVdencBrcImgBuffer(
+        PMOS_RESOURCE             vdencBrcImgBuffer,
+        PMHW_VDBOX_AVC_IMG_PARAMS params);
+
+    //!
+    //! \brief    Report Slice Size to MetaData buffer
+    //! \details  Report Slice Size to MetaData buffer.
+    //! \param    [in] presMetadataBuffer
+    //!               Pointer to allocated HW MetaData buffer
+    //!           [in] cmdBuffer
+    //!               Pointer to primary cmd buffer
+    //!           [in] slcCount
+    //!               Current slice count
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS ReportSliceSizeMetaData(
+        PMOS_RESOURCE presMetadataBuffer,
+        PMOS_COMMAND_BUFFER cmdBuffer,
+        uint32_t slcCount);
+
     //!
     //! \brief    Add MI_STORE commands in the command buffer to update DMEM from other HW output buffer if needed
     //!
@@ -1150,6 +1212,8 @@ protected:
     virtual MOS_STATUS DumpEncodeImgStats(
         PMOS_COMMAND_BUFFER        cmdbuffer);
 
+    virtual uint32_t GetPakVDEncPassDumpSize();
+
     virtual MOS_STATUS DumpSeqParFile() override;
     virtual MOS_STATUS DumpFrameParFile() override;
 
@@ -1311,7 +1375,7 @@ MOS_STATUS CodechalVdencAvcState::SetDmemHuCBrcInitResetImpl(CODECHAL_VDENC_AVC_
     hucVDEncBrcInitDmem->INIT_InitQPIP = (uint8_t)initQP;
 
     // MBBRC control
-    if (m_mbBrcEnabled || m_avcPicParam->bNativeROI)
+    if (IsMBBRCControlEnabled())
     {
         hucVDEncBrcInitDmem->INIT_MbQpCtrl_U8 = 1;
         MOS_SecureMemcpy(hucVDEncBrcInitDmem->INIT_DistQPDelta_I8, 4 * sizeof(int8_t), (void*)BRC_INIT_DistQPDelta_I8, 4 * sizeof(int8_t));
