@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2021, Intel Corporation
+* Copyright (c) 2017-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -41,12 +41,6 @@
 
 #define MFX_PAK_STREAMOUT_DATA_BYTE_SIZE   4
 
-typedef enum _MHW_VDBOX_AVC_DMV_OFFSET
-{
-    MHW_VDBOX_AVC_DMV_DEST_TOP = 32,
-    MHW_VDBOX_AVC_DMV_DEST_BOTTOM = 33
-} MHW_VDBOX_AVC_DMV_OFFSET;
-
 typedef enum _MHW_VDBOX_DECODE_VC1_IT_ILDB_EDGE_CONTROL_LUMA
 {
     MHW_VDBOX_DECODE_VC1_IT_ILDB_EDGE_CONTROL_LUMA_X0Y0 = 0x0f0c0300,
@@ -65,16 +59,6 @@ typedef enum _MHW_VDBOX_DECODE_VC1_IT_ILDB_EDGE_CONTROL_CHROMA
 
 } MHW_VDBOX_DECODE_VC1_IT_ILDB_EDGE_CONTROL_CHROMA;
 
-typedef enum _MHW_VDBOX_DECODE_JPEG_FORMAT_CODE
-{
-    MHW_VDBOX_DECODE_JPEG_FORMAT_SEPARATE_PLANE = 0, // formats of 3 separate plane for Y, U, and V respectively
-    MHW_VDBOX_DECODE_JPEG_FORMAT_NV12 = 1,
-    MHW_VDBOX_DECODE_JPEG_FORMAT_UYVY = 2,
-    MHW_VDBOX_DECODE_JPEG_FORMAT_YUY2 = 3
-} MHW_VDBOX_DECODE_JPEG_FORMAT_CODE;
-
-
-
 typedef struct _MHW_VDBOX_MPEG2_SLICE_STATE
 {
     PMOS_RESOURCE                   presDataBuffer;
@@ -375,14 +359,6 @@ typedef struct _MHW_VDBOX_BSP_BUF_BASE_ADDR_PARAMS
     PMOS_RESOURCE               presBitplaneBuffer;
 } MHW_VDBOX_BSP_BUF_BASE_ADDR_PARAMS, *PMHW_VDBOX_BSP_BUF_BASE_ADDR_PARAMS;
 
-typedef struct _MHW_VDBOX_GPUNODE_LIMIT
-{
-    bool       bHcpInUse;
-    bool       bHuCInUse;
-    bool       bSfcInUse;
-    uint32_t   dwGpuNodeToUse;
-}MHW_VDBOX_GPUNODE_LIMIT, *PMHW_VDBOX_GPUNODE_LIMIT;
-
 typedef struct _MHW_VDBOX_AVC_IMG_BITRATE_PARAMS
 {
     uint32_t   frameBitRateMin : 14;
@@ -629,6 +605,10 @@ protected:
 
     MmioRegistersMfx            m_mmioRegisters[MHW_VDBOX_NODE_MAX] = {};  //!< mfx mmio registers
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    bool bMMCReported = false;
+#endif
+
     //!
     //! \brief    Constructor
     //!
@@ -1064,6 +1044,14 @@ public:
     //!
     virtual uint32_t GetAvcImgStateSize() = 0;
 
+    //!
+    //! \brief    get AVC slc state size
+    //!
+    //! \return   uint32_t
+    //!           AVC slc state size got
+    //!
+    virtual uint32_t GetAvcSlcStateSize() = 0;
+
     //!
     //! \brief    Decide Which GPU Node to use for Decode
     //! \details  Client facing function to create gpu context used by decoder
