@@ -25,7 +25,7 @@
 //! \details  Implements the MOS interface extension cross OS - virtual engine. Only necessary when KMD virtual engine is supported
 //!
 
-#include "mos_util_debug.h"
+#include "mos_os.h"
 #include "mos_os_virtualengine_singlepipe_specific.h"
 #include "mos_os_virtualengine_scalability_specific.h"
 #include "mos_os_virtualengine_singlepipe_specific_next.h"
