@@ -30,7 +30,7 @@
 #include "vphal.h"
 #include "vphal_render_renderstate.h"
 #include "vphal_render_common.h"
-#include "mhw_render.h"
+#include "mhw_render_legacy.h"
 
 //!
 //! \brief Compositing buffers
@@ -791,7 +791,8 @@ protected:
     //!
     bool AddCompLayer(
         PVPHAL_COMPOSITE_PARAMS     pComposite,
-        PVPHAL_SURFACE              pSource);
+        PVPHAL_SURFACE              pSource,
+        bool                        bDisableAvsSampler);
 
     //!
     //! \brief    Adds render target layer for composite
@@ -847,6 +848,10 @@ protected:
     virtual bool SubmitStates(
         PVPHAL_RENDERING_DATA_COMPOSITE     pRenderingData);
 
+    virtual bool IsDisableAVSSampler(
+        int32_t         iSources,
+        bool            isTargetY);
+
 private:
     //!
     //! \brief    Prepare phases for composite and determine intermediate colorspace
