@@ -47,8 +47,6 @@ MOS_STATUS MhwRenderInterfaceG10::AddMediaVfeCmd(
 
     cmd->DW4.SliceDisable = params->eVfeSliceDisable;
 
-    MEDIA_SYSTEM_INFO *gtSystemInfo = m_osInterface->pfnGetGtSystemInfo(m_osInterface);
-    MHW_MI_CHK_NULL(gtSystemInfo);
     auto waTable = m_osInterface->pfnGetWaTable(m_osInterface);
     MHW_MI_CHK_NULL(waTable);
 
@@ -103,6 +101,7 @@ MOS_STATUS MhwRenderInterfaceG10::AddMediaObjectWalkerCmd(
 {
     MHW_FUNCTION_ENTER;
 
+    MHW_MI_CHK_NULL(m_osInterface);
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(params);
 
@@ -134,7 +133,7 @@ MOS_STATUS MhwRenderInterfaceG10::AddMediaObjectWalkerCmd(
     {
         // add dummy walker command to clear the state setting
         mhw_render_g10_X::MEDIA_OBJECT_WALKER_CMD cmd;
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
         loadRegisterParams.dwData = m_preemptionCntlRegisterValue;
         MHW_MI_CHK_STATUS(m_miInterface->AddMiLoadRegisterImmCmd(cmdBuffer, &loadRegisterParams));
     }
@@ -184,6 +183,7 @@ MOS_STATUS MhwRenderInterfaceG10::AddPaletteLoadCmd(
 {
     MHW_FUNCTION_ENTER;
 
+    MHW_MI_CHK_NULL(m_osInterface);
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(params);
     MHW_MI_CHK_NULL(params->pPaletteData);
@@ -200,14 +200,14 @@ MOS_STATUS MhwRenderInterfaceG10::AddPaletteLoadCmd(
         mhw_render_g10_X::_3DSTATE_SAMPLER_PALETTE_LOAD0_CMD cmd;
         // Set size of palette load command
         cmd.DW0.DwordLength = params->iNumEntries - 1;
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
     }
     else if (params->iPaletteID == 1)
     {
         mhw_render_g10_X::_3DSTATE_SAMPLER_PALETTE_LOAD1_CMD cmd;
         // Set size of palette load command
         cmd.DW0.DwordLength = params->iNumEntries - 1;
-        MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+        MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
     }
     else
     {
@@ -219,7 +219,7 @@ MOS_STATUS MhwRenderInterfaceG10::AddPaletteLoadCmd(
     uint32_t cmdSize = entry.byteSize * params->iNumEntries;
 
     // Send palette load command followed by palette data
-    MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, params->pPaletteData, cmdSize));
+    MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, params->pPaletteData, cmdSize));
 
     return MOS_STATUS_SUCCESS;
 }
@@ -267,6 +267,7 @@ MOS_STATUS MhwRenderInterfaceG10::AddGpgpuCsrBaseAddrCmd(
     PMOS_COMMAND_BUFFER             cmdBuffer,
     PMOS_RESOURCE                   csrResource)
 {
+    MHW_MI_CHK_NULL(m_osInterface);
     MHW_MI_CHK_NULL(cmdBuffer);
     MHW_MI_CHK_NULL(csrResource);
 
@@ -287,7 +288,7 @@ MOS_STATUS MhwRenderInterfaceG10::AddGpgpuCsrBaseAddrCmd(
         cmdBuffer,
         &resourceParams));
 
-    MHW_MI_CHK_STATUS(Mos_AddCommand(cmdBuffer, &cmd, cmd.byteSize));
+    MHW_MI_CHK_STATUS(m_osInterface->pfnAddCommand(cmdBuffer, &cmd, cmd.byteSize));
 
     return MOS_STATUS_SUCCESS;
 }
