@@ -619,7 +619,7 @@ CodechalDecodeJpegG12::CodechalDecodeJpegG12(
 
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
-    Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+    m_osInterface->pfnVirtualEngineSupported(m_osInterface, true, true);
 }
 
 void CodechalDecodeJpegG12::CalcRequestedSpace(
