@@ -1625,7 +1625,7 @@ CodechalDecodeVc1G12::CodechalDecodeVc1G12(
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(hwInterface);
     CODECHAL_DECODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
-    Mos_CheckVirtualEngineSupported(m_osInterface, true, true);
+    m_osInterface->pfnVirtualEngineSupported(m_osInterface, true, true);
 
     m_olpCurbeStaticDataLength = CODECHAL_DECODE_VC1_CURBE_SIZE_OLP;
 
