@@ -108,7 +108,7 @@ VAStatus DdiEncodeAV1::ContextInitialize(
     codecHalSettings->mode             = m_encodeCtx->wModeType;
     codecHalSettings->standard         = CODECHAL_AV1;
     codecHalSettings->chromaFormat     = AVP_CHROMA_FORMAT_YUV420;
-    codecHalSettings->lumaChromaDepth  = CODECHAL_LUMA_CHROMA_DEPTH_8_BITS;
+    codecHalSettings->lumaChromaDepth  = CODECHAL_LUMA_CHROMA_DEPTH_10_BITS;
 
     VAStatus eStatus = VA_STATUS_SUCCESS;
 
@@ -434,7 +434,11 @@ VAStatus DdiEncodeAV1::ParseSeqParams(void *ptr)
     av1SeqParams->CodingToolFlags.fields.enable_restoration   = seqParams->seq_fields.bits.enable_restoration;
 
     av1SeqParams->order_hint_bits_minus_1 = seqParams->order_hint_bits_minus_1;
+#if VA_CHECK_VERSION(1, 16, 0)
+    av1SeqParams->SeqFlags.fields.HierarchicalFlag = seqParams->hierarchical_flag;
+#else
     av1SeqParams->SeqFlags.fields.HierarchicalFlag = seqParams->reserved8b;
+#endif
 
     return VA_STATUS_SUCCESS;
 }
@@ -547,7 +551,12 @@ VAStatus DdiEncodeAV1::ParsePicParams(DDI_MEDIA_CONTEXT *mediaCtx, void *ptr)
     av1PicParams->PicFlags.fields.DisableFrameRecon            = picParams->picture_flags.bits.disable_frame_recon;
     av1PicParams->PicFlags.fields.PaletteModeEnable            = picParams->picture_flags.bits.palette_mode_enable;
     av1PicParams->PicFlags.fields.SegIdBlockSize               = picParams->seg_id_block_size;
+
+#if VA_CHECK_VERSION(1, 16, 0)
+    av1PicParams->HierarchLevelPlus1                           = picParams->hierarchical_level_plus1;
+#else
     av1PicParams->HierarchLevelPlus1                           = picParams->reserved8bits0;
+#endif
 
     DDI_CHK_RET(
         MOS_SecureMemcpy(av1PicParams->filter_level,
@@ -641,6 +650,8 @@ VAStatus DdiEncodeAV1::ParsePicParams(DDI_MEDIA_CONTEXT *mediaCtx, void *ptr)
 
     DDI_CHK_RET(CheckCDEF(picParams, mediaCtx->platform.eProductFamily), "invalid CDEF Paramter");
 
+    DDI_CHK_RET(CheckTile(picParams), "invalid Tile Paramter");
+
     av1PicParams->context_update_tile_id = picParams->context_update_tile_id;
     av1PicParams->temporal_id            = picParams->temporal_id;
 
@@ -901,6 +912,9 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
     PCODEC_AV1_ENCODE_SEQUENCE_PARAMS seqParams = (PCODEC_AV1_ENCODE_SEQUENCE_PARAMS)m_encodeCtx->pSeqParams;
     DDI_CHK_NULL(seqParams, "nullptr seqParams", VA_STATUS_ERROR_INVALID_PARAMETER);
 
+    PCODEC_AV1_ENCODE_PICTURE_PARAMS  picParams = (PCODEC_AV1_ENCODE_PICTURE_PARAMS)(m_encodeCtx->pPicParams);
+    DDI_CHK_NULL(picParams, "nullptr picParams", VA_STATUS_ERROR_INVALID_PARAMETER);
+
     uint32_t temporalId = vaEncMiscParamRC->rc_flags.bits.temporal_id;
     DDI_CHK_LESS(temporalId, (seqParams->NumTemporalLayersMinus1 + 1),
         "invalid temporal id", VA_STATUS_ERROR_INVALID_PARAMETER);
@@ -908,6 +922,10 @@ VAStatus DdiEncodeAV1::ParseMiscParamRC(void *data)
     uint32_t bitRate                    = MOS_ROUNDUP_DIVIDE(vaEncMiscParamRC->bits_per_second, CODECHAL_ENCODE_BRC_KBPS);
     seqParams->MaxBitRate               = MOS_MAX(seqParams->MaxBitRate, bitRate);
     seqParams->SeqFlags.fields.ResetBRC = vaEncMiscParamRC->rc_flags.bits.reset;
+    seqParams->FrameSizeTolerance       = static_cast<ENCODE_FRAMESIZE_TOLERANCE>(vaEncMiscParamRC->rc_flags.bits.frame_tolerance_mode);
+#if VA_CHECK_VERSION(1, 10, 0)
+    picParams->TargetFrameSize = vaEncMiscParamRC->target_frame_size;
+#endif
 
     if (VA_RC_CBR == m_encodeCtx->uiRCMethod)
     {
@@ -1051,6 +1069,29 @@ VAStatus DdiEncodeAV1::CheckCDEF(const VAEncPictureParameterBufferAV1 *picParams
     return VA_STATUS_SUCCESS;
 }
 
+VAStatus DdiEncodeAV1::CheckTile(const VAEncPictureParameterBufferAV1 *picParams)
+{
+    int minTileHeightInSB = picParams->height_in_sbs_minus_1[0] + 1;
+    int minTileWidthInSB = picParams->width_in_sbs_minus_1[0] + 1;
+
+    for(int i = 1;i < picParams->tile_cols;i++)
+    {
+        minTileWidthInSB = MOS_MIN(minTileWidthInSB, picParams->width_in_sbs_minus_1[i] + 1);
+    }
+    for(int i = 1;i < picParams->tile_rows;i++)
+    {
+        minTileHeightInSB = MOS_MIN(minTileHeightInSB, picParams->height_in_sbs_minus_1[i] + 1);
+    }
+
+    if(minTileWidthInSB * minTileHeightInSB < 2)
+    {
+        DDI_ASSERTMESSAGE("Unsupported Tile Size");
+        return VA_STATUS_ERROR_INVALID_PARAMETER;
+    }
+
+    return VA_STATUS_SUCCESS;
+}
+
 void DdiEncodeAV1::SetupCodecPicture(
     DDI_MEDIA_CONTEXT             *mediaCtx,
     DDI_CODEC_RENDER_TARGET_TABLE *rtTbl,
