@@ -75,6 +75,7 @@ VAStatus DdiEncodeBase::EndPicture(
     DDI_CHK_NULL(mediaCtx, "Null mediaCtx", VA_STATUS_ERROR_INVALID_CONTEXT);
 
     VAStatus status = EncodeInCodecHal(m_encodeCtx->dwNumSlices);
+    ClearPicParams();
     if (VA_STATUS_SUCCESS != status)
     {
         DDI_ASSERTMESSAGE("DDI:DdiEncode_EncodeInCodecHal return failure.");
@@ -175,19 +176,17 @@ VAStatus DdiEncodeBase::StatusReport(
     // Get encoded frame information from status buffer queue.
     while (VA_STATUS_SUCCESS == (eStatus = GetSizeFromStatusReportBuffer(mediaBuf, &size, &status, &index)))
     {
-        if ((index >= 0) && (size != 0))  //Get the matched encoded buffer information
+        if ((index >= 0) && ((size != 0) || (status & VA_CODED_BUF_STATUS_BAD_BITSTREAM))) //Get the matched encoded buffer information
         {
             // the first segment in the single-link list: pointer for the coded bitstream and the size
             m_encodeCtx->BufMgr.pCodedBufferSegment->buf    = DdiMediaUtil_LockBuffer(mediaBuf, MOS_LOCKFLAG_READONLY);
             m_encodeCtx->BufMgr.pCodedBufferSegment->size   = size;
             m_encodeCtx->BufMgr.pCodedBufferSegment->status = status;
-            break;
-        }
-        else if ((index >= 0) && (size == 0) && (status & VA_CODED_BUF_STATUS_BAD_BITSTREAM))
-        {
-            m_encodeCtx->BufMgr.pCodedBufferSegment->buf    = DdiMediaUtil_LockBuffer(mediaBuf, MOS_LOCKFLAG_READONLY);
-            m_encodeCtx->BufMgr.pCodedBufferSegment->size   = size;
-            m_encodeCtx->BufMgr.pCodedBufferSegment->status = status;
+
+            if (status & VA_CODED_BUF_STATUS_BAD_BITSTREAM)
+            {
+                return VA_STATUS_ERROR_ENCODING_ERROR;
+            }
             break;
         }
 
@@ -211,6 +210,20 @@ VAStatus DdiEncodeBase::StatusReport(
         {
             // Only AverageQP is reported at this time. Populate other bits with relevant informaiton later;
             status = (encodeStatusReport[0].AverageQp & VA_CODED_BUF_STATUS_PICTURE_AVE_QP_MASK);
+            if(m_encodeCtx->wModeType == CODECHAL_ENCODE_MODE_AVC)
+            {
+                CodecEncodeAvcFeiPicParams *feiPicParams = (CodecEncodeAvcFeiPicParams*) m_encodeCtx->pFeiPicParams;
+                if ((feiPicParams != NULL) && (feiPicParams->dwMaxFrameSize != 0))
+                {
+                    // The reported the pass number should be multi-pass PAK caused by the MaxFrameSize.
+                    // if the suggestedQpYDelta is 0, it means that MaxFrameSize doesn't trigger multi-pass PAK.
+                    // The MaxMbSize triggers multi-pass PAK, the cases should be ignored when reporting the PAK pass.
+                    if ((encodeStatusReport[0].SuggestedQpYDelta == 0) && (encodeStatusReport[0].NumberPasses != 1))
+                    {
+                        encodeStatusReport[0].NumberPasses = 1;
+                    }
+                }
+            }
             status = status | ((encodeStatusReport[0].NumberPasses) & 0xf)<<24;
             // fill hdcp related buffer
             DDI_CHK_RET(m_encodeCtx->pCpDdiInterface->StatusReportForHdcp2Buffer(&m_encodeCtx->BufMgr, encodeStatusReport), "fail to get hdcp2 status report!");
@@ -220,7 +233,7 @@ VAStatus DdiEncodeBase::StatusReport(
                 m_encodeCtx->BufMgr.pCodedBufferSegment->size = 0;
                 m_encodeCtx->BufMgr.pCodedBufferSegment->status |= VA_CODED_BUF_STATUS_BAD_BITSTREAM;
                 m_encodeCtx->statusReportBuf.ulUpdatePosition = (m_encodeCtx->statusReportBuf.ulUpdatePosition + 1) % DDI_ENCODE_MAX_STATUS_REPORT_BUFFER;
-                break;
+                return VA_STATUS_ERROR_ENCODING_ERROR;
             }
 
             // Report extra status for completed coded buffer
@@ -237,8 +250,7 @@ VAStatus DdiEncodeBase::StatusReport(
         {
             bool inlineEncodeStatusUpdate;
             CodechalEncoderState *encoder = dynamic_cast<CodechalEncoderState *>(m_encodeCtx->pCodecHal);
-            DDI_CHK_NULL(encoder, "Null codechal encoder", VA_STATUS_ERROR_INVALID_CONTEXT);
-            inlineEncodeStatusUpdate = encoder->m_inlineEncodeStatusUpdate;
+            inlineEncodeStatusUpdate = encoder == nullptr ? false : encoder->m_inlineEncodeStatusUpdate;
 
             if (inlineEncodeStatusUpdate)
             {
@@ -267,17 +279,17 @@ VAStatus DdiEncodeBase::StatusReport(
                 m_encodeCtx->BufMgr.pCodedBufferSegment->status |= VA_CODED_BUF_STATUS_BAD_BITSTREAM;
                 UpdateStatusReportBuffer(encodeStatusReport[0].bitstreamSize, m_encodeCtx->BufMgr.pCodedBufferSegment->status);
                 DDI_ASSERTMESSAGE("Something unexpected happened in HW, return error to application");
-                break;
+                return VA_STATUS_ERROR_ENCODING_ERROR;
             }
         }
         else if (CODECHAL_STATUS_ERROR == encodeStatusReport[0].CodecStatus)
         {
-            DDI_NORMALMESSAGE("Encoding failure due to HW issue");
+            DDI_ASSERTMESSAGE("Encoding failure due to HW issue");
             m_encodeCtx->BufMgr.pCodedBufferSegment->buf  = DdiMediaUtil_LockBuffer(mediaBuf, MOS_LOCKFLAG_READONLY);
             m_encodeCtx->BufMgr.pCodedBufferSegment->size = 0;
             m_encodeCtx->BufMgr.pCodedBufferSegment->status |= VA_CODED_BUF_STATUS_BAD_BITSTREAM;
             UpdateStatusReportBuffer(encodeStatusReport[0].bitstreamSize, m_encodeCtx->BufMgr.pCodedBufferSegment->status);
-            break;
+            return VA_STATUS_ERROR_ENCODING_ERROR;
         }
         else
         {
@@ -926,6 +938,13 @@ VAStatus DdiEncodeBase::CreateBuffer(
     }
     case VAEncMacroblockMapBufferType:
     {
+        if(m_cpuFormat)
+        {
+            // elementsNum should be 1, ignore here just for robustness
+            bufSize = size;
+            break;
+        }
+
         buf->uiWidth = MOS_ALIGN_CEIL(size, 64);
         if (size != buf->uiWidth)
         {
@@ -1127,6 +1146,7 @@ VAStatus DdiEncodeBase::CreateBuffer(
             buf->iSize  = size;
             buf->format = Media_Format_Buffer;
         }
+        buf->bUseSysGfxMem = true;
         va = DdiMediaUtil_CreateBuffer(buf, mediaCtx->pDrmBufMgr);
         if (va != VA_STATUS_SUCCESS)
         {
@@ -1230,6 +1250,19 @@ VAStatus DdiEncodeBase::CreateBuffer(
         }
         break;
     }
+#if VA_CHECK_VERSION(1, 10, 0)
+    case VAContextParameterUpdateBufferType:
+    {
+        bufSize       = size;
+        if (bufSize < sizeof(VAContextParameterUpdateBuffer))
+        {
+            va = VA_STATUS_ERROR_INVALID_PARAMETER;
+            CleanUpBufferandReturn(buf);
+            return va;
+        }
+        break;
+    }
+#endif
     default:
     {
         bufSize = size * elementsNum;
@@ -1241,13 +1274,20 @@ VAStatus DdiEncodeBase::CreateBuffer(
             return va;
         }
 
-        DDI_ASSERTMESSAGE("DDI: non supported buffer type = %d, size = %d, num = %d", type, size, elementsNum);
+        va = m_encodeCtx->pCpDdiInterface->CreateBuffer(type, buf, size, elementsNum);
+        if (va  == VA_STATUS_ERROR_UNSUPPORTED_BUFFERTYPE)
+        {
+            MOS_FreeMemory(buf);
+            DDI_ASSERTMESSAGE("DDI: non supported buffer type = %d, size = %d, num = %d", type, size, elementsNum);
+            return va;
+        }
+
         break;
     }
     }
 
     if ((VAEncCodedBufferType != type) &&
-        (VAEncMacroblockMapBufferType != type) &&
+        (VAEncMacroblockMapBufferType != type || m_cpuFormat) &&
         (VAEncFEIMVBufferType != type) &&
         (VAEncFEIMBCodeBufferType != type) &&
         (VAEncFEICTBCmdBufferType != type)      &&
@@ -1289,14 +1329,27 @@ VAStatus DdiEncodeBase::CreateBuffer(
     mediaCtx->uiNumBufs++;
 
     // return success if data is nullptr, no need to copy data
-    if (data == nullptr || VAEncMacroblockMapBufferType == type)
+    if (data == nullptr)
     {
         return va;
     }
 
     DdiMediaUtil_LockBuffer(buf, MOS_LOCKFLAG_WRITEONLY | MOS_LOCKFLAG_READONLY);
 
-    MOS_STATUS eStatus = MOS_SecureMemcpy((void*)(buf->pData + buf->uiOffset), bufSize, (void*)data, bufSize);
+    // HW may use bigger than 64 pitch alignment for 2D. In such a case linear copying spoils the data
+    // and has to be executed line by line. 'size' is in fact input data pitch.
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    if (elementsNum > 1 && buf->format == Media_Format_2DBuffer && size < buf->uiPitch)
+    {
+        uint8_t *pDst = buf->pData + buf->uiOffset;
+        uint8_t *pSrc = (uint8_t *) data;
+        for (int32_t i = 0; i < elementsNum && eStatus == MOS_STATUS_SUCCESS; i++)
+            eStatus = MOS_SecureMemcpy(pDst + i*buf->uiPitch, size, pSrc + i*size, size);
+    }
+    else
+    {
+        eStatus = MOS_SecureMemcpy((void*)(buf->pData + buf->uiOffset), bufSize, (void*)data, bufSize);
+    }
 
     DdiMediaUtil_UnlockBuffer(buf);
 
@@ -1340,3 +1393,7 @@ uint32_t DdiEncodeBase::getQMatrixBufferSize()
 {
     return 0xffffffff;
 }
+
+void DdiEncodeBase::ClearPicParams()
+{
+}
