@@ -38,7 +38,7 @@
 #include "mos_solo_generic.h"
 #include "media_ddi_factory.h"
 #include "media_ddi_decode_base.h"
-#include "media_interfaces.h"
+#include "media_factory.h"
 #include "media_ddi_decode_const.h"
 #include "decode_status_report.h"
 #include "vphal_render_vebox_memdecomp.h"
@@ -50,6 +50,7 @@
 #include <linux/fb.h>
 
 typedef MediaDdiFactory<DdiMediaDecode, DDI_DECODE_CONFIG_ATTR> DdiDecodeFactory;
+static uint32_t DecodeFrameIndex;
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
 void DecodeEventDataAVCPicParamInit(
@@ -794,6 +795,11 @@ void DecodeEventDataAV1TileParamInit(
 
 static int32_t DdiDecode_GetDisplayInfo(VADriverContextP ctx)
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_DISPLAYINFOVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     PDDI_MEDIA_CONTEXT mediaDrvCtx        = DdiMedia_GetMediaContext(ctx);
     int32_t fd                            = -1;
     struct fb_var_screeninfo              vsinfo;
@@ -825,6 +831,14 @@ static int32_t DdiDecode_GetDisplayInfo(VADriverContextP ctx)
     DDI_NORMALMESSAGE("DDI:mediaDrvCtx->uiDisplayWidth =%d", mediaDrvCtx->uiDisplayWidth);
     DDI_NORMALMESSAGE("DDI:mediaDrvCtx->uiDisplayHeight =%d",mediaDrvCtx->uiDisplayHeight);
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_DISPLAYINFO eventData;
+        eventData.uiDisplayWidth    = mediaDrvCtx->uiDisplayWidth;
+        eventData.uiDisplayHeight    = mediaDrvCtx->uiDisplayHeight;
+        MOS_TraceEvent(EVENT_DECODE_DDI_DISPLAYINFOVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     return 0;
 }
 
@@ -838,11 +852,26 @@ VAStatus DdiDecode_CreateBuffer(
     VABufferID              *bufId
 )
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_CREATEBUFFERVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     *bufId     = VA_INVALID_ID;
     if (decCtx->m_ddiDecode){
         DDI_CHK_RET(decCtx->m_ddiDecode->CreateBuffer(type, size, numElements, data, bufId),"DdiDecode_CreateBuffer failed!");
     }
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_CREATEBUFFER eventData;
+        eventData.type = type;
+        eventData.size = size;
+        eventData.numElements = numElements;
+        eventData.bufId = bufId;
+        MOS_TraceEvent(EVENT_DECODE_DDI_CREATEBUFFERVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     return VA_STATUS_SUCCESS;
 
 }
@@ -855,6 +884,13 @@ VAStatus DdiDecode_BeginPicture (
 {
     DDI_FUNCTION_ENTER();
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_BEGINPICTURE_START eventData;
+        eventData.FrameIndex    = DecodeFrameIndex;
+        MOS_TraceEvent(EVENT_DECODE_DDI_BEGINPICTUREVA, EVENT_TYPE_START, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_DDI);
 
     uint32_t  ctxType;
@@ -870,6 +906,14 @@ VAStatus DdiDecode_BeginPicture (
     {
         VAStatus va = decCtx->m_ddiDecode->BeginPicture(ctx, context, renderTarget);
         DDI_FUNCTION_EXIT(va);
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_BEGINPICTURE eventData;
+        eventData.FrameIndex                  = DecodeFrameIndex;
+        eventData.hRes                        = va;
+        MOS_TraceEvent(EVENT_DECODE_DDI_BEGINPICTUREVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
         return va;
     }
 
@@ -890,6 +934,13 @@ VAStatus DdiDecode_EndPicture (
 {
     DDI_FUNCTION_ENTER();
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_ENDPICTURE_START eventData;
+        eventData.FrameIndex = DecodeFrameIndex;
+        MOS_TraceEvent(EVENT_DECODE_DDI_ENDPICTUREVA, EVENT_TYPE_START, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_DDI);
 
     DDI_CHK_NULL(ctx,                "nullptr context in vpgDecodeEndPicture!", VA_STATUS_ERROR_INVALID_CONTEXT);
@@ -906,6 +957,15 @@ VAStatus DdiDecode_EndPicture (
         {
             VAStatus va = decCtx->pCpDdiInterface->EndPicture(ctx, context);
             DDI_FUNCTION_EXIT(va);
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_ENDPICTURE eventData;
+        eventData.FrameIndex = DecodeFrameIndex;
+        eventData.hRes       = va;
+        MOS_TraceEvent(EVENT_DECODE_DDI_ENDPICTUREVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+        DecodeFrameIndex++;
+    }
+#endif
             return va;
         }
     }
@@ -914,6 +974,15 @@ VAStatus DdiDecode_EndPicture (
     {
         VAStatus va = decCtx->m_ddiDecode->EndPicture(ctx, context);
         DDI_FUNCTION_EXIT(va);
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_ENDPICTURE eventData;
+        eventData.FrameIndex = DecodeFrameIndex;
+        eventData.hRes       = va;
+        MOS_TraceEvent(EVENT_DECODE_DDI_ENDPICTUREVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+        DecodeFrameIndex++;
+    }
+#endif
         return va;
     }
 
@@ -932,6 +1001,13 @@ VAStatus DdiDecode_RenderPicture (
     int32_t             numBuffers
 )
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_RENDERPICTURE_START eventData;
+        eventData.buffers = buffers;
+        MOS_TraceEvent(EVENT_DECODE_DDI_RENDERPICTUREVA, EVENT_TYPE_START, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     VAStatus        va                      = VA_STATUS_SUCCESS;
     int32_t         numOfBuffers            = numBuffers;
     int32_t         priority                = 0;
@@ -972,6 +1048,15 @@ VAStatus DdiDecode_RenderPicture (
     {
         va = decCtx->m_ddiDecode->RenderPicture(ctx, context, buffers, numOfBuffers);
         DDI_FUNCTION_EXIT(va);
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_RENDERPICTURE eventData;
+        eventData.buffers = buffers;
+        eventData.hRes    = va;
+        eventData.numBuffers = numBuffers;
+        MOS_TraceEvent(EVENT_DECODE_DDI_RENDERPICTUREVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
         return va;
     }
 
@@ -991,6 +1076,11 @@ void DdiDecodeCleanUp(
     VADriverContextP    ctx,
     PDDI_DECODE_CONTEXT decCtx)
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_CLEARUPVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     if(decCtx)
     {
         if(decCtx->m_ddiDecode)
@@ -1001,11 +1091,21 @@ void DdiDecodeCleanUp(
             decCtx = nullptr;
         }
     }
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_CLEARUPVA, EVENT_TYPE_END, NULL, 0, NULL, 0);
+    }
+#endif
     return;
 }
 
 VAStatus DdiDecode_StatusReport(PDDI_MEDIA_CONTEXT mediaCtx, CodechalDecode *decoder, DDI_MEDIA_SURFACE *surface)
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_STATUSREPORTVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     if (decoder->IsStatusQueryReportingEnabled())
     {
         uint32_t i = 0;
@@ -1077,6 +1177,11 @@ VAStatus DdiDecode_StatusReport(PDDI_MEDIA_CONTEXT mediaCtx, CodechalDecode *dec
             }
         }
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_STATUSREPORTVA, EVENT_TYPE_END, NULL, 0, NULL, 0);
+    }
+#endif
         // check the report ptr of current surface.
         if (surface->curStatusReportQueryState == DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED)
         {
@@ -1103,6 +1208,11 @@ VAStatus DdiDecode_StatusReport(PDDI_MEDIA_CONTEXT mediaCtx, CodechalDecode *dec
 
 VAStatus DdiDecode_StatusReport(PDDI_MEDIA_CONTEXT mediaCtx, DecodePipelineAdapter *decoder, DDI_MEDIA_SURFACE *surface)
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_STATUSREPORTVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     if (surface->curStatusReportQueryState == DDI_MEDIA_STATUS_REPORT_QUERY_STATE_PENDING)
     {
         uint32_t uNumCompletedReport = decoder->GetCompletedReport();
@@ -1150,6 +1260,11 @@ VAStatus DdiDecode_StatusReport(PDDI_MEDIA_CONTEXT mediaCtx, DecodePipelineAdapt
         }
     }
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_STATUSREPORTVA, EVENT_TYPE_END, NULL, 0, NULL, 0);
+    }
+#endif
     // check the report ptr of current surface.
     if (surface->curStatusReportQueryState == DDI_MEDIA_STATUS_REPORT_QUERY_STATE_COMPLETED)
     {
@@ -1196,6 +1311,13 @@ VAStatus DdiDecode_CreateContext (
 {
     PERF_UTILITY_AUTO(__FUNCTION__, PERF_DECODE, PERF_LEVEL_DDI);
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_CREATECONTEXT_START eventData;
+        eventData.configId = configId;
+        MOS_TraceEvent(EVENT_DECODE_DDI_CREATECONTEXTVA, EVENT_TYPE_START, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     MOS_CONTEXT                       mosCtx = {};
     PDDI_MEDIA_VACONTEXT_HEAP_ELEMENT contextHeapElement;
     DdiMediaDecode                    *ddiDecBase;
@@ -1275,10 +1397,10 @@ VAStatus DdiDecode_CreateContext (
     mosCtx.m_cmdBufMgr           = mediaCtx->m_cmdBufMgr;
     mosCtx.fd                    = mediaCtx->fd;
     mosCtx.iDeviceId             = mediaCtx->iDeviceId;
-    mosCtx.SkuTable              = mediaCtx->SkuTable;
-    mosCtx.WaTable               = mediaCtx->WaTable;
-    mosCtx.gtSystemInfo          = *mediaCtx->pGtSystemInfo;
-    mosCtx.platform              = mediaCtx->platform;
+    mosCtx.m_skuTable            = mediaCtx->SkuTable;
+    mosCtx.m_waTable             = mediaCtx->WaTable;
+    mosCtx.m_gtSystemInfo        = *mediaCtx->pGtSystemInfo;
+    mosCtx.m_platform            = mediaCtx->platform;
     mosCtx.ppMediaMemDecompState = &mediaCtx->pMediaMemDecompState;
     mosCtx.pfnMemoryDecompress   = mediaCtx->pfnMemoryDecompress;
     mosCtx.pfnMediaMemoryCopy    = mediaCtx->pfnMediaMemoryCopy;
@@ -1289,6 +1411,7 @@ VAStatus DdiDecode_CreateContext (
     mosCtx.m_osDeviceContext     = mediaCtx->m_osDeviceContext;
     mosCtx.m_apoMosEnabled       = mediaCtx->m_apoMosEnabled;
     mosCtx.pPerfData             = (PERF_DATA *)MOS_AllocAndZeroMemory(sizeof(PERF_DATA));
+    mosCtx.m_userSettingPtr      = mediaCtx->m_userSettingPtr;
 
     if (nullptr == mosCtx.pPerfData)
     {
@@ -1360,6 +1483,14 @@ VAStatus DdiDecode_CreateContext (
     {
         decCtx->RecListSurfaceID[i] = VA_INVALID_ID;
     }
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_CREATECONTEXT eventData;
+        eventData.configId = configId;
+        eventData.hRes = va;
+        MOS_TraceEvent(EVENT_DECODE_DDI_CREATECONTEXTVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     return va;
 }
 
@@ -1379,6 +1510,11 @@ static void* DdiMedia_GetDecCtxFromVABufferID (PDDI_MEDIA_CONTEXT mediaCtx, VABu
 {
     DDI_CHK_NULL(mediaCtx, "nullptr mediaCtx", nullptr);
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_GETDECCTXFROMBUFFERIDVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     uint32_t i      = (uint32_t)bufferID;
     DDI_CHK_LESS(i, mediaCtx->pBufferHeap->uiAllocatedHeapElements, "invalid buffer id", nullptr);
     DdiMediaUtil_LockMutex(&mediaCtx->BufferMutex);
@@ -1387,6 +1523,13 @@ static void* DdiMedia_GetDecCtxFromVABufferID (PDDI_MEDIA_CONTEXT mediaCtx, VABu
     void *temp      = bufHeapElement->pCtx;
     DdiMediaUtil_UnLockMutex(&mediaCtx->BufferMutex);
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_GETDECCTX eventData;
+        eventData.bufferID = (uint32_t)bufferID;
+        MOS_TraceEvent(EVENT_DECODE_DDI_GETDECCTXFROMBUFFERIDVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     return temp;
 }
 
@@ -1413,7 +1556,14 @@ static void DdiMedia_FreeBufferHeapElements(VADriverContextP    ctx, PDDI_DECODE
         return;
 
     int32_t bufNums = mediaCtx->uiNumBufs;
-    for (int32_t elementId = 0; bufNums > 0; ++elementId)
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_FREEBUFFERHEAPELEMENTS eventData;
+        eventData.bufNums = bufNums;
+        MOS_TraceEvent(EVENT_DECODE_DDI_FREEBUFFERHEAPELEMENTSVA, EVENT_TYPE_START, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
+    for (int32_t elementId = 0; bufNums > 0 && elementId < bufferHeap->uiAllocatedHeapElements; ++elementId)
     {
         PDDI_MEDIA_BUFFER_HEAP_ELEMENT mediaBufferHeapElmt = &mediaBufferHeapBase[elementId];
         if (nullptr == mediaBufferHeapElmt->pBuffer)
@@ -1439,6 +1589,13 @@ static void DdiMedia_FreeBufferHeapElements(VADriverContextP    ctx, PDDI_DECODE
         //Ensure the non-empty buffer to be destroyed.
         --bufNums;
     }
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_FREEBUFFERHEAPELEMENTS eventData;
+        eventData.bufNums = bufNums;
+        MOS_TraceEvent(EVENT_DECODE_DDI_FREEBUFFERHEAPELEMENTSVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
 }
 
 VAStatus DdiDecode_DestroyContext (
@@ -1446,6 +1603,13 @@ VAStatus DdiDecode_DestroyContext (
     VAContextID         context
 )
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_DESTROYCONTEXT_START eventData;
+        eventData.context = context;
+        MOS_TraceEvent(EVENT_DECODE_DDI_DESTROYCONTEXTVA, EVENT_TYPE_START, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     PDDI_MEDIA_CONTEXT mediaCtx   = DdiMedia_GetMediaContext(ctx);
     DDI_CHK_NULL(mediaCtx,          "nullptr mediaCtx",          VA_STATUS_ERROR_INVALID_CONTEXT);
     uint32_t  ctxType;
@@ -1462,6 +1626,13 @@ VAStatus DdiDecode_DestroyContext (
 
     DdiMedia_FreeBufferHeapElements(ctx, decCtx);
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        DECODE_EVENTDATA_VA_DESTROYCONTEXT eventData;
+        eventData.context = context;
+        MOS_TraceEvent(EVENT_DECODE_DDI_DESTROYCONTEXTVA, EVENT_TYPE_END, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
     if (decCtx->m_ddiDecode) {
     DdiDecodeCleanUp(ctx,decCtx);
         return VA_STATUS_SUCCESS;
@@ -1476,6 +1647,11 @@ VAStatus DdiDecode_SetGpuPriority(
     int32_t              priority
 )
 {
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_SETGPUPRIORITYVA, EVENT_TYPE_START, NULL, 0, NULL, 0);
+    }
+#endif
     PDDI_MEDIA_CONTEXT mediaCtx = DdiMedia_GetMediaContext(ctx);
     DDI_CHK_NULL(mediaCtx,           "nullptr mediaCtx",                             VA_STATUS_ERROR_INVALID_CONTEXT);
     DDI_CHK_NULL(decCtx,             "nullptr decCtx",                               VA_STATUS_ERROR_INVALID_CONTEXT);
@@ -1495,6 +1671,11 @@ VAStatus DdiDecode_SetGpuPriority(
         if(mediaVeboxDecompState->m_osInterface)
             mediaVeboxDecompState->m_osInterface->pfnSetGpuPriority(mediaVeboxDecompState->m_osInterface, priority);
     }
+#endif
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    {
+        MOS_TraceEvent(EVENT_DECODE_DDI_SETGPUPRIORITYVA, EVENT_TYPE_END, NULL, 0, NULL, 0);
+    }
 #endif
     return VA_STATUS_SUCCESS;
 }
