@@ -39,6 +39,10 @@
 #define DDI_DECODE_HCP_SFC_MAX_HEIGHT               (16*1024)
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
+
+#define MACROBLOCK_HEIGHT   16
+#define MACROBLOCK_WIDTH    16
+
 typedef struct _DECODE_EVENTDATA_BITSTREAM
 {
     uint8_t Data[32];
@@ -51,6 +55,120 @@ typedef struct _DECODE_EVENTDATA_FRAME
     uint32_t PicEntry;  
 } DECODE_EVENTDATA_FRAME;
 
+typedef struct _DECODE_EVENTDATA_INFO_PICTURE
+{
+    uint32_t CodecFormat;
+    uint32_t FrameType;
+    uint32_t PicStruct;
+    uint32_t Width;
+    uint32_t Height;
+    uint32_t Bitdepth;
+    uint32_t ChromaFormat;
+    bool     EnabledSCC;
+    bool     EnabledSegment;
+    bool     EnabledFilmGrain;
+} DECODE_EVENTDATA_INFO_PICTURE;
+
+typedef struct _DECODE_EVENTDATA_INFO_PICTUREVA
+{
+    uint32_t CodecFormat;
+    uint32_t FrameType;
+    uint32_t PicStruct;
+    uint32_t Width;
+    uint32_t Height;
+    uint32_t Bitdepth;
+    uint32_t ChromaFormat;
+    bool     EnabledSCC;
+    bool     EnabledSegment;
+    bool     EnabledFilmGrain;
+} DECODE_EVENTDATA_INFO_PICTUREVA;
+
+typedef struct _DECODE_EVENTDATA_VA_DISPLAYINFO
+{
+    uint32_t uiDisplayWidth;
+    uint32_t uiDisplayHeight;
+} DECODE_EVENTDATA_VA_DISPLAYINFO;
+
+typedef struct _DECODE_EVENTDATA_VA_CREATEBUFFER
+{
+    VABufferType type;
+    uint32_t size;
+    uint32_t numElements;
+    VABufferID *bufId;
+} DECODE_EVENTDATA_VA_CREATEBUFFER;
+
+typedef struct _DECODE_EVENTDATA_VA_BEGINPICTURE_START
+{
+    uint32_t FrameIndex;
+} DECODE_EVENTDATA_VA_BEGINPICTURE_START;
+
+typedef struct _DECODE_EVENTDATA_VA_BEGINPICTURE
+{
+    uint32_t FrameIndex;
+    uint32_t hRes;
+} DECODE_EVENTDATA_VA_BEGINPICTURE;
+
+typedef struct _DECODE_EVENTDATA_VA_ENDPICTURE_START
+{
+    uint32_t FrameIndex;
+} DECODE_EVENTDATA_VA_ENDPICTURE_START;
+
+typedef struct _DECODE_VA_EVENTDATA_ENDPICTURE
+{
+    uint32_t FrameIndex;
+    uint32_t hRes;
+} DECODE_EVENTDATA_VA_ENDPICTURE;
+
+
+typedef struct _DECODE_EVENTDATA_VA_RENDERPICTURE_START
+{
+    VABufferID *buffers;
+} DECODE_EVENTDATA_VA_RENDERPICTURE_START;
+
+typedef struct _DECODE_EVENTDATA_VA_RENDERPICTURE
+{
+    VABufferID *buffers;
+    uint32_t hRes;
+    uint32_t numBuffers;
+} DECODE_EVENTDATA_VA_RENDERPICTURE;
+
+typedef struct _DECODE_EVENTDATA_VA_CREATECONTEXT_START
+{
+    VABufferID configId;
+} DECODE_EVENTDATA_VA_CREATECONTEXT_START;
+
+typedef struct _DECODE_EVENTDATA_VA_CREATECONTEXT
+{
+    VABufferID configId;
+    uint32_t hRes;
+} DECODE_EVENTDATA_VA_CREATECONTEXT;
+
+typedef struct _DECODE_EVENTDATA_VA_DESTROYCONTEXT_START
+{
+    VABufferID context;
+} DECODE_EVENTDATA_VA_DESTROYCONTEXT_START;
+
+typedef struct _DECODE_EVENTDATA_VA_DESTROYCONTEXT
+{
+    VABufferID context;
+} DECODE_EVENTDATA_VA_DESTROYCONTEXT;
+
+typedef struct _DECODE_EVENTDATA_VA_GETDECCTX
+{
+    uint32_t bufferID;
+} DECODE_EVENTDATA_VA_GETDECCTX;
+
+typedef struct _DECODE_EVENTDATA_VA_FREEBUFFERHEAPELEMENTS
+{
+    uint32_t bufNums;
+} DECODE_EVENTDATA_VA_FREEBUFFERHEAPELEMENTS;
+
+typedef struct _DECODE_EVENTDATA_VA_FEATURE_REPORTMODE
+{
+    uint32_t wMode;
+    uint32_t ValueID;
+} DECODE_EVENTDATA_VA_FEATURE_REPORTMODE;
+
 typedef struct _DECODE_EVENTDATA_PICPARAM_AVC
 {
     uint32_t CurrFrameIdx;
@@ -594,6 +712,8 @@ struct DDI_DECODE_CONFIG_ATTR
 typedef struct DDI_DECODE_CONFIG_ATTR *PDDI_DECODE_CONFIG_ATTR;
 
 class DdiMediaDecode;
+class DdiDecodeBase;
+class DdiVpFunctions;
 
 //!
 //! \struct DDI_DECODE_CONTEXT
@@ -604,8 +724,10 @@ struct DDI_DECODE_CONTEXT
     // Decoder data related with the specific codec
     // The instance of DdiDecodeXXX. For example: DdiDecodeAvc, DdiDecodeJPEG
     DdiMediaDecode                  *m_ddiDecode;
+    DdiDecodeBase                   *m_ddiDecodeNext;
     // Decoder private data
     DdiCpInterface                  *pCpDdiInterface;
+    DdiVpFunctions                  *pVpDdiInterface;
     // Parameters
     CodechalDecodeParams            DecodeParams;
     uint16_t                        wMode;                  // Get the info during hand shaking
