@@ -34,6 +34,7 @@
 #include <fcntl.h>
 #include <dlfcn.h>
 #include <errno.h>
+#include "inttypes.h"
 
 #include "media_libva_util.h"
 #include "mos_utilities.h"
@@ -91,7 +92,7 @@ void DdiMediaUtil_MediaPrintFps()
         int64_t diff  = (tv2.tv_sec - tv1.tv_sec)*1000000 + tv2.tv_usec - tv1.tv_usec;
         float fps     = frameCountFps / (diff / 1000000.0);
         DDI_NORMALMESSAGE("FPS:%6.4f, Interval:%11lu.", fps,((uint64_t)tv2.tv_sec)*1000 + (tv2.tv_usec/1000));
-        sprintf(temp,"FPS:%6.4f, Interval:%11lu\n", fps,((uint64_t)tv2.tv_sec)*1000 + (tv2.tv_usec/1000));
+        sprintf(temp,"FPS:%6.4f, Interval:%" PRIu64"\n", fps,((uint64_t)tv2.tv_sec)*1000 + (tv2.tv_usec/1000));
 
         MOS_ZeroMemory(fpsFileName,LENGTH_OF_FPS_FILE_NAME);
         sprintf(fpsFileName, FPS_FILE_NAME);
@@ -1111,19 +1112,20 @@ static VAStatus SwizzleSurfaceByHW(DDI_MEDIA_SURFACE *surface, bool isDeSwizzle
     mosCtx.m_cmdBufMgr     = mediaDrvCtx->m_cmdBufMgr;
     mosCtx.fd              = mediaDrvCtx->fd;
     mosCtx.iDeviceId       = mediaDrvCtx->iDeviceId;
-    mosCtx.SkuTable        = mediaDrvCtx->SkuTable;
-    mosCtx.WaTable         = mediaDrvCtx->WaTable;
-    mosCtx.gtSystemInfo    = *mediaDrvCtx->pGtSystemInfo;
-    mosCtx.platform        = mediaDrvCtx->platform;
+    mosCtx.m_skuTable      = mediaDrvCtx->SkuTable;
+    mosCtx.m_waTable       = mediaDrvCtx->WaTable;
+    mosCtx.m_gtSystemInfo  = *mediaDrvCtx->pGtSystemInfo;
+    mosCtx.m_platform      = mediaDrvCtx->platform;
 
     mosCtx.ppMediaMemDecompState = &mediaDrvCtx->pMediaMemDecompState;
     mosCtx.pfnMemoryDecompress   = mediaDrvCtx->pfnMemoryDecompress;
     mosCtx.pfnMediaMemoryCopy    = mediaDrvCtx->pfnMediaMemoryCopy;
     mosCtx.pfnMediaMemoryCopy2D  = mediaDrvCtx->pfnMediaMemoryCopy2D;
     mosCtx.pPerfData             = &perfData;
-    mosCtx.gtSystemInfo          = *mediaDrvCtx->pGtSystemInfo;
+    mosCtx.m_gtSystemInfo        = *mediaDrvCtx->pGtSystemInfo;
     mosCtx.m_auxTableMgr         = mediaDrvCtx->m_auxTableMgr;
     mosCtx.pGmmClientContext     = mediaDrvCtx->pGmmClientContext;
+    mosCtx.m_userSettingPtr      = mediaDrvCtx->m_userSettingPtr;
 
     mosCtx.m_osDeviceContext     = mediaDrvCtx->m_osDeviceContext;
 
@@ -1910,6 +1912,7 @@ VAStatus DdiMediaUtil_UnRegisterRTSurfaces(
 
 VAStatus DdiMediaUtil_SetMediaResetEnableFlag(PDDI_MEDIA_CONTEXT mediaCtx)
 {
+    bool enableReset = false;
     mediaCtx->bMediaResetEnable = false;
     
     DDI_CHK_NULL(mediaCtx,"nullptr mediaCtx!", VA_STATUS_ERROR_INVALID_CONTEXT);
@@ -1921,15 +1924,15 @@ VAStatus DdiMediaUtil_SetMediaResetEnableFlag(PDDI_MEDIA_CONTEXT mediaCtx)
     }
 
     mediaCtx->bMediaResetEnable = true;
+#if (_DEBUG || _RELEASE_INTERNAL)
+    ReadUserSettingForDebug(
+        mediaCtx->m_userSettingPtr,
+        enableReset,
+        __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_ENABLE,
+        MediaUserSetting::Group::Device);
+    mediaCtx->bMediaResetEnable = enableReset;
+#endif
 
-    MOS_USER_FEATURE_VALUE_DATA userFeatureData;
-    MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
-    MOS_USER_FEATURE_INVALID_KEY_ASSERT(
-        MOS_UserFeature_ReadValue_ID(nullptr,
-                                     __MEDIA_USER_FEATURE_VALUE_MEDIA_RESET_ENABLE_ID,
-                                     &userFeatureData,
-                                     (MOS_CONTEXT_HANDLE)nullptr));
-    mediaCtx->bMediaResetEnable = userFeatureData.i32Data ? true : false;
     if(!mediaCtx->bMediaResetEnable)
     {
         return VA_STATUS_SUCCESS;
