@@ -29,7 +29,7 @@
 
 #include "media_interfaces_dg2.h"
 #include "codechal.h"
-#include "codechal_debug_xe_hpm_ext.h"
+#include "codechal_debug.h"
 #if defined(ENABLE_KERNELS) && defined(_MEDIA_RESERVED)
 #include "cm_gpucopy_kernel_xe_hpm.h"
 #include "cm_gpuinit_kernel_xe_hpm.h"
@@ -50,33 +50,33 @@ unsigned char *pGPUInit_kernel_isa_dg2 = nullptr;
 #include "igvpkrn_isa_xe_hpg.h"
 #endif
 #endif
+#include "codechal_hw_next_xe_hpm.h"
 
 using namespace mhw::vdbox::avp::xe_hpm;
 using namespace mhw::vdbox::vdenc::xe_hpm;
 using namespace mhw::vdbox::huc::xe_hpm;
 
-extern template class MediaInterfacesFactory<MhwInterfaces>;
-extern template class MediaInterfacesFactory<MmdDevice>;
-extern template class MediaInterfacesFactory<McpyDevice>;
-extern template class MediaInterfacesFactory<MosUtilDevice>;
-extern template class MediaInterfacesFactory<CodechalDevice>;
-extern template class MediaInterfacesFactory<CMHalDevice>;
-extern template class MediaInterfacesFactory<VphalDevice>;
-extern template class MediaInterfacesFactory<RenderHalDevice>;
-extern template class MediaInterfacesFactory<Nv12ToP010Device>;
-extern template class MediaInterfacesFactory<DecodeHistogramDevice>;
-extern template class MediaInterfacesFactory<MediaInterfacesHwInfoDevice>;
+extern template class MediaFactory<uint32_t, MhwInterfaces>;
+extern template class MediaFactory<uint32_t, MmdDevice>;
+extern template class MediaFactory<uint32_t, McpyDevice>;
+extern template class MediaFactory<uint32_t, CodechalDevice>;
+extern template class MediaFactory<uint32_t, CodechalDeviceNext>;
+extern template class MediaFactory<uint32_t, CMHalDevice>;
+extern template class MediaFactory<uint32_t, VphalDevice>;
+extern template class MediaFactory<uint32_t, RenderHalDevice>;
+extern template class MediaFactory<uint32_t, Nv12ToP010Device>;
+extern template class MediaFactory<uint32_t, DecodeHistogramDevice>;
+extern template class MediaFactory<uint32_t, MediaInterfacesHwInfoDevice>;
 
 // Swith to use new media factory template
 extern template class MediaFactory<uint32_t, MhwInterfacesNext>;
 
 static bool dg2RegisteredVphal =
-MediaInterfacesFactory<VphalDevice>::
-RegisterHal<VphalInterfacesXe_Hpm>((uint32_t)IGFX_DG2);
+MediaFactory<uint32_t, VphalDevice>::
+Register<VphalInterfacesXe_Hpm>((uint32_t)IGFX_DG2);
 
 MOS_STATUS VphalInterfacesXe_Hpm::Initialize(
     PMOS_INTERFACE  osInterface,
-    PMOS_CONTEXT    osDriverContext,
     bool            bInitVphalState,
     MOS_STATUS      *eStatus)
 {
@@ -120,7 +120,6 @@ MOS_STATUS VphalInterfacesXe_Hpm::Initialize(
         m_vpBase = MOS_New(
             VpPipelineAdapterXe_Hpm,
             osInterface,
-            osDriverContext,
             *vpPlatformInterface,
             *eStatus);
         if (nullptr == m_vpBase)
@@ -133,10 +132,9 @@ MOS_STATUS VphalInterfacesXe_Hpm::Initialize(
     }
     else
     {
-        m_vphalState = MOS_New(
+        m_vpBase = MOS_New(
             VphalState,
             osInterface,
-            osDriverContext,
             eStatus);
     }
 
@@ -166,24 +164,21 @@ void VphalInterfacesXe_Hpm::InitPlatformKernelBinary(
     vp::VpPlatformInterface  *&vpPlatformInterface)
 {
 #if defined(ENABLE_KERNELS)
-    vpPlatformInterface->SetVpKernelBinary(
+    vpPlatformInterface->SetVpFCKernelBinary(
                         IGVPKRN_XE_HPG,
                         IGVPKRN_XE_HPG_SIZE,
                         IGVPKRN_XE_HPG_CMFCPATCH,
                         IGVPKRN_XE_HPG_CMFCPATCH_SIZE);
 #if !defined(_FULL_OPEN_SOURCE)
-    vpPlatformInterface->SetVpISAKernelBinary(
-                        IGVP3DLUT_GENERATION_XE_HPG,
-                        IGVP3DLUT_GENERATION_XE_HPG_SIZE,
-                        IGVPHVS_DENOISE_XE_HPG,
-                        IGVPHVS_DENOISE_XE_HPG_SIZE);  
+    vpPlatformInterface->AddVpIsaKernelEntryToList(IGVP3DLUT_GENERATION_XE_HPG, IGVP3DLUT_GENERATION_XE_HPG_SIZE);
+    vpPlatformInterface->AddVpIsaKernelEntryToList(IGVPHVS_DENOISE_XE_HPG, IGVPHVS_DENOISE_XE_HPG_SIZE);
 #endif
 #endif
 }
 
 static bool dg2RegisteredMhw =
-    MediaInterfacesFactory<MhwInterfaces>::
-    RegisterHal<MhwInterfacesDg2>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, MhwInterfaces>::
+    Register<MhwInterfacesDg2>((uint32_t)IGFX_DG2);
 
 #define PLATFORM_INTEL_DG2    22
 #define GENX_XEHP              11
@@ -247,7 +242,7 @@ MOS_STATUS MhwInterfacesDg2::Initialize(
         m_hcpInterface =
             MOS_New(Hcp, osInterface, m_miInterface, m_cpInterface, params.m_isDecode);
     }
-    if (params.Flags.m_vdboxAll)
+    if (params.Flags.m_vdboxAll || params.Flags.m_avp)
     {
         m_avpInterface =
             MOS_New(Avp, osInterface, m_miInterface, m_cpInterface, params.m_isDecode);
@@ -270,8 +265,8 @@ MOS_STATUS MhwInterfacesDg2::Initialize(
 
 #ifdef _MMC_SUPPORTED
 static bool dg2RegisteredMmd =
-    MediaInterfacesFactory<MmdDevice>::
-    RegisterHal<MmdDeviceXe_Hpm>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, MmdDevice>::
+    Register<MmdDeviceXe_Hpm>((uint32_t)IGFX_DG2);
 
 MOS_STATUS MmdDeviceXe_Hpm::Initialize(
     PMOS_INTERFACE osInterface,
@@ -312,6 +307,11 @@ MOS_STATUS MmdDeviceXe_Hpm::Initialize(
         mhwInterfaces->m_miInterface,
         mhwInterfaces->m_veboxInterface) != MOS_STATUS_SUCCESS)
     {
+        // Vebox/mi/cp interface will gove control to mmd device, will release will be in destructure func
+        // set as null to avoid double free in driver
+        mhwInterfaces->m_cpInterface = nullptr;
+        mhwInterfaces->m_miInterface = nullptr;
+        mhwInterfaces->m_veboxInterface = nullptr;
         MMD_FAILURE();
     }
 
@@ -334,8 +334,8 @@ MhwInterfaces* MmdDeviceXe_Hpm::CreateMhwInterface(
 #endif
 
 static bool dg2RegisteredMcpy =
-    MediaInterfacesFactory<McpyDevice>::
-    RegisterHal<McpyDeviceXe_Hpm>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, McpyDevice>::
+    Register<McpyDeviceXe_Hpm>((uint32_t)IGFX_DG2);
 
 MOS_STATUS McpyDeviceXe_Hpm::Initialize(
     PMOS_INTERFACE osInterface,
@@ -401,8 +401,8 @@ MhwInterfaces* McpyDeviceXe_Hpm::CreateMhwInterface(
 }
 
 static bool dg2RegisteredNv12ToP010 =
-    MediaInterfacesFactory<Nv12ToP010Device>::
-    RegisterHal<Nv12ToP010DeviceXe_Hpm>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, Nv12ToP010Device>::
+    Register<Nv12ToP010DeviceXe_Hpm>((uint32_t)IGFX_DG2);
 
 MOS_STATUS Nv12ToP010DeviceXe_Hpm::Initialize(
     PMOS_INTERFACE            osInterface)
@@ -413,8 +413,12 @@ MOS_STATUS Nv12ToP010DeviceXe_Hpm::Initialize(
 }
 
 static bool dg2RegisteredCodecHal =
-    MediaInterfacesFactory<CodechalDevice>::
-    RegisterHal<CodechalInterfacesXe_Hpm>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, CodechalDevice>::
+    Register<CodechalInterfacesXe_Hpm>((uint32_t)IGFX_DG2);
+
+static bool dg2RegisteredCodecHalNext =
+    MediaFactory<uint32_t, CodechalDeviceNext>::
+        Register<CodechalInterfacesNextXe_Hpm>((uint32_t)IGFX_DG2);
 
 static bool dg2RegisteredMhwNext =
     MediaFactory<uint32_t, MhwInterfacesNext>::
@@ -446,20 +450,19 @@ MOS_STATUS MhwInterfacesDg2_Next::Initialize(
     // MHW_CP and MHW_MI must always be created
     MOS_STATUS status;
     m_cpInterface = Create_MhwCpInterface(osInterface);
-    m_miInterface = MOS_New(Mi, m_cpInterface, osInterface);
-    {
-        MHW_MI_CHK_NULL(m_miInterface);
-        m_miItf = std::static_pointer_cast<mhw::mi::Itf>(m_miInterface->GetNewMiInterface());
-        //After dependency of legacy m_miInterface is cleanup, code above will be replaced with following codes.
-        //auto ptr = std::make_shared<mhw::mi::xe_xpm_base::Impl>(osInterface);
-        //ptr->SetCpInterface(m_cpInterface);
-        //m_miItf  = std::static_pointer_cast<mhw::mi::Itf>(ptr);
-    }
+    MHW_MI_CHK_NULL(m_cpInterface);
+    m_miInterface = std::make_shared<Mi>(m_cpInterface, osInterface);
+
+    auto ptr = std::make_shared<mhw::mi::xe_xpm_base::Impl>(osInterface);
+    m_miItf       = std::static_pointer_cast<mhw::mi::Itf>(ptr);
+    ptr->SetCpInterface(m_cpInterface, m_miItf);
 
     if (params.Flags.m_render)
     {
         m_renderInterface =
-            MOS_New(Render, m_miInterface, osInterface, gtSystemInfo, params.m_heapMode);
+            MOS_New(Render, m_miInterface.get(), osInterface, gtSystemInfo, params.m_heapMode);
+        auto renderPtr = std::make_shared<mhw::render::xe_hpg::Impl>(osInterface);
+        m_renderItf    = std::static_pointer_cast<mhw::render::Itf>(renderPtr);
     }
     if (params.Flags.m_stateHeap)
     {
@@ -477,13 +480,10 @@ MOS_STATUS MhwInterfacesDg2_Next::Initialize(
 
     if (params.Flags.m_vdboxAll || params.Flags.m_mfx)
     {
-        m_mfxInterface =
-            MOS_New(Mfx, osInterface, m_miInterface, m_cpInterface, params.m_isDecode);
+        m_mfxItf = nullptr;
     }
     if (params.Flags.m_vdboxAll || params.Flags.m_hcp)
     {
-        m_hcpInterface =
-            MOS_New(Hcp, osInterface, m_miInterface, m_cpInterface, params.m_isDecode);
         m_hcpItf = std::make_shared<mhw::vdbox::hcp::xe_xpm_base::xe_hpm::Impl>(osInterface);
     }
     if (params.Flags.m_vdboxAll)
@@ -493,13 +493,11 @@ MOS_STATUS MhwInterfacesDg2_Next::Initialize(
     }
     if (params.Flags.m_vdboxAll || params.Flags.m_huc)
     {
-        m_hucInterface = MOS_New(Huc, osInterface, m_miInterface, m_cpInterface);
         auto ptr = std::make_shared<mhw::vdbox::huc::xe_hpm::Impl>(osInterface, m_cpInterface);
         m_hucItf = std::static_pointer_cast<mhw::vdbox::huc::Itf>(ptr);
     }
     if (params.Flags.m_vdboxAll || params.Flags.m_vdenc)
     {
-        m_vdencInterface = MOS_New(Vdenc, osInterface);
         auto ptr = std::make_shared<mhw::vdbox::vdenc::xe_hpm::Impl>(osInterface);
         m_vdencItf = std::static_pointer_cast<mhw::vdbox::vdenc::Itf>(ptr);
     }
@@ -518,7 +516,13 @@ MOS_STATUS MhwInterfacesDg2_Next::Initialize(
 void MhwInterfacesDg2_Next::Destroy()
 {
     MhwInterfacesNext::Destroy();
+    MOS_Delete(m_sfcInterface);
+    MOS_Delete(m_veboxInterface);
     MOS_Delete(m_bltInterface);
+    if (m_renderInterface != nullptr)
+    {
+        MOS_Delete(m_renderInterface);
+    }
 }
 
 MOS_STATUS CodechalInterfacesXe_Hpm::Initialize(
@@ -535,35 +539,28 @@ MOS_STATUS CodechalInterfacesXe_Hpm::Initialize(
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
-    bool mdfSupported = true;
-#if (_DEBUG || _RELEASE_INTERNAL)
-    MOS_USER_FEATURE_VALUE_DATA     UserFeatureData;
-    MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
-    MOS_UserFeature_ReadValue_ID(
-        nullptr,
-        __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_MDF_DISABLE_ID,
-        &UserFeatureData,
-        osInterface->pOsContext);
-    mdfSupported = (UserFeatureData.i32Data == 1) ? false : true;
-#endif // (_DEBUG || _RELEASE_INTERNAL)
-
     PCODECHAL_STANDARD_INFO info = ((PCODECHAL_STANDARD_INFO)standardInfo);
     CODECHAL_FUNCTION CodecFunction = info->CodecFunction;
 
     bool disableScalability = false;
     PLATFORM platform = {};
     osInterface->pfnGetPlatform(osInterface, &platform);
-    if((platform.usDeviceID == 0x56C0)
-        || (platform.usDeviceID == 0x56C1))
+    if((platform.usDeviceID >= 0x56C0)
+        && (platform.usDeviceID <= 0x56CF))
     {
         disableScalability = true;
     }
 
     CodechalHwInterface    *hwInterface    = nullptr;
     CodechalDebugInterface *debugInterface = nullptr;
-
+    CodechalHwInterfaceNext    *hwInterface_next    = nullptr;
+    
     if (CodecHalIsDecode(CodecFunction))
     {
+        if(osInterface->bHcpDecScalabilityMode == MOS_SCALABILITY_ENABLE_MODE_USER_FORCE)
+        {
+            disableScalability = false;
+        }
         CreateCodecHalInterface(mhwInterfaces, hwInterface, debugInterface, osInterface, CodecFunction, disableScalability);
 
     #ifdef _MPEG2_DECODE_SUPPORTED
@@ -725,11 +722,13 @@ MOS_STATUS CodechalInterfacesXe_Hpm::Initialize(
 #if defined (_AV1_ENCODE_VDENC_SUPPORTED)
         if (info->Mode == codechalEncodeModeAv1)
         {
-            CreateCodecHalInterface(mhwInterfaces, mhwInterfacesNext, hwInterface, debugInterface, osInterface, CodecFunction, disableScalability);
+            CreateCodecHalInterface(mhwInterfaces, mhwInterfacesNext, hwInterface_next, debugInterface, osInterface, CodecFunction, disableScalability);
 
             if (CodecHalUsesVdencEngine(info->CodecFunction))
             {
-                m_codechalDevice = MOS_New(Encode::Av1Vdenc, hwInterface, debugInterface);
+                m_codechalDevice = MOS_New(Encode::Av1Vdenc, hwInterface_next, debugInterface);
+                MOS_Delete(hwInterface);
+                hwInterface = nullptr;
                 CODECHAL_PUBLIC_CHK_NULL_RETURN(m_codechalDevice);
                 RETURN_STATUS_WITH_DELETE(MOS_STATUS_SUCCESS);
             }
@@ -743,11 +742,11 @@ MOS_STATUS CodechalInterfacesXe_Hpm::Initialize(
 #if defined (_HEVC_ENCODE_VDENC_SUPPORTED)
         if (info->Mode == CODECHAL_ENCODE_MODE_HEVC)
         {
-            CreateCodecHalInterface(mhwInterfaces, mhwInterfacesNext, hwInterface, debugInterface, osInterface, CodecFunction, disableScalability);
+            CreateCodecHalInterface(mhwInterfaces, mhwInterfacesNext, hwInterface_next, debugInterface, osInterface, CodecFunction, disableScalability);
 
             if (CodecHalUsesVdencEngine(info->CodecFunction))
             {
-                m_codechalDevice = MOS_New(Encode::HevcVdenc, hwInterface, debugInterface);
+                m_codechalDevice = MOS_New(Encode::HevcVdenc, hwInterface_next, debugInterface);
                 if (m_codechalDevice == nullptr)
                 {
                     CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
@@ -777,10 +776,121 @@ MOS_STATUS CodechalInterfacesXe_Hpm::Initialize(
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS CodechalInterfacesNextXe_Hpm::Initialize(
+    void *standardInfo,
+    void *settings,
+    MhwInterfacesNext *mhwInterfaces,
+    PMOS_INTERFACE osInterface)
+{
+     bool mdfSupported = true;
+#if (_DEBUG || _RELEASE_INTERNAL)
+    MOS_USER_FEATURE_VALUE_DATA UserFeatureData;
+    MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
+    MOS_UserFeature_ReadValue_ID(
+        nullptr,
+        __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_MDF_DISABLE_ID,
+        &UserFeatureData,
+        osInterface->pOsContext);
+    mdfSupported = (UserFeatureData.i32Data == 1) ? false : true;
+#endif  // (_DEBUG || _RELEASE_INTERNAL)
+    if (standardInfo == nullptr ||
+        mhwInterfaces == nullptr ||
+        osInterface == nullptr)
+    {
+        CODECHAL_PUBLIC_ASSERTMESSAGE("CodecHal device is not valid!");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
+    // This part should be moved back to media_intefaces.cpp for softlet build
+    PCODECHAL_STANDARD_INFO info          = ((PCODECHAL_STANDARD_INFO)standardInfo);
+    CODECHAL_FUNCTION       CodecFunction = info->CodecFunction;
+
+    if (mhwInterfaces == nullptr)
+    {
+        CODECHAL_PUBLIC_ASSERTMESSAGE("mhwInterfaces is not valid!");
+        return MOS_STATUS_NO_SPACE;
+    }
+
+    bool disableScalability = false;
+#ifdef _VP9_ENCODE_VDENC_SUPPORTED
+    if (info->Mode == CODECHAL_ENCODE_MODE_VP9)
+        disableScalability = true;
+#endif
+    CodechalHwInterfaceNext *hwInterface = MOS_New(Hw, osInterface, CodecFunction, mhwInterfaces, disableScalability);
+
+    if (hwInterface == nullptr)
+    {
+        CODECHAL_PUBLIC_ASSERTMESSAGE("hwInterface is not valid!");
+        return MOS_STATUS_NO_SPACE;
+    }
+
+#if USE_CODECHAL_DEBUG_TOOL
+    CodechalDebugInterface *debugInterface = MOS_New(CodechalDebugInterface);
+    if (debugInterface == nullptr)
+    {
+        MOS_Delete(hwInterface);
+        mhwInterfaces->SetDestroyState(true);
+        CODECHAL_PUBLIC_ASSERTMESSAGE("debugInterface is not valid!");
+        return MOS_STATUS_NO_SPACE;
+    }
+    if (debugInterface->Initialize(hwInterface, CodecFunction) != MOS_STATUS_SUCCESS)
+    {
+        MOS_Delete(hwInterface);
+        mhwInterfaces->SetDestroyState(true);
+        MOS_Delete(debugInterface);
+        CODECHAL_PUBLIC_ASSERTMESSAGE("Debug interface creation failed!");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+#else
+    CodechalDebugInterface *debugInterface = nullptr;
+#endif  // USE_CODECHAL_DEBUG_TOOL
+
+    if (CodecHalIsDecode(CodecFunction))
+    {
+        CODECHAL_PUBLIC_ASSERTMESSAGE("Decode allocation failed, Decoder with CodechalDeviceNext is not supported!");
+        return MOS_STATUS_INVALID_PARAMETER;
+ 
+    }
+    else if (CodecHalIsEncode(CodecFunction))
+    {
+        CodechalEncoderState *encoder = nullptr;
+
+#if defined (_AV1_ENCODE_VDENC_SUPPORTED)
+        if (info->Mode == codechalEncodeModeAv1)
+        {
+            //TODO, use create 
+            if (CodecHalUsesVdencEngine(info->CodecFunction))
+            {
+                m_codechalDevice = MOS_New(Encode::Av1Vdenc, hwInterface, debugInterface);
+                CODECHAL_PUBLIC_CHK_NULL_RETURN(m_codechalDevice);
+                return MOS_STATUS_SUCCESS;
+            }
+            else
+            {
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
+        }
+        else
+#endif
+        {
+            CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported encode function requested.");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+    }
+    else
+    {
+        CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported codec function requested.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 #ifdef _MEDIA_RESERVED
 static bool dg2RegisteredCMHal =
-    MediaInterfacesFactory<CMHalDevice>::
-    RegisterHal<CMHalInterfacesXe_Hpm>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, CMHalDevice>::
+    Register<CMHalInterfacesXe_Hpm>((uint32_t)IGFX_DG2);
 MOS_STATUS CMHalInterfacesXe_Hpm::Initialize(CM_HAL_STATE *pCmState)
 {
     if (pCmState == nullptr)
@@ -814,41 +924,9 @@ MOS_STATUS CMHalInterfacesXe_Hpm::Initialize(CM_HAL_STATE *pCmState)
 }
 #endif
 
-static bool dg2RegisteredMosUtil =
-    MediaInterfacesFactory<MosUtilDevice>::
-    RegisterHal<MosUtilDeviceXe_Hpm>((uint32_t)IGFX_DG2);
-
-MOS_STATUS MosUtilDeviceXe_Hpm::Initialize()
-{
-#define MOSUTIL_FAILURE()                                       \
-{                                                           \
-    if (device != nullptr)                                  \
-    {                                                       \
-        delete device;                                      \
-    }                                                       \
-    return MOS_STATUS_NO_SPACE;                             \
-}
-
-    MosUtil *device = nullptr;
-
-    device = MOS_New(MosUtil);
-
-    if (device == nullptr)
-    {
-        MOSUTIL_FAILURE();
-    }
-
-    if (device->Initialize() != MOS_STATUS_SUCCESS)
-    {
-        MOSUTIL_FAILURE();
-    }
-
-    m_mosUtilDevice = device;
-    return MOS_STATUS_SUCCESS;
-}
 static bool dg2RegisteredRenderHal =
-    MediaInterfacesFactory<RenderHalDevice>::
-    RegisterHal<RenderHalInterfacesXe_Hpg>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, RenderHalDevice>::
+    Register<RenderHalInterfacesXe_Hpg>((uint32_t)IGFX_DG2);
 MOS_STATUS RenderHalInterfacesXe_Hpg::Initialize()
 {
     m_renderhalDevice = MOS_New(XRenderHal);
@@ -860,8 +938,8 @@ MOS_STATUS RenderHalInterfacesXe_Hpg::Initialize()
     return MOS_STATUS_SUCCESS;
 }
 static bool dg2RegisteredDecodeHistogram =
-MediaInterfacesFactory<DecodeHistogramDevice>::
-RegisterHal<DecodeHistogramDeviceXe_Hpm>((uint32_t)IGFX_DG2);
+MediaFactory<uint32_t, DecodeHistogramDevice>::
+Register<DecodeHistogramDeviceXe_Hpm>((uint32_t)IGFX_DG2);
 MOS_STATUS DecodeHistogramDeviceXe_Hpm::Initialize(
     CodechalHwInterface       *hwInterface,
     PMOS_INTERFACE            osInterface)
@@ -877,7 +955,7 @@ MOS_STATUS DecodeHistogramDeviceXe_Hpm::Initialize(
 }
 
 static bool dg2RegisteredHwInfo =
-    MediaInterfacesFactory<MediaInterfacesHwInfoDevice>::RegisterHal<MediaInterfacesHwInfoDeviceDg2>((uint32_t)IGFX_DG2);
+    MediaFactory<uint32_t, MediaInterfacesHwInfoDevice>::Register<MediaInterfacesHwInfoDeviceDg2>((uint32_t)IGFX_DG2);
 
 #define IP_VERSION_XE_HPM      0x1207
 
@@ -888,7 +966,7 @@ MOS_STATUS MediaInterfacesHwInfoDeviceDg2::RefreshRevId(PLATFORM &platform, MEDI
         CODECHAL_PUBLIC_ASSERTMESSAGE("waTable is null!");
         return MOS_STATUS_INVALID_PARAMETER;
     }
-    if (!MEDIA_IS_WA(waTable, WaEnableOnlyASteppingFeatures) && platform.usRevId == 0)
+    if (!MEDIA_IS_WA(waTable, WaEnableOnlyASteppingFeatures) && (platform.usRevId == 0 || platform.usRevId == 1))
     {
         platform.usRevId = 4;
     }
@@ -902,7 +980,7 @@ MOS_STATUS MediaInterfacesHwInfoDeviceDg2::Initialize(PLATFORM platform)
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces          *mhwInterfaces,
+MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces *mhwInterfaces,
                                                              CodechalHwInterface    *&pHwInterface,
                                                              CodechalDebugInterface *&pDebugInterface,
                                                              PMOS_INTERFACE         osInterface,
@@ -910,14 +988,25 @@ MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces
                                                              bool                   disableScalability)
 {
     pHwInterface = MOS_New(Hw, osInterface, CodecFunction, mhwInterfaces, disableScalability);
-
     if (pHwInterface == nullptr)
     {
         CODECHAL_PUBLIC_ASSERTMESSAGE("hwInterface is not valid!");
         return MOS_STATUS_NO_SPACE;
     }
+    pHwInterface->m_hwInterfaceNext                            = MOS_New(CodechalHwInterfaceNext, osInterface, pHwInterface->IsDisableScalability());
+    if (pHwInterface->m_hwInterfaceNext == nullptr)
+    {
+        MOS_Delete(pHwInterface);
+        mhwInterfaces->SetDestroyState(true);
+        CODECHAL_PUBLIC_ASSERTMESSAGE("hwInterfaceNext is not valid!");
+        return MOS_STATUS_NO_SPACE;
+    }
+    pHwInterface->m_hwInterfaceNext->pfnCreateDecodeSinglePipe = decode::DecodeScalabilitySinglePipe::CreateDecodeSinglePipe;
+    pHwInterface->m_hwInterfaceNext->pfnCreateDecodeMultiPipe  = decode::DecodeScalabilityMultiPipe::CreateDecodeMultiPipe;
+    pHwInterface->m_hwInterfaceNext->SetMediaSfcInterface(pHwInterface->GetMediaSfcInterface());
+
 #if USE_CODECHAL_DEBUG_TOOL
-    pDebugInterface = MOS_New(CodechalDebugInterfaceXe_Hpm);
+    pDebugInterface = MOS_New(CodechalDebugInterface);
     if (pDebugInterface == nullptr)
     {
         MOS_Delete(pHwInterface);
@@ -937,19 +1026,19 @@ MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces          *mhwInterfaces,
-                                                             MhwInterfacesNext      *&pMhwInterfacesNext,
-                                                             CodechalHwInterface    *&pHwInterface,
-                                                             CodechalDebugInterface *&pDebugInterface,
-                                                             PMOS_INTERFACE         osInterface,
-                                                             CODECHAL_FUNCTION      CodecFunction,
-                                                             bool                   disableScalability)
+MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces *mhwInterfaces,
+    MhwInterfacesNext                                                     *&pMhwInterfacesNext,
+    CodechalHwInterfaceNext                                               *&pHwInterface,
+    CodechalDebugInterface                                                *&pDebugInterface,
+    PMOS_INTERFACE                                                          osInterface,
+    CODECHAL_FUNCTION                                                       CodecFunction,
+    bool                                                                    disableScalability)
 {
     if (mhwInterfaces != nullptr)
     {
-        if (((MhwInterfacesDg2*)mhwInterfaces)->m_avpInterface != nullptr)
+        if (((MhwInterfacesDg2 *)mhwInterfaces)->m_avpInterface != nullptr)
         {
-            MOS_Delete(((MhwInterfacesDg2*)mhwInterfaces)->m_avpInterface);
+            MOS_Delete(((MhwInterfacesDg2 *)mhwInterfaces)->m_avpInterface);
         }
         mhwInterfaces->Destroy();
     }
@@ -957,13 +1046,13 @@ MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces
     pMhwInterfacesNext = nullptr;
     MhwInterfacesNext::CreateParams params;
     MOS_ZeroMemory(&params, sizeof(params));
-    params.Flags.m_render = true;
-    params.Flags.m_sfc = true;
+    params.Flags.m_render   = true;
+    params.Flags.m_sfc      = true;
     params.Flags.m_vdboxAll = true;
-    params.Flags.m_vebox = true;
-    params.m_heapMode = (uint8_t)2;
-    params.m_isDecode = CodecHalIsDecode(CodecFunction);
-    pMhwInterfacesNext = MhwInterfacesNext::CreateFactory(params, osInterface);
+    params.Flags.m_vebox    = true;
+    params.m_heapMode       = (uint8_t)2;
+    params.m_isDecode       = CodecHalIsDecode(CodecFunction);
+    pMhwInterfacesNext      = MhwInterfacesNext::CreateFactory(params, osInterface);
 
     if (pMhwInterfacesNext == nullptr)
     {
@@ -971,7 +1060,7 @@ MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces
         return MOS_STATUS_NO_SPACE;
     }
 
-    pHwInterface = MOS_New(Hw, osInterface, CodecFunction, pMhwInterfacesNext, disableScalability);
+    pHwInterface = MOS_New(CodechalHwInterfaceNextXe_Hpm, osInterface, CodecFunction, pMhwInterfacesNext, disableScalability);
 
     if (pHwInterface == nullptr)
     {
@@ -979,7 +1068,7 @@ MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces
         return MOS_STATUS_NO_SPACE;
     }
 #if USE_CODECHAL_DEBUG_TOOL
-    pDebugInterface = MOS_New(CodechalDebugInterfaceXe_Hpm);
+    pDebugInterface = MOS_New(CodechalDebugInterface);
     if (pDebugInterface == nullptr)
     {
         MOS_Delete(pHwInterface);
@@ -995,6 +1084,6 @@ MOS_STATUS CodechalInterfacesXe_Hpm::CreateCodecHalInterface(MhwInterfaces
         CODECHAL_PUBLIC_ASSERTMESSAGE("Debug interface creation failed!");
         return MOS_STATUS_INVALID_PARAMETER;
     }
-#endif // USE_CODECHAL_DEBUG_TOOL
+#endif  // USE_CODECHAL_DEBUG_TOOL
     return MOS_STATUS_SUCCESS;
 }
