@@ -53,11 +53,11 @@ namespace encode
     class Av1VdencPktXe_M_Base : public Av1VdencPkt
     {
     public:
-        Av1VdencPktXe_M_Base(MediaPipeline *pipeline, MediaTask *task, CodechalHwInterface *hwInterface) :
+        Av1VdencPktXe_M_Base(MediaPipeline *pipeline, MediaTask *task, CodechalHwInterfaceNext *hwInterface) :
             Av1VdencPkt(pipeline, task, hwInterface)
         {
-            auto hwInterfaceG12 = dynamic_cast<CodechalHwInterfaceG12 *>(m_hwInterface);
-            ENCODE_CHK_NULL_NO_STATUS_RETURN(hwInterfaceG12);
+            //auto hwInterfaceG12 = dynamic_cast<CodechalHwInterfaceG12 *>(m_hwInterface);
+            //ENCODE_CHK_NULL_NO_STATUS_RETURN(hwInterfaceG12);
         }
 
         virtual ~Av1VdencPktXe_M_Base() {}
@@ -103,8 +103,6 @@ namespace encode
         MOS_STATUS RegisterPostCdef();
         MOS_STATUS UpdateUserFeatureKey(PMOS_SURFACE surface);
 
-        virtual MOS_STATUS UpdateStatusReport(uint32_t srType, MOS_COMMAND_BUFFER *cmdBuffer) override;
-
         MHW_SETPAR_DECL_HDR(AVP_IND_OBJ_BASE_ADDR_STATE);
 
         MHW_SETPAR_DECL_HDR(AVP_PIC_STATE);
@@ -122,12 +120,11 @@ namespace encode
 #endif  // USE_CODECHAL_DEBUG_TOOL
 
         bool  m_userFeatureUpdated_post_cdef = false;  //!< Inidate if mmc user feature key for post cdef is updated
-        AtomicScratchBufferAv1 m_atomicScratchBuf = {}; //!< Stores atomic operands and result
 
     private:
         uint16_t m_tileColStartSb[64];  //!< tile column start SB
         uint16_t m_tileRowStartSb[64];  //!< tile row start SB
-    MEDIA_CLASS_DEFINE_END(Av1VdencPktXe_M_Base)
+    MEDIA_CLASS_DEFINE_END(encode__Av1VdencPktXe_M_Base)
     };
 
 }
