@@ -27,10 +27,11 @@
 #include "vp_feature_manager_xe_xpm.h"
 #include "vp_platform_interface_xe_xpm.h"
 #include "vp_vebox_cmd_packet_xe_xpm.h"
-#include "media_user_settings_mgr_g12.h"
 #include "vp_render_sfc_xe_xpm_base.h"
 #include "vp_render_ief.h"
 #include "vp_kernel_config_m12_base.h"
+#include "vp_scalability_multipipe.h"
+#include "vp_scalability_singlepipe.h"
 
 using namespace vp;
 
@@ -106,7 +107,7 @@ MOS_STATUS VpPlatformInterfaceXe_Xpm::VeboxQueryStatLayout(VEBOX_STAT_QUERY_TYPE
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-    VPHAL_RENDER_CHK_NULL_RETURN(pQuery);
+    VP_RENDER_CHK_NULL_RETURN(pQuery);
 
     switch (queryType)
     {
@@ -127,7 +128,7 @@ MOS_STATUS VpPlatformInterfaceXe_Xpm::VeboxQueryStatLayout(VEBOX_STAT_QUERY_TYPE
         break;
 
     default:
-        VPHAL_RENDER_ASSERTMESSAGE("Vebox Statistics Layout Query, type ('%d') is not implemented.", queryType);
+        VP_RENDER_ASSERTMESSAGE("Vebox Statistics Layout Query, type ('%d') is not implemented.", queryType);
         eStatus = MOS_STATUS_UNKNOWN;
         break;
     }
@@ -209,15 +210,25 @@ MOS_STATUS VpPlatformInterfaceXe_Xpm::GetVeboxHeapInfo(
     return eStatus;
 }
 
-bool VpPlatformInterfaceXe_Xpm::IsVeboxScalabilitywith4K(
+bool VpPlatformInterfaceXe_Xpm::IsVeboxScalabilityWith4KNotSupported(
         VP_MHWINTERFACE          vpMhwInterface)
 {
-    if (vpMhwInterface.m_veboxInterface)
+    if (vpMhwInterface.m_veboxInterface && !(vpMhwInterface.m_veboxInterface->m_veboxScalabilitywith4K))
     {
-        return vpMhwInterface.m_veboxInterface->m_veboxScalabilitywith4K;
+        return true;
     }
     else
     {
         return false;
     }
 }
+
+MOS_STATUS VpPlatformInterfaceXe_Xpm::ConfigureVpScalability(VP_MHWINTERFACE &vpMhwInterface)
+{
+    VP_FUNC_CALL();
+
+    vpMhwInterface.pfnCreateSinglePipe = vp::VpScalabilitySinglePipe::CreateSinglePipe;
+    vpMhwInterface.pfnCreateMultiPipe  = vp::VpScalabilityMultiPipe::CreateMultiPipe;
+
+    return MOS_STATUS_SUCCESS;
+}
