@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020, Intel Corporation
+* Copyright (c) 2020-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -119,13 +119,9 @@ namespace decode {
          * */
         DECODE_FUNC_CALL();
         DECODE_CHK_NULL(m_avcPicParams);
+        DECODE_CHK_NULL(m_avcSliceParams);
 
-        if(m_avcPicParams->seq_fields.chroma_format_idc > avcChromaFormat420
-            || m_avcPicParams->bit_depth_luma_minus8 > 0
-            || m_avcPicParams->bit_depth_chroma_minus8 > 0)
-        {
-            DECODE_ASSERTMESSAGE("Only 4:2:0 8bit is supported!");
-        }
+        DECODE_CHK_STATUS(CheckBitDepthAndChromaSampling());
 
         if(m_avcPicParams->seq_fields.chroma_format_idc != 3
             && m_avcPicParams->seq_fields.residual_colour_transform_flag)
@@ -227,6 +223,28 @@ namespace decode {
             DECODE_ASSERTMESSAGE("Conflict with H264 Spec! weighted_bipred_idc is out of range");
         }
 
+        if (!m_shortFormatInUse)
+        {
+            for (uint32_t slcIdx = 0; slcIdx < m_numSlices; slcIdx++)
+            {
+                PCODEC_AVC_SLICE_PARAMS slc = m_avcSliceParams + slcIdx;
+                if(m_avcPicParams->pic_fields.field_pic_flag == 0)
+                {
+                    if(slc->num_ref_idx_l0_active_minus1 > 15)
+                    {
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
+                }
+                else if(m_avcPicParams->pic_fields.field_pic_flag == 1)
+                {
+                    if(slc->num_ref_idx_l0_active_minus1 > 31)
+                    {
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
+                }
+            }
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -418,6 +436,21 @@ namespace decode {
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS AvcBasicFeature::CheckBitDepthAndChromaSampling()
+    {
+        DECODE_FUNC_CALL();
+        DECODE_CHK_NULL(m_avcPicParams);
+
+        if (m_avcPicParams->seq_fields.chroma_format_idc > avcChromaFormat420
+            || m_avcPicParams->bit_depth_luma_minus8 > 0
+            || m_avcPicParams->bit_depth_chroma_minus8 > 0)
+        {
+            DECODE_ASSERTMESSAGE("Only 4:2:0 8bit is supported!");
+        }
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS AvcBasicFeature::SetRequiredBitstreamSize(uint32_t requiredSize)
     {
         DECODE_FUNC_CALL();
