@@ -43,7 +43,7 @@
 namespace decode {
 
 DecodePipeline::DecodePipeline(
-    CodechalHwInterface *hwInterface,
+    CodechalHwInterfaceNext *hwInterface,
     CodechalDebugInterface *debugInterface):
     MediaPipeline(hwInterface ? hwInterface->GetOsInterface() : nullptr)
 {
@@ -55,6 +55,13 @@ DecodePipeline::DecodePipeline(
 
     m_singleTaskPhaseSupported =
         ReadUserFeature(m_userSettingPtr, "Decode Single Task Phase Enable", MediaUserSetting::Group::Sequence).Get<bool>();
+
+    m_pCodechalOcaDumper = MOS_New(CodechalOcaDumper);
+    if (!m_pCodechalOcaDumper)
+    {
+        MOS_OS_ASSERTMESSAGE("Initialize CodechalOcaDumper failed!");
+    }
+
     CODECHAL_DEBUG_TOOL(
         DECODE_ASSERT(debugInterface != nullptr);
         m_debugInterface = debugInterface;
@@ -146,7 +153,9 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
     DECODE_CHK_NULL(settings);
 
     DECODE_CHK_STATUS(MediaPipeline::InitPlatform());
-    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopy());
+    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopyWrapper());
+    DECODE_CHK_NULL(m_mediaCopyWrapper);
+    m_mediaCopyWrapper->CreateMediaCopyState();
 
     DECODE_CHK_NULL(m_waTable);
 
@@ -154,6 +163,16 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
     DECODE_CHK_NULL(m_hwInterface);
     DECODE_CHK_STATUS(m_hwInterface->Initialize(codecSettings));
 
+    if (m_mediaCopyWrapper->MediaCopyStateIsNull())
+    {
+        m_mediaCopyWrapper->SetMediaCopyState(m_hwInterface->CreateMediaCopy(m_osInterface));
+    }
+
+#if USE_CODECHAL_DEBUG_TOOL
+    DECODE_CHK_NULL(m_debugInterface);
+    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopyWrapper->GetMediaCopyState()));
+#endif
+
     m_mediaContext = MOS_New(MediaContext, scalabilityDecoder, m_hwInterface, m_osInterface);
     DECODE_CHK_NULL(m_mediaContext);
 
@@ -168,7 +187,7 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
 
     DECODE_CHK_STATUS(CreateStatusReport());
 
-    m_decodecp = Create_DecodeCpInterface(codecSettings, m_hwInterface);
+    m_decodecp = Create_DecodeCpInterface(codecSettings, m_hwInterface->GetCpInterface(), m_hwInterface->GetOsInterface());
     if (m_decodecp)
     {
         m_decodecp->RegisterParams(codecSettings);
@@ -392,7 +411,7 @@ MOS_STATUS DecodePipeline::DumpOutput(const DecodeStatusReportData& reportData)
 {
     DECODE_FUNC_CALL();
 
-    if (m_debugInterface->DumpIsEnabled(CodechalDbgAttr::attrDecodeOutputSurface))
+    if (m_debugInterface->DumpIsEnabled(CodechalDbgAttr::attrDecodeOutputSurface) || MOS_TraceKeyEnabled(TR_KEY_DECODE_DSTYUV))
     {
         MOS_SURFACE dstSurface;
         MOS_ZeroMemory(&dstSurface, sizeof(dstSurface));
@@ -419,11 +438,8 @@ MOS_STATUS DecodePipeline::DumpOutput(const DecodeStatusReportData& reportData)
 
             if (!Mos_ResourceIsNull(&sfcDstSurface.OsResource))
             {
-                DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&sfcDstSurface));
-                DECODE_CHK_STATUS(m_debugInterface->DumpYUVSurface(
-                    &sfcDstSurface, CodechalDbgAttr::attrSfcOutputSurface, "SfcDstSurf"));
-
 #if (_DEBUG || _RELEASE_INTERNAL)
+                DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&sfcDstSurface));
                 //rgb format read from reg key
                 uint32_t sfcOutputRgbFormatFlag =
                     ReadUserFeature(m_userSettingPtr, "Decode SFC RGB Format Output", MediaUserSetting::Group::Sequence).Get<uint32_t>();
@@ -432,6 +448,11 @@ MOS_STATUS DecodePipeline::DumpOutput(const DecodeStatusReportData& reportData)
                     DECODE_CHK_STATUS(m_debugInterface->DumpRgbDataOnYUVSurface(
                         &sfcDstSurface, CodechalDbgAttr::attrSfcOutputSurface, "SfcDstRgbSurf"));
                 }
+                else
+                {
+                    DECODE_CHK_STATUS(m_debugInterface->DumpYUVSurface(
+                        &sfcDstSurface, CodechalDbgAttr::attrSfcOutputSurface, "SfcDstSurf"));
+                }
 #endif
             }
         }
@@ -516,7 +537,7 @@ MOS_STATUS DecodePipeline::TraceDataDumpOutput(const DecodeStatusReportData &rep
             m_tempOutputSurf->UPlaneOffset.iSurfaceOffset,
             m_tempOutputSurf->VPlaneOffset.iSurfaceOffset,
         };
-        MOS_TraceEvent(EVENT_DECODE_DST_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0); 
+        MOS_TraceEvent(EVENT_DECODE_DUMPINFO_DST, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0); 
 
         ResourceAutoLock resLock(m_allocator, &m_tempOutputSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
@@ -548,7 +569,7 @@ MOS_STATUS DecodePipeline::TraceDataDump2ndLevelBB(PMHW_BATCH_BUFFER batchBuffer
 
     MOS_TraceDataDump(
         "Decode_2ndLevelCmdBB",
-        0,
+        m_osInterface->pfnGetGpuContext(m_osInterface),
         pData,
         batchBuffer->iLastCurrent);
 
@@ -669,7 +690,7 @@ MOS_STATUS DecodePipeline::StatusCheck()
 #endif
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-        if (MOS_TraceKeyEnabled(TR_KEY_DECODE_DSTYUV))
+        if (MOS_TraceKeyEnabled(TR_KEY_DECODE_DSTYUV_IN_TRACE))
         {
             const DecodeStatusReportData &reportETWData = statusReport->GetReportData(m_statusCheckCount);
             DECODE_CHK_STATUS(TraceDataDumpOutput(reportETWData));
