@@ -65,7 +65,7 @@ class Av1BasicFeature : public EncodeBasicFeature, public mhw::vdbox::vdenc::Itf
 {
 public:
     Av1BasicFeature(EncodeAllocator * allocator,
-                     CodechalHwInterface *hwInterface,
+                     CodechalHwInterfaceNext *hwInterface,
                      TrackedBuffer *trackedBuf,
                      RecycleResource *recycleBuf,
                      void *constSettings) :
@@ -217,7 +217,7 @@ protected:
     uint32_t m_appHdrSize                = 0;
     uint32_t m_appHdrSizeExcludeFrameHdr = 0;
 
-MEDIA_CLASS_DEFINE_END(Av1BasicFeature)
+MEDIA_CLASS_DEFINE_END(encode__Av1BasicFeature)
 };
 
 }  // namespace encode
