@@ -27,8 +27,6 @@
 
 #include "encode_huc_brc_update_packet.h"
 #include "codechal_debug.h"
-#include "mhw_vdbox_hcp_g12_X.h"
-#include "codechal_vdenc_hevc_g12.h"
 #include "encode_hevc_vdenc_weighted_prediction.h"
 #include "encode_hevc_brc.h"
 #include "encode_hevc_vdenc_scc.h"
@@ -40,7 +38,7 @@ namespace encode
     MOS_STATUS HucBrcUpdatePkt::Init()
     {
         ENCODE_FUNC_CALL();
-        HUC_CHK_STATUS_RETURN(EncodeHucBasic::Init());
+        HUC_CHK_STATUS_RETURN(EncodeHucPkt::Init());
 
         ENCODE_CHK_NULL_RETURN(m_pipeline);
         m_allocator = m_pipeline->GetEncodeAllocator();
@@ -64,15 +62,12 @@ namespace encode
         uint32_t hucPatchListSize = 0;
         MHW_VDBOX_STATE_CMDSIZE_PARAMS stateCmdSizeParams;
 
-        if (m_hwInterface->m_hwInterfaceNext)
-        {
-            stateCmdSizeParams.uNumStoreDataImm = 2;
-            stateCmdSizeParams.uNumStoreReg     = 4;
-            stateCmdSizeParams.uNumMfxWait      = 3;
-            stateCmdSizeParams.uNumAddConBBEnd  = 1;
-            ENCODE_CHK_STATUS_RETURN(m_hwInterface->m_hwInterfaceNext->GetHucStateCommandSize(
-                m_basicFeature->m_mode, (uint32_t*)&hucCommandsSize, (uint32_t*)&hucPatchListSize, &stateCmdSizeParams));
-        }
+        stateCmdSizeParams.uNumStoreDataImm = 2;
+        stateCmdSizeParams.uNumStoreReg     = 4;
+        stateCmdSizeParams.uNumMfxWait      = 3;
+        stateCmdSizeParams.uNumAddConBBEnd  = 1;
+        ENCODE_CHK_STATUS_RETURN(m_hwInterface->GetHucStateCommandSize(
+            m_basicFeature->m_mode, (uint32_t*)&hucCommandsSize, (uint32_t*)&hucPatchListSize, &stateCmdSizeParams));
 
         commandBufferSize = hucCommandsSize;
         requestedPatchListSize = osInterface->bUsesPatchList ? hucPatchListSize : 0;
@@ -101,7 +96,7 @@ namespace encode
     MOS_STATUS HucBrcUpdatePkt::AllocateResources()
     {
         ENCODE_FUNC_CALL();
-        ENCODE_CHK_STATUS_RETURN(EncodeHucBasic::AllocateResources());
+        ENCODE_CHK_STATUS_RETURN(EncodeHucPkt::AllocateResources());
 
         MOS_ALLOC_GFXRES_PARAMS allocParamsForBufferLinear;
         MOS_ZeroMemory(&allocParamsForBufferLinear, sizeof(MOS_ALLOC_GFXRES_PARAMS));
@@ -116,6 +111,7 @@ namespace encode
         // Data (1024 bytes) for ref2
         allocParamsForBufferLinear.dwBytes = CODECHAL_PAGE_SIZE * 4;
         allocParamsForBufferLinear.pBufName = "Data from Pictures Buffer for Weighted Prediction";
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_NOCACHE;
         MOS_RESOURCE *allocatedbuffer       = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
         ENCODE_CHK_NULL_RETURN(allocatedbuffer);
         m_dataFromPicsBuffer = *allocatedbuffer;
@@ -125,6 +121,7 @@ namespace encode
             // Const Data buffer
             allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_vdencBrcConstDataBufferSize, CODECHAL_PAGE_SIZE);
             allocParamsForBufferLinear.pBufName = "VDENC BRC Const Data Buffer";
+            allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_WRITE;
             allocatedbuffer       = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
             ENCODE_CHK_NULL_RETURN(allocatedbuffer);
             m_vdencBrcConstDataBuffer[k] = *allocatedbuffer;
@@ -134,6 +131,7 @@ namespace encode
                 // VDEnc read batch buffer (input for HuC FW)
                 allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_hwInterface->m_vdencReadBatchBufferSize, CODECHAL_PAGE_SIZE);
                 allocParamsForBufferLinear.pBufName = "VDENC Read Batch Buffer";
+                allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
                 allocatedbuffer                     = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
                 ENCODE_CHK_NULL_RETURN(allocatedbuffer);
                 m_vdencReadBatchBuffer[k][i] = *allocatedbuffer;
@@ -141,6 +139,7 @@ namespace encode
                 // BRC update DMEM
                 allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_vdencBrcUpdateDmemBufferSize, CODECHAL_CACHELINE_SIZE);
                 allocParamsForBufferLinear.pBufName = "VDENC BrcUpdate DmemBuffer";
+                allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_NOCACHE;
                 allocatedbuffer                     = m_allocator->AllocateResource(allocParamsForBufferLinear, true, MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ);
                 ENCODE_CHK_NULL_RETURN(allocatedbuffer);
                 m_vdencBrcUpdateDmemBuffer[k][i] = *allocatedbuffer;
@@ -290,7 +289,7 @@ namespace encode
 
             if (selectedSlot == -1)
             {
-                CODECHAL_ENCODE_ASSERTMESSAGE("No valid ref slot index");
+                ENCODE_ASSERTMESSAGE("No valid ref slot index");
                 return MOS_STATUS_INVALID_PARAMETER;
             }
 
@@ -372,7 +371,7 @@ namespace encode
                 if ((hucVdencBrcUpdateDmem->CurrentFrameType_U8 == HEVC_BRC_FRAME_TYPE_INVALID) ||
                     (m_basicFeature->m_hevcSeqParams->LowDelayMode && hucVdencBrcUpdateDmem->CurrentFrameType_U8 == HEVC_BRC_FRAME_TYPE_B2))
                 {
-                    CODECHAL_ENCODE_ASSERTMESSAGE("HEVC_BRC_FRAME_TYPE_INVALID or LBD picture doesn't support Level 4\n");
+                    ENCODE_ASSERTMESSAGE("HEVC_BRC_FRAME_TYPE_INVALID or LBD picture doesn't support Level 4\n");
                     return MOS_STATUS_INVALID_PARAMETER;
                 }
             }
@@ -389,7 +388,7 @@ namespace encode
                 //Invalid CodingType.
                 if (hucVdencBrcUpdateDmem->CurrentFrameType_U8 == HEVC_BRC_FRAME_TYPE_INVALID)
                 {
-                    CODECHAL_ENCODE_ASSERTMESSAGE("Invalid CodingType\n");
+                    ENCODE_ASSERTMESSAGE("Invalid CodingType\n");
                     return MOS_STATUS_INVALID_PARAMETER;
                 }
             }
@@ -478,7 +477,12 @@ namespace encode
         hucVdencBrcUpdateDmem->FrameSizeBoostForSceneChange = m_tcbrcQualityBoost;
         hucVdencBrcUpdateDmem->TargetFrameSize              = m_basicFeature->m_hevcPicParams->TargetFrameSize << 3;
 
-        if (!(m_basicFeature->GetProfileLevelMaxFrameSize() < hucVdencBrcUpdateDmem->TargetFrameSize / 4) 
+        auto CalculatedMaxFrame                   = m_basicFeature->GetProfileLevelMaxFrameSize();
+        hucVdencBrcUpdateDmem->UPD_UserMaxFrame   = m_basicFeature->m_hevcSeqParams->UserMaxIFrameSize > 0 ? MOS_MIN(m_basicFeature->m_hevcSeqParams->UserMaxIFrameSize, CalculatedMaxFrame) : CalculatedMaxFrame;
+        hucVdencBrcUpdateDmem->UPD_UserMaxFramePB = m_basicFeature->m_hevcSeqParams->UserMaxPBFrameSize > 0 ? MOS_MIN(m_basicFeature->m_hevcSeqParams->UserMaxPBFrameSize, CalculatedMaxFrame) : CalculatedMaxFrame;
+
+        auto UserMaxFrame = m_basicFeature->m_hevcPicParams->CodingType == I_TYPE ? hucVdencBrcUpdateDmem->UPD_UserMaxFrame : hucVdencBrcUpdateDmem->UPD_UserMaxFramePB;
+        if (!(UserMaxFrame < hucVdencBrcUpdateDmem->TargetFrameSize / 4)  
             && !(hucVdencBrcUpdateDmem->FrameSizeBoostForSceneChange == 2) 
             && (m_basicFeature->m_hevcSeqParams->LookaheadDepth == 0))
         {
@@ -734,7 +738,7 @@ namespace encode
 
         TempBatchBuffer.iCurrent    = constructedCmdBuf.iOffset;
         TempBatchBuffer.iRemaining  = constructedCmdBuf.iRemaining;
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, &TempBatchBuffer));
+        ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, &TempBatchBuffer));
         constructedCmdBuf.pCmdPtr     += (TempBatchBuffer.iCurrent - constructedCmdBuf.iOffset) / 4;
         constructedCmdBuf.iOffset      = TempBatchBuffer.iCurrent;
         constructedCmdBuf.iRemaining   = TempBatchBuffer.iRemaining;
@@ -747,6 +751,13 @@ namespace encode
         return eStatus;
     }
 
+    MHW_SETPAR_DECL_SRC(HCP_PIC_STATE, HucBrcUpdatePkt)
+    {
+        params.bNotFirstPass = !m_pipeline->IsFirstPass();
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS HucBrcUpdatePkt::ConstructGroup2Cmds()
     {
         ENCODE_FUNC_CALL();
@@ -776,7 +787,7 @@ namespace encode
 
         TempBatchBuffer.iCurrent    = constructedCmdBuf.iOffset;
         TempBatchBuffer.iRemaining  = constructedCmdBuf.iRemaining;
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, &TempBatchBuffer));
+        ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, &TempBatchBuffer));
         constructedCmdBuf.pCmdPtr     += (TempBatchBuffer.iCurrent - constructedCmdBuf.iOffset) / 4;
         constructedCmdBuf.iOffset      = TempBatchBuffer.iCurrent;
         constructedCmdBuf.iRemaining   = TempBatchBuffer.iRemaining;
@@ -843,7 +854,7 @@ namespace encode
 
             TempBatchBuffer.iCurrent    = constructedCmdBuf.iOffset;
             TempBatchBuffer.iRemaining  = constructedCmdBuf.iRemaining;
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, &TempBatchBuffer));
+            ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, &TempBatchBuffer));
             constructedCmdBuf.pCmdPtr     += (TempBatchBuffer.iCurrent - constructedCmdBuf.iOffset) / 4;
             constructedCmdBuf.iOffset      = TempBatchBuffer.iCurrent;
             constructedCmdBuf.iRemaining   = TempBatchBuffer.iRemaining;
@@ -910,7 +921,9 @@ namespace encode
         CodechalDebugInterface *debugInterface = m_pipeline->GetDebugInterface();
         ENCODE_CHK_NULL_RETURN(debugInterface);
 
+        auto virtualAddrParams = m_hucItf->MHW_GETPAR_F(HUC_VIRTUAL_ADDR_STATE)();
         int32_t currentPass = m_pipeline->GetCurrentPass();
+
         if (isInput)
         {
             //Dump HucBrcUpdate input buffers
@@ -921,198 +934,66 @@ namespace encode
                 hucRegionDumpUpdate));
 
             // Region 1 - VDENC Statistics Buffer dump
-            auto vdencStatusBuffer = m_virtualAddrParams.regionParams[1].presRegion;
             HevcBasicFeature *hevcBasicFeature  = dynamic_cast<HevcBasicFeature *>(m_basicFeature);
             ENCODE_CHK_NULL_RETURN(hevcBasicFeature);
             uint32_t vdencBRCStatsBufferSize = 1216;
             uint32_t size = MOS_ALIGN_CEIL(vdencBRCStatsBufferSize * hevcBasicFeature->m_maxTileNumber, CODECHAL_PAGE_SIZE);
-            if (vdencStatusBuffer)
-            {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    vdencStatusBuffer,
-                    0,
-                    size,
-                    1,
-                    "_VdencStats",
-                    true,
-                    currentPass,
-                    hucRegionDumpUpdate));
-            }
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(1, "_VdencStats", true, hucRegionDumpUpdate, size));
 
             // Region 2 - PAK Statistics Buffer dump
-            auto frameStatStreamOutBuffer = m_virtualAddrParams.regionParams[2].presRegion;
             size = MOS_ALIGN_CEIL(HevcBasicFeature::m_sizeOfHcpPakFrameStats * hevcBasicFeature->m_maxTileNumber, CODECHAL_PAGE_SIZE);
-            if (frameStatStreamOutBuffer)
-            {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    frameStatStreamOutBuffer,
-                    0,
-                    size,
-                    2,
-                    "_PakStats",
-                    true,
-                    currentPass,
-                    hucRegionDumpUpdate));
-            }
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(2, "_PakStats", true, hucRegionDumpUpdate, size));
 
             // Region 3 - Input SLB Buffer
-            auto vdencReadBatchBuffer = m_virtualAddrParams.regionParams[3].presRegion;
-            ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                vdencReadBatchBuffer,
-                0,
-                m_hwInterface->m_vdencReadBatchBufferSize,
-                3,
-                "_Slb",
-                true,
-                currentPass,
-                hucRegionDumpUpdate));
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(3, "_Slb", true, hucRegionDumpUpdate, m_hwInterface->m_vdencReadBatchBufferSize));
 
             // Region 4 - Constant Data Buffer dump
-            auto vdencBrcConstDataBuffer = m_virtualAddrParams.regionParams[4].presRegion;
-            ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                vdencBrcConstDataBuffer,
-                0,
-                m_vdencBrcConstDataBufferSize,
-                4,
-                "_ConstData",
-                true,
-                currentPass,
-                hucRegionDumpUpdate));
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(4, "_ConstData", true, hucRegionDumpUpdate, m_vdencBrcConstDataBufferSize));
 
             // Region 7 - Slice Stat Streamout (Input)
-            auto lucBasedAddressBuffer = m_virtualAddrParams.regionParams[7].presRegion;
-            if (lucBasedAddressBuffer)
-            {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    lucBasedAddressBuffer,
-                    0,
-                    CODECHAL_HEVC_MAX_NUM_SLICES_LVL_6 * CODECHAL_CACHELINE_SIZE,
-                    7,
-                    "_SliceStat",
-                    true,
-                    currentPass,
-                    hucRegionDumpUpdate));
-            }
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(7, "_SliceStat", true, hucRegionDumpUpdate, CODECHAL_HEVC_MAX_NUM_SLICES_LVL_6 * CODECHAL_CACHELINE_SIZE));
 
             // Region 8 - PAK MMIO Buffer dump
-            auto pakInfoBufffer = m_virtualAddrParams.regionParams[8].presRegion;  
-            if (pakInfoBufffer)
-            {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    pakInfoBufffer,
-                    0,
-                    sizeof(CodechalVdencHevcPakInfo),
-                    8,
-                    "_PakMmio",
-                    true,
-                    currentPass,
-                    hucRegionDumpUpdate));
-            }
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(8, "_PakMmio", true, hucRegionDumpUpdate, sizeof(CodechalVdencHevcPakInfo)));
 
             // Region 9 - Streamin Buffer for ROI (Input)
             auto streamInBufferSize = (MOS_ALIGN_CEIL(m_basicFeature->m_frameWidth, 64) / 32) * (MOS_ALIGN_CEIL(m_basicFeature->m_frameHeight, 64) / 32) * CODECHAL_CACHELINE_SIZE;
-            auto stramInBuffer = m_virtualAddrParams.regionParams[9].presRegion;
-            if (stramInBuffer)
-            {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    stramInBuffer,
-                    0,
-                    streamInBufferSize,
-                    9,
-                    "_RoiStreamin",
-                    true,
-                    currentPass,
-                    hucRegionDumpUpdate));
-            }
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(9, "_RoiStreamin", true, hucRegionDumpUpdate, streamInBufferSize));
 
             // Region 10 - Delta QP for ROI Buffer
-            auto vdencDeltaQpBuffer = m_virtualAddrParams.regionParams[10].presRegion;
+            auto vdencDeltaQpBuffer = virtualAddrParams.regionParams[10].presRegion;
             if (vdencDeltaQpBuffer)
             {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    vdencDeltaQpBuffer,
-                    0,
-                    vdencDeltaQpBuffer->iSize,
-                    10,
-                    "_DeltaQp",
-                    true,
-                    currentPass,
-                    hucRegionDumpUpdate));
+                ENCODE_CHK_STATUS_RETURN(DumpRegion(10, "_DeltaQp", true, hucRegionDumpUpdate, vdencDeltaQpBuffer->iSize));
             }
         }
         else
         {
             // Region 5 - Output SLB Buffer
-            auto vdenc2ndLevelBatchBuffer = m_virtualAddrParams.regionParams[5].presRegion;
-            if (vdenc2ndLevelBatchBuffer)
-            {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    vdenc2ndLevelBatchBuffer,
-                    0,
-                    m_hwInterface->m_vdenc2ndLevelBatchBufferSize,
-                    5,
-                    "_Slb",
-                    false,
-                    currentPass,
-                    hucRegionDumpUpdate));
-            }
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(5, "_Slb", false, hucRegionDumpUpdate, m_hwInterface->m_vdenc2ndLevelBatchBufferSize));
 
             // Region 11 - Output ROI Streamin Buffer
-            auto vdencOutputROIStreaminBuffer = m_virtualAddrParams.regionParams[11].presRegion;
+            auto vdencOutputROIStreaminBuffer = virtualAddrParams.regionParams[11].presRegion;
             if (vdencOutputROIStreaminBuffer)
             {
-                ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                    vdencOutputROIStreaminBuffer,
-                    0,
-                    vdencOutputROIStreaminBuffer->iSize,
-                    11,
-                    "_RoiStreamin",
-                    false,
-                    currentPass,
-                    hucRegionDumpUpdate));
+                ENCODE_CHK_STATUS_RETURN(DumpRegion(11, "_RoiStreamin", false, hucRegionDumpUpdate, vdencOutputROIStreaminBuffer->iSize));
             }
         }
 
         // Region 0 - History Buffer dump (Input/Output)
-            auto vdencBrcHistoryBuffer = m_virtualAddrParams.regionParams[0].presRegion;
-        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-            vdencBrcHistoryBuffer,
-            0,
-            CODECHAL_VDENC_HEVC_BRC_HISTORY_BUF_SIZE,
-            0,
-            "_History",
-            isInput,
-            currentPass,
-            hucRegionDumpUpdate));
+        ENCODE_CHK_STATUS_RETURN(DumpRegion(0, "_History", isInput, hucRegionDumpUpdate, CODECHAL_VDENC_HEVC_BRC_HISTORY_BUF_SIZE));
 
         // Region 6 - Data from Pictures for Weighted Prediction (Input/Output)
-        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-            &m_dataFromPicsBuffer,
-            0,
-            CODECHAL_PAGE_SIZE * 4,
-            6,
-            "_PicsData",
-            isInput,
-            currentPass,
-            hucRegionDumpUpdate));
+        ENCODE_CHK_STATUS_RETURN(DumpRegion(6, "_PicsData", isInput, hucRegionDumpUpdate, CODECHAL_PAGE_SIZE * 4));
 
         // Region 15 - Debug Output
-        auto debugBuffer = m_virtualAddrParams.regionParams[15].presRegion;
+        auto debugBuffer = virtualAddrParams.regionParams[15].presRegion;
         if (debugBuffer)
         {
-            ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
-                debugBuffer,
-                0,
-                debugBuffer->iSize,
-                15,
-                "_Debug",
-                isInput,
-                currentPass,
-                hucRegionDumpUpdate));
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(15, "_Debug", isInput, hucRegionDumpUpdate, debugBuffer->iSize));
         }
-
+        
         return MOS_STATUS_SUCCESS;
-
     }
 
     MOS_STATUS HucBrcUpdatePkt::DumpInput()
@@ -1208,7 +1089,7 @@ namespace encode
                         MHW_MI_CHK_NULL(pBsBuffer);
                         MHW_MI_CHK_NULL(pBsBuffer->pBase);
                         uint8_t *data = (uint8_t *)(pBsBuffer->pBase + offSet);
-                        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, nullptr, data, byteSize));
+                        MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, nullptr, data, byteSize));
                     }
                     m_1stPakInsertObjectCmdSize += (cmdBuffer->iOffset - cmdBufOffset);
                 }
@@ -1251,7 +1132,7 @@ namespace encode
                 MHW_MI_CHK_NULL(pBsBuffer);
                 MHW_MI_CHK_NULL(pBsBuffer->pBase);
                 uint8_t *data = (uint8_t *)(pBsBuffer->pBase + offSet);
-                MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, nullptr, data, byteSize));
+                MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, nullptr, data, byteSize));
             }
 
             // Send HCP_PAK_INSERT_OBJ command. For dynamic slice, we are skipping the beginning part of slice header.
@@ -1273,7 +1154,7 @@ namespace encode
                 MHW_MI_CHK_NULL(pBsBuffer);
                 MHW_MI_CHK_NULL(pBsBuffer->pBase);
                 uint8_t *data = (uint8_t *)(pBsBuffer->pBase + offSet);
-                MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, nullptr, data, byteSize));
+                MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, nullptr, data, byteSize));
             }
             m_basicFeature->m_vdencBatchBufferPerSliceVarSize[m_basicFeature->m_curNumSlices] += (cmdBuffer->iOffset - cmdBufOffset);
         }
@@ -1293,7 +1174,7 @@ namespace encode
                 MHW_MI_CHK_NULL(pBsBuffer);
                 MHW_MI_CHK_NULL(pBsBuffer->pBase);
                 uint8_t *data = (uint8_t *)(pBsBuffer->pBase + offSet);
-                MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(cmdBuffer, nullptr, data, byteSize));
+                MHW_MI_CHK_STATUS(Mhw_AddCommandCmdOrBB(m_osInterface, cmdBuffer, nullptr, data, byteSize));
             }
         }
 
