@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -53,7 +53,6 @@
     DEF(MI_MATH);                         \
     DEF(MI_COPY_MEM_MEM);                 \
     DEF(MFX_WAIT)
-
 namespace mhw
 {
 namespace mi
@@ -61,6 +60,20 @@ namespace mi
 class Itf
 {
 public:
+
+    enum CommandsNumberOfAddresses
+    {
+        MFX_WAIT_CMD_NUMBER_OF_ADDRESSES                        = 0,
+        MI_BATCH_BUFFER_START_CMD_NUMBER_OF_ADDRESSES           = 1,
+        MI_STORE_DATA_IMM_CMD_NUMBER_OF_ADDRESSES               = 1,
+        MI_FLUSH_DW_CMD_NUMBER_OF_ADDRESSES                     = 1,
+        MI_CONDITIONAL_BATCH_BUFFER_END_CMD_NUMBER_OF_ADDRESSES = 1,
+        MI_STORE_REGISTER_MEM_CMD_NUMBER_OF_ADDRESSES           = 1,
+        MI_COPY_MEM_MEM_CMD_NUMBER_OF_ADDRESSES                 = 4,
+        MI_SEMAPHORE_WAIT_CMD_NUMBER_OF_ADDRESSES               = 1,
+        MI_ATOMIC_CMD_NUMBER_OF_ADDRESSES                       = 1
+    };
+
     class ParSetting
     {
     public:
@@ -81,15 +94,22 @@ public:
 
     virtual MOS_STATUS AddMiBatchBufferEnd(PMOS_COMMAND_BUFFER cmdBuffer, PMHW_BATCH_BUFFER batchBuffer) = 0;
 
+    virtual MOS_STATUS AddMiBatchBufferEndOnly(PMOS_COMMAND_BUFFER cmdBuffer, PMHW_BATCH_BUFFER batchBuffer) = 0;
+
+    virtual MOS_STATUS AddBatchBufferEndInsertionFlag(MOS_COMMAND_BUFFER &constructedCmdBuf) = 0;
+
     virtual MHW_MI_MMIOREGISTERS* GetMmioRegisters() = 0;
 
-    virtual MOS_STATUS SetCpInterface(MhwCpInterface *cpInterface) = 0;
+    virtual MOS_STATUS SetCpInterface(MhwCpInterface *cpInterface, std::shared_ptr<mhw::mi::Itf> m_miItf) = 0;
 
     virtual uint32_t GetMmioInterfaces(MHW_MMIO_REGISTER_OPCODE opCode) = 0;
 
     virtual MOS_STATUS AddProtectedProlog(MOS_COMMAND_BUFFER *cmdBuffer) = 0;
 
+    virtual MOS_STATUS AddVeboxMMIOPrologCmd(PMOS_COMMAND_BUFFER CmdBuffer) = 0;
+
     _MI_CMD_DEF(_MHW_CMD_ALL_DEF_FOR_ITF);
+MEDIA_CLASS_DEFINE_END(mhw__mi__Itf)
 };
 }  // namespace mi
 }  // namespace mhw
