@@ -30,6 +30,9 @@
 #include "vp_obj_factories.h"
 #include "sw_filter_handle.h"
 #include "vp_utils.h"
+#include "vp_user_feature_control.h"
+#include "vp_utils.h"
+
 using namespace vp;
 
 template <typename T>
@@ -46,6 +49,12 @@ inline void swap(T &a, T &b)
 
 SwFilter::SwFilter(VpInterface &vpInterface, FeatureType type) : m_vpInterface(vpInterface), m_type(type)
 {
+    if (m_EngineCaps.value != 0)
+    {
+        // Some complier may not work well for m_EngineCaps initialization by m_EngineCaps = {}. Force set to 0 here.
+        VP_PUBLIC_NORMALMESSAGE("m_EngineCaps is not initialized correctly since complier issue, m_EngineCaps.value: %x. Force reset to 0.", m_EngineCaps.value);
+        m_EngineCaps.value = 0;
+    }
 }
 
 SwFilter::~SwFilter()
@@ -165,6 +174,10 @@ MOS_STATUS SwFilterCsc::Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf,
     m_Params.output.chromaSiting    = surfOutput->ChromaSiting;
     // Alpha should be handled in input pipe to avoid alpha data lost from image.
     m_Params.pAlphaParams           = params.pCompAlpha;
+    // formatForCUS will be set on demand in Policy::GetCSCExecutionCapsBT2020ToRGB.
+    m_Params.formatforCUS           = Format_None;
+
+    VP_PUBLIC_NORMALMESSAGE("formatInput %d, formatOutput %d", m_Params.formatInput, m_Params.formatOutput);
 
     return MOS_STATUS_SUCCESS;
 }
@@ -195,6 +208,8 @@ MOS_STATUS SwFilterCsc::Configure(PVP_SURFACE surfInput, PVP_SURFACE surfOutput,
         m_Params.output.colorSpace = surfInput->ColorSpace;
 
         m_Params.formatInput = surfInput->osSurface->Format;
+        // formatForCUS will be set on demand in Policy::GetCSCExecutionCapsBT2020ToRGB.
+        m_Params.formatforCUS = Format_None;
         m_Params.formatOutput = veboxOutputFormat;
         m_Params.input.chromaSiting = surfInput->ChromaSiting;
         m_Params.output.chromaSiting = surfOutput->ChromaSiting;
@@ -211,6 +226,8 @@ MOS_STATUS SwFilterCsc::Configure(PVP_SURFACE surfInput, PVP_SURFACE surfOutput,
         // Skip CSC and only for chroma sitting purpose
         m_Params.input.colorSpace = m_Params.output.colorSpace = surfInput->ColorSpace;
         m_Params.formatInput = m_Params.formatOutput = surfInput->osSurface->Format;
+        // formatForCUS will be set on demand in Policy::GetCSCExecutionCapsBT2020ToRGB.
+        m_Params.formatforCUS                        = Format_None;
         m_Params.input.chromaSiting                  = surfInput->ChromaSiting;
         m_Params.output.chromaSiting                 = surfOutput->ChromaSiting;
         m_Params.pAlphaParams                        = nullptr;
@@ -220,8 +237,6 @@ MOS_STATUS SwFilterCsc::Configure(PVP_SURFACE surfInput, PVP_SURFACE surfOutput,
 
         return MOS_STATUS_SUCCESS;
     }
-
-    return MOS_STATUS_UNIMPLEMENTED;
 }
 
 MOS_STATUS SwFilterCsc::Configure(FeatureParamCsc &params)
@@ -245,6 +260,8 @@ MOS_STATUS SwFilterCsc::Configure(VEBOX_SFC_PARAMS &params)
     m_Params.output.colorSpace      = params.output.colorSpace;
     m_Params.pIEFParams             = nullptr;
     m_Params.formatInput            = params.input.surface->Format;
+    // formatForCUS will be set on demand in Policy::GetCSCExecutionCapsBT2020ToRGB.
+    m_Params.formatforCUS           = Format_None;
     m_Params.formatOutput           = params.output.surface->Format;
     m_Params.input.chromaSiting     = params.input.chromaSiting;
     m_Params.output.chromaSiting    = params.output.chromaSiting;
@@ -410,6 +427,12 @@ MOS_STATUS SwFilterScaling::Configure(VP_PIPELINE_PARAMS &params, bool isInputSu
 
     VP_PUBLIC_NORMALMESSAGE("interlacedScalingType %d", m_Params.interlacedScalingType);
 
+    m_Params.input.tileMode         = surfInput->TileModeGMM;
+    m_Params.output.tileMode        = surfOutput->TileModeGMM;
+
+    VP_PUBLIC_NORMALMESSAGE("Input  Surface:  TileType %d, TileModeGMM %d", surfInput->TileType,  surfInput->TileModeGMM);
+    VP_PUBLIC_NORMALMESSAGE("Output Surface:  TileType %d, TileModeGMM %d", surfOutput->TileType, surfOutput->TileModeGMM);
+
     // For field-to-interleaved scaling, the height of rcSrcInput is input field height,
     // the height of rcDstInput is output frame height, for scaling ratio calculation, the
     // bottom of rcDstInput need to divide 2.
@@ -452,6 +475,12 @@ MOS_STATUS SwFilterScaling::Configure(VEBOX_SFC_PARAMS &params)
     m_Params.pColorFillParams       = nullptr;
     m_Params.pCompAlpha             = nullptr;
 
+    m_Params.input.tileMode         = params.input.surface->TileModeGMM;
+    m_Params.output.tileMode        = params.output.surface->TileModeGMM;
+
+    VP_PUBLIC_NORMALMESSAGE("Input  Surface:  TileType %d, TileModeGMM %d", params.input.surface->TileType, params.input.surface->TileModeGMM);
+    VP_PUBLIC_NORMALMESSAGE("Output Surface:  TileType %d, TileModeGMM %d", params.output.surface->TileType, params.output.surface->TileModeGMM);
+
     RECT recOutput = {0, 0, (int32_t)params.output.surface->dwWidth, (int32_t)params.output.surface->dwHeight};
 
     if (params.input.rotation == (MEDIA_ROTATION)VPHAL_ROTATION_IDENTITY    ||
@@ -527,6 +556,12 @@ MOS_STATUS SwFilterScaling::Configure(PVP_SURFACE surfInput, PVP_SURFACE surfOut
     m_Params.csc.colorSpaceOutput       = surfOutput->ColorSpace;
     m_Params.rotation.rotationNeeded    = false;
 
+    m_Params.input.tileMode             = surfInput->osSurface->TileModeGMM;
+    m_Params.output.tileMode            = surfOutput->osSurface->TileModeGMM;
+
+    VP_PUBLIC_NORMALMESSAGE("Input  Surface:  TileType %d, TileModeGMM %d", surfInput->osSurface->TileType, surfInput->osSurface->TileModeGMM);
+    VP_PUBLIC_NORMALMESSAGE("Output Surface:  TileType %d, TileModeGMM %d", surfOutput->osSurface->TileType, surfOutput->osSurface->TileModeGMM);
+
     VP_PUBLIC_NORMALMESSAGE("Configure scaling parameters by Surfaces: intput %d x %d, output %d x %d, (%d, %d, %d, %d) -> (%d, %d, %d, %d)",
         m_Params.input.dwWidth, m_Params.input.dwHeight, m_Params.output.dwWidth, m_Params.output.dwHeight,
         m_Params.input.rcSrc.left, m_Params.input.rcSrc.top, m_Params.input.rcSrc.right, m_Params.input.rcSrc.bottom,
@@ -779,10 +814,11 @@ MOS_STATUS SwFilterDenoise::Configure(VP_PIPELINE_PARAMS& params, bool isInputSu
     m_Params.formatInput   = surfInput->Format;
     m_Params.formatOutput  = surfInput->Format;// Denoise didn't change the original format;
     m_Params.heightInput   = surfInput->dwHeight;
+    m_Params.srcBottom     = surfInput->rcSrc.bottom;
 
     m_Params.denoiseParams.bEnableChroma =
         m_Params.denoiseParams.bEnableChroma && m_Params.denoiseParams.bEnableLuma;
-
+#if !EMUL
     GMM_RESOURCE_INFO* pSrcGmmResInfo    = surfInput->OsResource.pGmmResInfo;
     GMM_RESOURCE_INFO* pTargetGmmResInfo = params.pTarget[0]->OsResource.pGmmResInfo;
     VP_PUBLIC_CHK_NULL_RETURN(pSrcGmmResInfo);
@@ -797,7 +833,24 @@ MOS_STATUS SwFilterDenoise::Configure(VP_PIPELINE_PARAMS& params, bool isInputSu
     {
         m_Params.secureDnNeeded = true;
     }
+#endif
 
+    VP_PUBLIC_NORMALMESSAGE("denoiseLevel = %d,secureDn = %d, AutoDn = %d", m_Params.denoiseParams.NoiseLevel, m_Params.secureDnNeeded, m_Params.denoiseParams.bAutoDetect);
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SwFilterDenoise::Configure(FeatureParamDenoise &params)
+{
+    VP_FUNC_CALL();
+
+    m_Params.sampleTypeInput = params.sampleTypeInput;
+    m_Params.denoiseParams   = params.denoiseParams;
+    m_Params.formatInput     = params.formatInput;
+    m_Params.formatOutput    = params.formatOutput;
+    m_Params.heightInput     = params.heightInput;
+    m_Params.secureDnNeeded  = params.secureDnNeeded;
+
+    VP_PUBLIC_NORMALMESSAGE("denoiseLevel = %d,secureDn = %d, AutoDn = %d", m_Params.denoiseParams.NoiseLevel, m_Params.secureDnNeeded, m_Params.denoiseParams.bAutoDetect);
     return MOS_STATUS_SUCCESS;
 }
 
@@ -966,12 +1019,16 @@ MOS_STATUS SwFilterSte::Configure(VP_PIPELINE_PARAMS& params, bool isInputSurf,
 
     if (surfInput->pColorPipeParams)
     {
-        m_Params.bEnableSTE =  surfInput->pColorPipeParams->bEnableSTE;
+        m_Params.bEnableSTE  =  surfInput->pColorPipeParams->bEnableSTE;
+        m_Params.bEnableSTD  = surfInput->pColorPipeParams->bEnableSTD;
+        m_Params.STDParam    = surfInput->pColorPipeParams->StdParams;
         m_Params.dwSTEFactor = surfInput->pColorPipeParams->SteParams.dwSTEFactor;
     }
     else
     {
-        m_Params.bEnableSTE = false;
+        m_Params.bEnableSTE  = false;
+        m_Params.bEnableSTD  = false;
+        m_Params.STDParam    = {};
         m_Params.dwSTEFactor = 0;
     }
 
@@ -1228,21 +1285,30 @@ MOS_STATUS SwFilterHdr::Clean()
 MOS_STATUS SwFilterHdr::Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex)
 {
     VP_FUNC_CALL();
-
     PVPHAL_SURFACE surfInput  = isInputSurf ? params.pSrc[surfIndex] : params.pSrc[0];
     PVPHAL_SURFACE surfOutput = isInputSurf ? params.pTarget[0] : params.pTarget[surfIndex];
+    MOS_STATUS     eStatus    = MOS_STATUS_SUCCESS;
+    uint32_t       i          = 0;
+    uint32_t     dwUpdateMask = 0;
+    bool                        bSupported       = false;
+    VPHAL_HDR_LUT_MODE          CurrentLUTMode      = VPHAL_HDR_LUT_MODE_NONE;
 
     VP_PUBLIC_CHK_NULL_RETURN(surfInput);
     VP_PUBLIC_CHK_NULL_RETURN(surfOutput);
     VP_PUBLIC_CHK_NULL_RETURN(surfInput->pHDRParams);
+    VP_PUBLIC_CHK_NULL_RETURN(m_vpInterface.GetHwInterface());
+    VP_PUBLIC_CHK_NULL_RETURN(m_vpInterface.GetHwInterface()->m_osInterface);
 
     m_Params.formatInput  = surfInput->Format;
     m_Params.formatOutput = surfOutput->Format;
+    m_Params.widthInput   = surfInput->dwWidth;
+    m_Params.heightInput  = surfInput->dwHeight;
 
     // For H2S, it is possible that there is no HDR params for render target.
     m_Params.uiMaxContentLevelLum = surfInput->pHDRParams->MaxCLL;
     m_Params.srcColorSpace        = surfInput->ColorSpace;
     m_Params.dstColorSpace        = surfOutput->ColorSpace;
+
     if (surfInput->pHDRParams->EOTF == VPHAL_HDR_EOTF_SMPTE_ST2084)
     {
         m_Params.hdrMode = VPHAL_HDR_MODE_TONE_MAPPING;
@@ -1255,13 +1321,73 @@ MOS_STATUS SwFilterHdr::Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf,
             }
         }
     }
+    else if (surfInput->pHDRParams->EOTF == VPHAL_HDR_EOTF_TRADITIONAL_GAMMA_SDR && surfOutput->pHDRParams->EOTF == VPHAL_HDR_EOTF_SMPTE_ST2084)
+    {
+        m_Params.hdrMode = VPHAL_HDR_MODE_INVERSE_TONE_MAPPING;
+    }
+
     if (m_Params.hdrMode == VPHAL_HDR_MODE_NONE)
     {
         VP_PUBLIC_ASSERTMESSAGE("HDR Mode is NONE");
         VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
     }
-    return MOS_STATUS_SUCCESS;
+
+    m_Params.pColorFillParams = params.pColorFillParams;
+
+    if (surfInput->SurfType == SURF_IN_PRIMARY && m_Params.globalLutMode != VPHAL_HDR_LUT_MODE_3D)
+    {
+        CurrentLUTMode = VPHAL_HDR_LUT_MODE_2D;
+    }
+    else
+    {
+        CurrentLUTMode = VPHAL_HDR_LUT_MODE_2D;
+    }
+
+    // Neither 1D nor 3D LUT is needed in linear output case.
+    if (IS_RGB64_FLOAT_FORMAT(surfOutput->Format))
+    {
+        CurrentLUTMode = VPHAL_HDR_LUT_MODE_NONE;
+    }
+
+    m_Params.lutMode = CurrentLUTMode;
+
+    VP_PUBLIC_CHK_STATUS_RETURN(HdrIsInputFormatSupported(surfInput, &bSupported));
+
+    if (!bSupported)
+    {
+        VP_RENDER_ASSERTMESSAGE("HDR Unsupported Source Format\n");
+        return MOS_STATUS_SUCCESS;
+    }
+
+    if (surfInput && surfInput->pHDRParams)
+    {
+        MOS_SecureMemcpy(&m_Params.srcHDRParams, sizeof(HDR_PARAMS), (HDR_PARAMS *)surfInput->pHDRParams, sizeof(HDR_PARAMS));
+    }
+    else
+    {
+        MOS_ZeroMemory(&m_Params.srcHDRParams, sizeof(HDR_PARAMS));
+    }
+
+    VP_PUBLIC_CHK_STATUS_RETURN(HdrIsOutputFormatSupported(surfOutput, &bSupported));
+
+    if (!bSupported)
+    {
+        VP_RENDER_ASSERTMESSAGE("HDR Unsupported Target Format\n");
+        return MOS_STATUS_SUCCESS;
+    }
+
+    if (surfOutput && surfOutput->pHDRParams)
+    {
+        MOS_SecureMemcpy(&m_Params.targetHDRParams, sizeof(HDR_PARAMS), (HDR_PARAMS *)surfOutput->pHDRParams, sizeof(HDR_PARAMS));
+    }
+    else
+    {
+        MOS_ZeroMemory(&m_Params.targetHDRParams, sizeof(HDR_PARAMS));
+    }
+
+     return MOS_STATUS_SUCCESS;
 }
+
 FeatureParamHdr &SwFilterHdr::GetSwFilterParams()
 {
     VP_FUNC_CALL();
@@ -1286,6 +1412,112 @@ SwFilter *SwFilterHdr::Clone()
     return p;
 }
 
+//!
+//! \brief    Checks to see if HDR can be enabled for the formats
+//! \details  Checks to see if HDR can be enabled for the formats
+//! \param    PVPHAL_SURFACE pSrcSurface
+//!           [in] Pointer to source surface
+//! \param    bool* pbSupported
+//!           [out] true supported false not supported
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS SwFilterHdr::HdrIsInputFormatSupported(
+    PVPHAL_SURFACE pSrcSurface,
+    bool          *pbSupported)
+{
+    VP_FUNC_CALL();
+
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+    VP_PUBLIC_CHK_NULL(pSrcSurface);
+    VP_PUBLIC_CHK_NULL(pbSupported);
+
+    // HDR supported formats
+    if (pSrcSurface->Format == Format_A8R8G8B8 ||
+        pSrcSurface->Format == Format_X8R8G8B8 ||
+        pSrcSurface->Format == Format_A8B8G8R8 ||
+        pSrcSurface->Format == Format_X8B8G8R8 ||
+        pSrcSurface->Format == Format_R10G10B10A2 ||
+        pSrcSurface->Format == Format_B10G10R10A2 ||
+        pSrcSurface->Format == Format_A16B16G16R16 ||
+        pSrcSurface->Format == Format_A16R16G16B16 ||
+        pSrcSurface->Format == Format_A16B16G16R16F ||
+        pSrcSurface->Format == Format_A16R16G16B16F ||
+        pSrcSurface->Format == Format_P016 ||
+        pSrcSurface->Format == Format_NV12 ||
+        pSrcSurface->Format == Format_P010 ||
+        pSrcSurface->Format == Format_YUY2 ||
+        pSrcSurface->Format == Format_AYUV)
+    {
+        *pbSupported = true;
+        goto finish;
+    }
+    else
+    {
+        VP_RENDER_ASSERTMESSAGE(
+            "HDR Unsupported Source Format: '0x%08x'\n",
+            pSrcSurface->Format);
+        *pbSupported = false;
+    }
+
+finish:
+    return eStatus;
+}
+
+//!
+//! \brief    Checks to see if HDR can be enabled for the formats
+//! \details  Checks to see if HDR can be enabled for the formats
+//! \param    PVPHAL_SURFACE pTargetSurface
+//!           [in] Pointer to target surface
+//! \param    bool* pbSupported
+//!           [out] true supported false not supported
+//! \return   MOS_STATUS
+//!           MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS SwFilterHdr::HdrIsOutputFormatSupported(
+    PVPHAL_SURFACE pTargetSurface,
+    bool          *pbSupported)
+{
+    VP_FUNC_CALL();
+
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+
+    VP_PUBLIC_CHK_NULL(pTargetSurface);
+    VP_PUBLIC_CHK_NULL(pbSupported);
+
+    // HDR supported formats
+    if (pTargetSurface->Format == Format_A8R8G8B8 ||
+        pTargetSurface->Format == Format_X8R8G8B8 ||
+        pTargetSurface->Format == Format_A8B8G8R8 ||
+        pTargetSurface->Format == Format_X8B8G8R8 ||
+        pTargetSurface->Format == Format_R10G10B10A2 ||
+        pTargetSurface->Format == Format_B10G10R10A2 ||
+        pTargetSurface->Format == Format_A16B16G16R16 ||
+        pTargetSurface->Format == Format_A16R16G16B16 ||
+        pTargetSurface->Format == Format_YUY2 ||
+        pTargetSurface->Format == Format_P016 ||
+        pTargetSurface->Format == Format_NV12 ||
+        pTargetSurface->Format == Format_P010 ||
+        pTargetSurface->Format == Format_P016 ||
+        pTargetSurface->Format == Format_A16R16G16B16F ||
+        pTargetSurface->Format == Format_A16B16G16R16F)
+    {
+        *pbSupported = true;
+        goto finish;
+    }
+    else
+    {
+        VP_RENDER_ASSERTMESSAGE(
+            "HDR Unsupported Target Format: '0x%08x'\n",
+            pTargetSurface->Format);
+        *pbSupported = false;
+    }
+
+finish:
+    return eStatus;
+}
+
 bool vp::SwFilterHdr::operator==(SwFilter &swFilter)
 {
     VP_FUNC_CALL();
@@ -1726,6 +1958,135 @@ MOS_STATUS vp::SwFilterAlpha::Update(VP_SURFACE* inputSurf, VP_SURFACE* outputSu
     return MOS_STATUS_SUCCESS;
 }
 
+/****************************************************************************************************/
+/*                                      SwFilterCgc                                                 */
+/****************************************************************************************************/
+
+SwFilterCgc::SwFilterCgc(VpInterface& vpInterface) : SwFilter(vpInterface, FeatureTypeCgc)
+{
+    m_Params.type = m_type;
+}
+
+SwFilterCgc::~SwFilterCgc()
+{
+    Clean();
+}
+
+MOS_STATUS SwFilterCgc::Clean()
+{
+    VP_FUNC_CALL();
+
+    VP_PUBLIC_CHK_STATUS_RETURN(SwFilter::Clean());
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SwFilterCgc::Configure(VP_PIPELINE_PARAMS& params, bool isInputSurf, int surfIndex)
+{
+    VP_FUNC_CALL();
+
+    PVPHAL_SURFACE surfInput = static_cast<PVPHAL_SURFACE>(isInputSurf ? params.pSrc[surfIndex] : params.pSrc[0]);
+    PVPHAL_SURFACE surfOutput = isInputSurf ? params.pTarget[0] : params.pTarget[surfIndex];
+    VP_PUBLIC_CHK_NULL_RETURN(surfInput);
+    VP_PUBLIC_CHK_NULL_RETURN(surfOutput);
+
+    m_Params.formatInput   = surfInput->Format;
+    m_Params.formatOutput  = surfInput->Format; // CGC didn't change the original format;
+
+    if (IsBt2020ToRGB(params, isInputSurf, surfIndex))
+    {
+        m_Params.formatOutput     = Format_A8B8G8R8;
+        m_Params.bBt2020ToRGB     = true;
+        m_Params.colorSpace       = surfInput->ColorSpace;
+        m_Params.GCompMode        = GAMUT_MODE_NONE;
+        m_Params.bExtendedSrcGamut = false;
+        m_Params.bExtendedDstGamut = false;
+        m_Params.dwAttenuation = 0;
+        MOS_ZeroMemory(m_Params.displayRGBW_x, sizeof(m_Params.displayRGBW_x));
+        MOS_ZeroMemory(m_Params.displayRGBW_y, sizeof(m_Params.displayRGBW_y));
+    }
+    else
+    {
+        m_Params.GCompMode = GAMUT_MODE_NONE;
+        m_Params.colorSpace = CSpace_Any;
+        m_Params.bExtendedSrcGamut = false;
+        m_Params.bExtendedDstGamut = false;
+        m_Params.dwAttenuation = 0;
+        MOS_ZeroMemory(m_Params.displayRGBW_x, sizeof(m_Params.displayRGBW_x));
+        MOS_ZeroMemory(m_Params.displayRGBW_y, sizeof(m_Params.displayRGBW_y));
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
+FeatureParamCgc& SwFilterCgc::GetSwFilterParams()
+{
+    VP_FUNC_CALL();
+
+    return m_Params;
+}
+
+SwFilter * SwFilterCgc::Clone()
+{
+    VP_FUNC_CALL();
+
+    SwFilter* p = CreateSwFilter(m_type);
+
+    SwFilterCgc *swFilter = dynamic_cast<SwFilterCgc *>(p);
+    if (nullptr == swFilter)
+    {
+        DestroySwFilter(p);
+        return nullptr;
+    }
+
+    swFilter->m_Params = m_Params;
+    return p;
+}
+
+bool SwFilterCgc::operator==(SwFilter& swFilter)
+{
+    VP_FUNC_CALL();
+
+    SwFilterCgc* p = dynamic_cast<SwFilterCgc*>(&swFilter);
+    return nullptr != p && 0 == memcmp(&this->m_Params, &p->m_Params, sizeof(FeatureParamCgc));
+}
+
+MOS_STATUS SwFilterCgc::Update(VP_SURFACE* inputSurf, VP_SURFACE* outputSurf, SwFilterSubPipe &pipe)
+{
+    VP_FUNC_CALL();
+
+    VP_PUBLIC_CHK_NULL_RETURN(inputSurf);
+    VP_PUBLIC_CHK_NULL_RETURN(inputSurf->osSurface);
+    VP_PUBLIC_CHK_NULL_RETURN(outputSurf);
+    VP_PUBLIC_CHK_NULL_RETURN(outputSurf->osSurface);
+    m_Params.formatInput = inputSurf->osSurface->Format;
+    m_Params.formatOutput = outputSurf->osSurface->Format;
+    return MOS_STATUS_SUCCESS;
+}
+
+bool SwFilterCgc::IsBt2020ToRGB(VP_PIPELINE_PARAMS& params, bool isInputSurf, int surfIndex)
+{
+    VP_FUNC_CALL();
+
+    PVPHAL_SURFACE surfInput = static_cast<PVPHAL_SURFACE>(isInputSurf ? params.pSrc[surfIndex] : params.pSrc[0]);
+    PVPHAL_SURFACE surfOutput = isInputSurf ? params.pTarget[0] : params.pTarget[surfIndex];
+
+    if (surfInput && surfOutput &&
+        IS_COLOR_SPACE_BT2020_YUV(surfInput->ColorSpace))
+    {
+        if ((surfOutput->ColorSpace == CSpace_BT601) ||
+            (surfOutput->ColorSpace == CSpace_BT709) ||
+            (surfOutput->ColorSpace == CSpace_BT601_FullRange) ||
+            (surfOutput->ColorSpace == CSpace_BT709_FullRange) ||
+            (surfOutput->ColorSpace == CSpace_stRGB) ||
+            (surfOutput->ColorSpace == CSpace_sRGB))
+        {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 /****************************************************************************************************/
 /*                                      SwFilterSet                                                 */
 /****************************************************************************************************/
