@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -27,6 +27,7 @@
 #include "vp_kernelset.h"
 #include "vp_render_common.h"
 #include "vp_render_kernel_obj.h"
+#include "mhw_mi_itf.h"
 
 namespace vp
 {
@@ -62,8 +63,19 @@ public:
 
     virtual MOS_STATUS SetFcParams(PRENDER_FC_PARAMS params);
 
+    virtual MOS_STATUS SetHdr3DLutParams(PRENDER_HDR_3DLUT_CAL_PARAMS params);
+
+    virtual MOS_STATUS SetDnHVSParams(PRENDER_DN_HVS_CAL_PARAMS params);
+
     virtual MOS_STATUS DumpOutput() override;
 
+    void PrintWalkerParas(MHW_WALKER_PARAMS &WalkerParams);
+
+    virtual MOS_STATUS SetHdrParams(PRENDER_HDR_PARAMS params);
+    virtual bool IsRenderUncompressedWriteNeeded(PVP_SURFACE VpSurface);
+
+    void RenderMMCLimitationCheck(VP_SURFACE *vpSurface, RENDERHAL_SURFACE_NEXT &renderHalSurface, SurfaceType type);
+
 protected:
 
     virtual MOS_STATUS LoadKernel() override;
@@ -101,8 +113,6 @@ protected:
     // comments here: Hight overwite params if needed
     MOS_STATUS UpdateRenderSurface(RENDERHAL_SURFACE_NEXT &renderSurface, KERNEL_SURFACE_STATE_PARAM& kernelParams);
 
-    MOS_STATUS SetSamplerAvsParams(MHW_SAMPLER_STATE_PARAM& samplerStateParam, PRENDER_SR_PARAMS params);
-
    MOS_STATUS SamplerAvsCalcScalingTable(
         MHW_AVS_PARAMS& avsParameters,
         MOS_FORMAT      SrcFormat,
@@ -141,6 +151,8 @@ protected:
     virtual MOS_STATUS InitFcMemCacheControl(PVP_RENDER_CACHE_CNTL settings);
     MOS_STATUS InitSurfMemCacheControl(VP_EXECUTE_CAPS packetCaps);
 
+    MHW_SETPAR_DECL_HDR(PIPE_CONTROL);
+
 protected:
 
     KERNEL_OBJECTS                     m_kernelObjs;
@@ -157,13 +169,16 @@ protected:
     KERNEL_SAMPLER_STATE_GROUP         m_kernelSamplerStateGroup;
 
     KERNEL_SUBMISSION_MODE             m_submissionMode = MULTI_KERNELS_WITH_MULTI_MEDIA_STATES;
+    KERNEL_BINDINGTABLE_MODE           m_bindingtableMode = MULTI_KERNELS_WITH_ONE_BINDINGTABLE;
     uint32_t                           m_slmSize        = 0;
     uint32_t                           m_totalCurbeSize = 0;
     uint32_t                           m_totoalInlineSize = 0;
 
     VP_SURFACE                        *m_currentSurface  = nullptr;              //!< Current frame
     PVP_RENDER_CACHE_CNTL              m_surfMemCacheCtl = nullptr;              //!< Surface memory cache control
+    PRENDERHAL_ENLARGE_PARAMS          m_enlargedStateHeapSetting = nullptr;
 
+MEDIA_CLASS_DEFINE_END(vp__VpRenderCmdPacket)
 };
 }
 
