@@ -29,9 +29,11 @@
 #ifndef __VP_FEATURE_REPORT_H__
 #define __VP_FEATURE_REPORT_H__
 
+#include <stdint.h>
 #include "vp_common.h"
-#include "vphal_common_tools.h"
+#include "vp_common_tools.h"
 #include "media_class_trace.h"
+#include "vp_common_hdr.h"
 
 //!
 //! Class VphalFeatureReport
@@ -66,6 +68,7 @@ public:
         bool                          veFeatureInUse      = false;                        //!< If any VEBOX feature is in use, excluding pure bypass for SFC
         bool                          diScdMode           = false;                        //!< Scene change detection
         VPHAL_HDR_MODE                hdrMode             = VPHAL_HDR_MODE_NONE;          //!< HDR mode
+        bool                          packetReused        = false;                        //!< true if packet reused.
     };
 
     virtual ~VpFeatureReport(){};
@@ -91,7 +94,7 @@ public:
     //!
     virtual void SetConfigValues(
         PVP_CONFIG configValues,
-        uint32_t   &laceInUse);
+        bool       traceEvent = true);
 
     VP_FEATURES &GetFeatures()
     {
