@@ -64,8 +64,8 @@
 #define VP_SURFACE_DUMP(                                       \
     debuginterface, surf, frameCntr, layerCntr, loc)           \
     if (debuginterface)                                        \
-        VP_DEBUG_CHK_STATUS(debuginterface->DumpVpSurface(     \
-           surf, frameCntr, layerCntr, loc));
+        debuginterface->DumpVpSurface(                         \
+           surf, frameCntr, layerCntr, loc);
 
 //------------------------------------------------------------------------------
 // Dump array of surfaces
@@ -281,11 +281,7 @@ public:
     //!
     //! \brief    VpSurfaceDumper constuctor
     //!
-    VpSurfaceDumper(PMOS_INTERFACE pOsInterface)
-    :   m_dumpSpec(),
-        m_osInterface(pOsInterface)
-    {
-    };
+    VpSurfaceDumper(PMOS_INTERFACE pOsInterface);
 
     //!
     //! \brief    VpSurfaceDumper destuctor
@@ -390,6 +386,7 @@ protected:
     PMOS_INTERFACE              m_osInterface;
     char                        m_dumpPrefix[MAX_PATH];     // Called frequently, so avoid repeated stack resizing with member data
     char                        m_dumpLoc[MAX_PATH];        // to avoid recursive call from diff owner but sharing the same buffer
+    MediaUserSettingSharedPtr   m_userSettingPtr = nullptr; // userSettingInstance
 
 private:
 
@@ -478,11 +475,7 @@ public:
     //!
     //! \brief    VphalParameterDumper constuctor
     //!
-    VpParameterDumper(PMOS_INTERFACE pOsInterface)
-    :   m_dumpSpec(),
-        m_osInterface(pOsInterface)
-    {
-    };
+    VpParameterDumper(PMOS_INTERFACE pOsInterface);
 
     //!
     //! \brief    Get VPHAL Parameters Dump Spec
@@ -594,7 +587,7 @@ protected:
 
 private:
     PMOS_INTERFACE  m_osInterface;
-
+    MediaUserSettingSharedPtr m_userSettingPtr = nullptr;  // userSettingInstance
     //!
     //! \brief    Gets Debug Whole Format String
     //! \param    [in] format
@@ -613,6 +606,15 @@ private:
     //!
     const char * GetTileTypeStr(MOS_TILE_TYPE tile_type);
 
+    //!
+    //! \brief    Gets Debug Tile Mode String
+    //! \param    [in] tilemode
+    //!           Mos tile mode
+    //! \return   const char *
+    //!           String of the tile type
+    //!
+    const char *GetTileModeGMMStr(MOS_TILE_MODE_GMM tile_mode);
+
     //!
     //! \brief    Gets Debug Surface Type String
     //! \param    [in] component
@@ -694,6 +696,15 @@ private:
     //!
     const char * GetDenoiseModeStr(VPHAL_NOISELEVEL noise_level);
 
+    //!
+    //! \brief    Gets Debug HVS Denoise Mode String
+    //! \param    [in] hvs denoise mode
+    //!           vphal hvsdn mode
+    //! \return   const char *
+    //!           String of vphal hvs denoise mode
+    //!
+    const char *GetHVSDenoiseModeStr(VPHAL_HVSDN_MODE hvs_dn_mode);
+
 MEDIA_CLASS_DEFINE_END(VpParameterDumper)
 };
 
