@@ -23,6 +23,8 @@
 //! \file    mos_gpucontext_specific_next.cpp
 //! \brief   Container class for the Linux specific gpu context
 //!
+
+#include <unistd.h>
 #include "mos_gpucontext_specific_next.h"
 #include "mos_context_specific_next.h"
 #include "mos_graphicsresource_specific_next.h"
@@ -30,12 +32,25 @@
 #include "mos_util_devult_specific_next.h"
 #include "mos_cmdbufmgr_next.h"
 #include "mos_os_virtualengine_next.h"
-#include <unistd.h>
 #include "mos_interface.h"
+#include "mos_os_cp_interface_specific.h"
 
 #define MI_BATCHBUFFER_END 0x05000000
 static pthread_mutex_t command_dump_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+void GpuContextSpecificNext::StoreCreateOptions(PMOS_GPUCTX_CREATOPTIONS createoption)
+{
+    if (typeid(*createoption) == typeid(MOS_GPUCTX_CREATOPTIONS_ENHANCED))
+    {
+        m_bEnhancedUsed = true;
+        MosUtilities::MosSecureMemcpy(&m_createOptionEnhanced, sizeof(MOS_GPUCTX_CREATOPTIONS_ENHANCED), createoption, sizeof(MOS_GPUCTX_CREATOPTIONS_ENHANCED));
+    }
+    else
+    {
+        MosUtilities::MosSecureMemcpy(&m_createOption, sizeof(MOS_GPUCTX_CREATOPTIONS), createoption, sizeof(MOS_GPUCTX_CREATOPTIONS));
+    }
+}
+
 GpuContextSpecificNext::GpuContextSpecificNext(
     const MOS_GPU_NODE gpuNode,
     CmdBufMgrNext         *cmdBufMgr,
@@ -81,6 +96,72 @@ GpuContextSpecificNext::~GpuContextSpecificNext()
     Clear();
 }
 
+MOS_STATUS GpuContextSpecificNext::PatchGPUContextProtection(MOS_STREAM_HANDLE streamState)
+{
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    MOS_OS_CHK_NULL_RETURN(streamState);
+    auto osParameters = (PMOS_CONTEXT)streamState->perStreamParameters;
+    MOS_OS_CHK_NULL_RETURN(osParameters);
+
+    // clean up clear gem context and create protected gem context if CP is enabled
+    if (streamState->osCpInterface &&
+        streamState->osCpInterface->IsCpEnabled())    // Check if CP is enabled as protected GEM context is only needed when CP is enabled
+        {
+            if (streamState->ctxBasedScheduling)
+            {
+                if (m_bProtectedContext == false)    // Check if GEM context is already protected or not
+                {
+                    // Context is not protected, recreate it as protected
+                    Clear();
+                    m_bProtectedContext = true;
+                    PMOS_GPUCTX_CREATOPTIONS createOption;
+                    if (m_bEnhancedUsed)
+                    {
+                        createOption = &m_createOptionEnhanced;
+                    }
+                    else
+                    {
+                        createOption = &m_createOption;
+                    }
+                    eStatus = Init(m_osContext, streamState, createOption);
+                }
+            }
+            else
+            {
+                if (osParameters->m_protectedGEMContext == false)
+                {
+                    // for non context based scheduling protected context is always created as protected during Initialization if needed
+                    // If it is not created during Initialization then do nothing and add a comment for Debug purposes
+                    MOS_OS_CRITICALMESSAGE("Using Clear GEM context when protected Context is needed");
+                    eStatus = MOS_STATUS_SUCCESS;
+                }
+            }
+        }
+
+    // clean up protected gem context and recreate clear gem context if CP is disabled
+    if (streamState->osCpInterface &&
+        !streamState->osCpInterface->IsCpEnabled() &&
+        streamState->ctxBasedScheduling &&
+        m_bProtectedContext == true)    // Check if GEM context is protected or not
+        {
+            // Context is protected, recreate it as clear
+            Clear();
+            m_bProtectedContext = false;
+            PMOS_GPUCTX_CREATOPTIONS createOption;
+            if (m_bEnhancedUsed)
+            {
+                createOption = &m_createOptionEnhanced;
+            }
+            else
+            {
+                createOption = &m_createOption;
+            }
+            eStatus = Init(m_osContext, streamState, createOption);
+        }
+
+    return eStatus;
+}
+
 MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
                     MOS_STREAM_HANDLE streamState,
                     PMOS_GPUCTX_CREATOPTIONS createOption)
@@ -94,6 +175,8 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
     auto osParameters = (PMOS_CONTEXT)streamState->perStreamParameters;
     MOS_OS_CHK_NULL_RETURN(osParameters);
 
+    m_osParameters       = osParameters;
+
     MOS_GPU_NODE gpuNode = MOS_GPU_NODE_3D;
     gpuNode = static_cast<MOS_GPU_NODE>(createOption->gpuNode);
 
@@ -151,15 +234,7 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
 
     m_GPUStatusTag = 1;
 
-    m_createOptionEnhanced = (MOS_GPUCTX_CREATOPTIONS_ENHANCED*)MOS_AllocAndZeroMemory(sizeof(MOS_GPUCTX_CREATOPTIONS_ENHANCED));
-    MOS_OS_CHK_NULL_RETURN(m_createOptionEnhanced);
-    m_createOptionEnhanced->SSEUValue = createOption->SSEUValue;
-
-    if (typeid(*createOption) == typeid(MOS_GPUCTX_CREATOPTIONS_ENHANCED))
-    {
-        PMOS_GPUCTX_CREATOPTIONS_ENHANCED createOptionEnhanced = static_cast<PMOS_GPUCTX_CREATOPTIONS_ENHANCED>(createOption);
-        m_createOptionEnhanced->UsingSFC = createOptionEnhanced->UsingSFC;
-    }
+    StoreCreateOptions(createOption);
 
     for (int i=0; i<MAX_ENGINE_INSTANCE_NUM+1; i++)
     {
@@ -177,7 +252,8 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
 
         m_i915Context[0] = mos_gem_context_create_shared(osParameters->bufmgr,
                                              osParameters->intel_context,
-                                             I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
+                                             I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
+                                             m_bProtectedContext);
         if (m_i915Context[0] == nullptr)
         {
             MOS_OS_ASSERTMESSAGE("Failed to create context.\n");
@@ -291,68 +367,75 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
 
             if (nengine >= 2)
             {
-                if(!streamState->bGucSubmission)
+                int i;
+                //master queue
+                m_i915Context[1] = mos_gem_context_create_shared(osParameters->bufmgr,
+                                                                    osParameters->intel_context,
+                                                                    I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
+                                                                    m_bProtectedContext);
+                if (m_i915Context[1] == nullptr)
                 {
-                    //master queue
-                    m_i915Context[1] = mos_gem_context_create_shared(osParameters->bufmgr,
-                                                                     osParameters->intel_context,
-                                                                     I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
-                    if (m_i915Context[1] == nullptr)
+                    MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
+                    MOS_SafeFreeMemory(engine_map);
+                    return MOS_STATUS_UNKNOWN;
+                }
+                m_i915Context[1]->pOsContext = osParameters;
+
+                if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
+                {
+                    MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
+                    MOS_SafeFreeMemory(engine_map);
+                    return MOS_STATUS_UNKNOWN;
+                }
+
+                //slave queue
+                for (i=1; i<nengine; i++)
+                {
+                    m_i915Context[i+1] = mos_gem_context_create_shared(osParameters->bufmgr,
+                                                                        osParameters->intel_context,
+                                                                        I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
+                                                                        m_bProtectedContext);
+                    if (m_i915Context[i+1] == nullptr)
                     {
-                        MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
+                        MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
                         MOS_SafeFreeMemory(engine_map);
                         return MOS_STATUS_UNKNOWN;
                     }
-                    m_i915Context[1]->pOsContext = osParameters;
+                    m_i915Context[i+1]->pOsContext = osParameters;
 
-                    if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
+                    if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
                     {
-                        MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
-                        MOS_SafeFreeMemory(engine_map);
-                        return MOS_STATUS_UNKNOWN;
-                    }
-
-                    //slave queue
-                    for (int i=1; i<nengine; i++)
-                    {
-                        m_i915Context[i+1] = mos_gem_context_create_shared(osParameters->bufmgr,
-                                                                         osParameters->intel_context,
-                                                                         I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
-                        if (m_i915Context[i+1] == nullptr)
+                        int err = errno;
+                        if (err == ENODEV)
                         {
-                            MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
+                            mos_gem_context_destroy(m_i915Context[1]);
+                            mos_gem_context_destroy(m_i915Context[i+1]);
+                            m_i915Context[i+1] = nullptr;
+                            break;
+                        }
+                        else
+                        {
+                            MOS_OS_ASSERTMESSAGE("Failed to set slave context bond extension. errno=%d\n",err);
                             MOS_SafeFreeMemory(engine_map);
                             return MOS_STATUS_UNKNOWN;
                         }
-                        m_i915Context[i+1]->pOsContext = osParameters;
-
-                        if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
-                        {
-                            int err = errno;
-                            if (err == ENODEV)
-                            {
-                                mos_gem_context_destroy(m_i915Context[i+1]);
-                                m_i915Context[i+1] = nullptr;
-                                break;
-                            }
-                            else
-                            {
-                                MOS_OS_ASSERTMESSAGE("Failed to set slave context bond extension. errno=%d\n",err);
-                                MOS_SafeFreeMemory(engine_map);
-                                return MOS_STATUS_UNKNOWN;
-                            }
-                        }
                     }
                 }
+                if (i == nengine)
+                {
+                    streamState->bGucSubmission = false;
+                }
                 else
                 {
+                    streamState->bGucSubmission = true;
                     //create context with different width
-                    for(int i = 1; i < nengine; i++)
+                    for(i = 1; i < nengine; i++)
                     {
                         unsigned int ctxWidth = i + 1;
                         m_i915Context[i] = mos_gem_context_create_shared(osParameters->bufmgr,
                                                                      osParameters->intel_context,
-                                                                     0); // I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE not allowed for parallel submission
+                                                                     0, // I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE not allowed for parallel submission
+                                                                     m_bProtectedContext);
                         if (mos_set_context_param_parallel(m_i915Context[i], engine_map, ctxWidth) != S_SUCCESS)
                         {
                             MOS_OS_ASSERTMESSAGE("Failed to set parallel extension since discontinuous logical engine.\n");
@@ -444,7 +527,6 @@ void GpuContextSpecificNext::Clear()
     MOS_SafeFreeMemory(m_patchLocationList);
     MOS_SafeFreeMemory(m_attachedResources);
     MOS_SafeFreeMemory(m_writeModeList);
-    MOS_SafeFreeMemory(m_createOptionEnhanced);
 
     for (int i=0; i<MAX_ENGINE_INSTANCE_NUM; i++)
     {
@@ -1082,6 +1164,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
             }
         }
 
+        MOS_OS_CHK_NULL_RETURN(tempCmdBo->virt);
         if (perStreamParameters->bUse64BitRelocs)
         {
             *((uint64_t *)((uint8_t *)tempCmdBo->virt + currentPatch->PatchOffset)) =
@@ -1284,6 +1367,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
     }
     else if (nullRendering == false)
     {
+        UnlockPendingOcaBuffers(cmdBuffer, perStreamParameters);
         if (streamState->ctxBasedScheduling && m_i915Context[0] != nullptr)
         {
             if (cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_MASK)
@@ -1430,6 +1514,32 @@ finish:
     return eStatus;
 }
 
+void GpuContextSpecificNext::UnlockPendingOcaBuffers(PMOS_COMMAND_BUFFER cmdBuffer, PMOS_CONTEXT mosContext)
+{
+    MOS_OS_CHK_NULL_NO_STATUS_RETURN(cmdBuffer);
+    MOS_OS_CHK_NULL_NO_STATUS_RETURN(mosContext);
+    MosOcaInterface *pOcaInterface         = &MosOcaInterfaceSpecific::GetInstance();
+    if (nullptr == pOcaInterface || !((MosOcaInterfaceSpecific*)pOcaInterface)->IsOcaEnabled())
+    {
+        // Will come here for UMD_OCA not being enabled case.
+        return;
+    }
+
+    int count = 0;
+    struct MOS_OCA_EXEC_LIST_INFO *info = nullptr;
+    if ((cmdBuffer->iSubmissionType & SUBMISSION_TYPE_SINGLE_PIPE_MASK) && ((MosOcaInterfaceSpecific*)pOcaInterface)->IsOcaDumpExecListInfoEnabled())
+    {
+        info = mos_bo_get_softpin_targets_info(cmdBuffer->OsResource.bo, &count);
+    }
+
+    pOcaInterface->UnlockPendingOcaBuffers(mosContext, info, count);
+
+    if(info)
+    {
+        free(info);
+    }
+}
+
 int32_t GpuContextSpecificNext::SubmitPipeCommands(
     MOS_COMMAND_BUFFER *cmdBuffer,
     MOS_LINUX_BO *cmdBo,
