@@ -24,34 +24,28 @@
 //! \brief       This module implements the MOS wrapper functions for Linux/Android
 //!
 
-#include "mos_utilities_specific.h"
-#include "mos_utilities.h"
-#include "mos_util_debug.h"
 #include <fcntl.h>     // open
 #include <stdlib.h>    // atoi
 #include <string.h>    // strlen, strcat, etc.
 #include <errno.h>     // strerror(errno)
 #include <time.h>      // get_clocktime
-#include <sys/stat.h>  // fstat
 #include <dlfcn.h>     // dlopen, dlsym, dlclose
-#include <sys/types.h>
 #include <unistd.h>
-#if _MEDIA_RESERVED
-#include "codechal_user_settings_mgr_ext.h"
-#include "vphal_user_settings_mgr_ext.h"
-#endif // _MEDIA_RESERVED
-#ifdef WDDM_LINUX
-#include "media_user_settings_mgr_specific.h"
-#endif
-#include "mos_user_setting.h"
-
-#include <sys/ipc.h>  // System V IPC
-#include <sys/types.h>
-#include <sys/sem.h>
 #include <signal.h>
 #include <unistd.h>  // fork
 #include <algorithm>
-#include <execinfo.h> // backtrace
+#include <sys/types.h>
+#include <sys/stat.h>  // fstat
+#include <sys/ipc.h>  // System V IPC
+#include <sys/types.h>
+#include <sys/sem.h>
+#include <sys/mman.h>
+#include "mos_compat.h" // libc variative definitions: backtrace
+#include "mos_user_setting.h"
+#include "mos_utilities_specific.h"
+#include "mos_utilities.h"
+#include "mos_util_debug.h"
+#include "inttypes.h"
 
 const char           *MosUtilitiesSpecificNext::m_szUserFeatureFile     = USER_FEATURE_FILE;
 MOS_PUF_KEYLIST      MosUtilitiesSpecificNext::m_ufKeyList              = nullptr;
@@ -71,26 +65,26 @@ double MosUtilities::MosGetTime()
 #define MOS_UFKEY_EXT     "UFKEY_EXTERNAL"
 #define MOS_UFKEY_INT     "UFKEY_INTERNAL"
 
+//!
+//! \brief trace setting definition
+//!
+#define TRACE_SETTING_PATH             "/dev/shm/GFX_MEDIA_TRACE"
+#define TRACE_SETTING_SIZE             sizeof(MtControlData)
+
 //!
 //! \brief Linux specific trace entry path and file description.
 //!
 const char *const MosUtilitiesSpecificNext::m_mosTracePath  = "/sys/kernel/debug/tracing/trace_marker_raw";
 int32_t           MosUtilitiesSpecificNext::m_mosTraceFd    = -1;
-MosMutex          MosUtilitiesSpecificNext::m_userSettingMutex;
+uint64_t          MosUtilitiesSpecificNext::m_filterEnv     = 0;
+uint32_t          MosUtilitiesSpecificNext::m_levelEnv      = 0;
 
-//!
-//! \brief Keyword for GFX tracing
-//!
-#define DATA_DUMP_KEYWORD               0x10000
-#define COMP_CP_KEYWORD                 0x20000
-#define COMP_VP_KEYWORD                 0x40000
-#define COMP_CODEC_KEYWORD              0x80000
-#define COMP_ALL_KEYWORD                0x01000
+MosMutex          MosUtilitiesSpecificNext::m_userSettingMutex;
 
 //!
 //! \brief trace event size definition
 //!
-#define TRACE_EVENT_MAX_SIZE           (1024)
+#define TRACE_EVENT_MAX_SIZE           (3072)
 #define TRACE_EVENT_HEADER_SIZE        (sizeof(uint32_t)*3)
 #define TRACE_EVENT_MAX_DATA_SIZE      (TRACE_EVENT_MAX_SIZE - TRACE_EVENT_HEADER_SIZE - sizeof(uint16_t)) // Trace info data size section is in uint16_t
 
@@ -113,11 +107,6 @@ MosMutex          MosUtilitiesSpecificNext::m_userSettingMutex;
 MosMutex MosUtilities::m_mutexLock;
 uint32_t MosUtilities::m_mosUtilInitCount = 0; // number count of mos utilities init
 
-#if _MEDIA_RESERVED
-MediaUserSettingsMgr *MosUtilities::m_codecUserFeatureExt = nullptr;
-MediaUserSettingsMgr *MosUtilities::m_vpUserFeatureExt    = nullptr;
-#endif
-
 MediaUserSettingsMgr *MosUtilities::m_mediaUserFeatureSpecific  = nullptr;
 
 MOS_STATUS MosUtilities::MosSecureStrcat(char  *strDestination, size_t numberOfElements, const char * const strSource)
@@ -1028,10 +1017,12 @@ MOS_STATUS MosUtilitiesSpecificNext::UserFeatureDumpDataToFile(const char *szFil
                         (char *)(pKeyTmp->pElem->pValueArray[j].ulValueBuf));
                     break;
                 case UF_DWORD:
-                case UF_QWORD:
-                    fprintf(File, "\t\t\t%d\n",
+                    fprintf(File, "\t\t\t%u\n",
                         *(uint32_t*)(pKeyTmp->pElem->pValueArray[j].ulValueBuf));
                     break;
+                case UF_QWORD:
+                    fprintf(File, "\t\t\t%" PRIu64"\n", *(uint64_t*)(pKeyTmp->pElem->pValueArray[j].ulValueBuf));
+                    break;
                 default:
                     fprintf(File, "\t\t\t%s\n",
                         (char *)(pKeyTmp->pElem->pValueArray[j].ulValueBuf));
@@ -1322,10 +1313,9 @@ MOS_STATUS MosUtilitiesSpecificNext::MosUserFeatureSetValueExFile(
     return eStatus;
 }
 
-MOS_STATUS MosUtilities::MosOsUtilitiesInit(MOS_CONTEXT_HANDLE mosCtx)
+MOS_STATUS MosUtilities::MosOsUtilitiesInit(MediaUserSettingSharedPtr userSettingPtr)
 {
     MOS_STATUS     eStatus = MOS_STATUS_SUCCESS;
-    MOS_UNUSED(mosCtx);
 
     // lock mutex to avoid multi init in multi-threading env
     m_mutexLock.Lock();
@@ -1352,23 +1342,19 @@ MOS_STATUS MosUtilities::MosOsUtilitiesInit(MOS_CONTEXT_HANDLE mosCtx)
     }
 #endif
 
+    //The user setting is device based, no need to guard with the reference count.
+    //It will be destroyed in media context termiation.
+    eStatus = MosUserSetting::InitMosUserSetting(userSettingPtr);
+
     if (m_mosUtilInitCount == 0)
     {
         //Init MOS User Feature Key from mos desc table
-        eStatus = MosUserSetting::InitMosUserSetting(nullptr);
-        eStatus = MosDeclareUserFeatureKeysForAllDescFields();
         MosUtilitiesSpecificNext::UserFeatureDumpFile(MosUtilitiesSpecificNext::m_szUserFeatureFile, &MosUtilitiesSpecificNext::m_ufKeyList);
-#if _MEDIA_RESERVED
-        m_codecUserFeatureExt = new CodechalUserSettingsMgr();
-        m_vpUserFeatureExt    = new VphalUserSettingsMgr();
-#endif
-#ifdef WDDM_LINUX
-        m_mediaUserFeatureSpecific = new MediaUserSettingsMgrSpecific();
-#endif
-        eStatus = MosGenerateUserFeatureKeyXML(mosCtx);
+        MosDeclareUserFeature();
+
 #if MOS_MESSAGES_ENABLED
         // Initialize MOS message params structure and HLT
-        MosUtilDebug::MosMessageInit(nullptr);
+        MosUtilDebug::MosMessageInit(userSettingPtr);
 #endif // MOS_MESSAGES_ENABLED
         m_mosMemAllocCounter     = 0;
         m_mosMemAllocFakeCounter = 0;
@@ -1381,7 +1367,7 @@ MOS_STATUS MosUtilities::MosOsUtilitiesInit(MOS_CONTEXT_HANDLE mosCtx)
     return eStatus;
 }
 
-MOS_STATUS MosUtilities::MosOsUtilitiesClose(MOS_CONTEXT_HANDLE mosCtx)
+MOS_STATUS MosUtilities::MosOsUtilitiesClose(MediaUserSettingSharedPtr userSettingPtr)
 {
     int32_t                             memoryCounter = 0;
     MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
@@ -1399,32 +1385,12 @@ MOS_STATUS MosUtilities::MosOsUtilitiesClose(MOS_CONTEXT_HANDLE mosCtx)
         MOS_OS_VERBOSEMESSAGE("MemNinja leak detection end");
 
         ReportUserSetting(
-            nullptr,
+            userSettingPtr,
             __MEDIA_USER_FEATURE_VALUE_MEMNINJA_COUNTER,
             memoryCounter,
             MediaUserSetting::Group::Device);
 
-        eStatus = MosDestroyUserFeatureKeysForAllDescFields();
-#if _MEDIA_RESERVED
-        if (m_codecUserFeatureExt)
-        {
-            delete m_codecUserFeatureExt;
-            m_codecUserFeatureExt = nullptr;
-        }
-        if (m_vpUserFeatureExt)
-        {
-            delete m_vpUserFeatureExt;
-            m_vpUserFeatureExt = nullptr;
-        }
-#endif // _MEDIA_RESERVED
-#ifdef WDDM_LINUX
-        if (m_mediaUserFeatureSpecific)
-        {
-            delete m_mediaUserFeatureSpecific;
-            m_mediaUserFeatureSpecific = nullptr;
-        }
-#endif
-        MosUserSetting::DestroyMediaUserSetting();
+        MosDestroyUserFeature();
 
 #if (_DEBUG || _RELEASE_INTERNAL)
         // MOS maintains a reference counter,
@@ -1540,8 +1506,12 @@ MOS_STATUS MosUtilities::MosInitializeReg(RegBufferMap &regBufferMap)
             while(!regStream.eof())
             {
                 std::string line = "";
-
                 std::getline(regStream, line);
+                auto endIndex = line.find("\r");
+                if(endIndex != std::string::npos)
+                {
+                    line = line.substr(0, endIndex);
+                }
                 if (std::string::npos != line.find(USER_SETTING_CONFIG_PATH))
                 {
                     id = USER_SETTING_CONFIG_PATH;
@@ -1592,6 +1562,16 @@ MOS_STATUS MosUtilities::MosUninitializeReg(RegBufferMap &regBufferMap)
     {
         return MOS_STATUS_SUCCESS;
     }
+
+    auto iter = regBufferMap.find(USER_SETTING_REPORT_PATH);
+    // No need to write the user setting files if no session [report].
+    // The session [config] is read only.
+    if(iter == regBufferMap.end() || iter->second.size() == 0)
+    {
+        MOS_OS_NORMALMESSAGE("no report session");
+        return MOS_STATUS_SUCCESS;
+    }
+
     std::ofstream regStream;
     try
     {
@@ -1675,42 +1655,41 @@ MOS_STATUS MosUtilities::MosCloseRegKey(
 }
 
 MOS_STATUS MosUtilities::MosReadEnvVariable(
-    UFKEY_NEXT keyHandle,
-    const std::string &valueName,
-    uint32_t *type,
-    std::string &data,
-    uint32_t *size)
+    const std::string           &envName,
+    MOS_USER_FEATURE_VALUE_TYPE defaultType,
+    MediaUserSetting::Value     &data)
 {
-    MOS_OS_CHK_NULL_RETURN(size);
-    MOS_UNUSED(type);
-
-    MOS_STATUS status = MOS_STATUS_SUCCESS;
-
-    std::string name = valueName;
-    std::replace(name.begin(), name.end(), ' ', '_');
-    char *retVal = getenv(name.c_str());
+    char *retVal = getenv(envName.c_str());
     if (retVal != nullptr)
     {
         std::string strData = retVal;
-        *size               = strData.length();
-        data                = strData;
-        return MOS_STATUS_SUCCESS;
+        auto status = StrToMediaUserSettingValue(strData, defaultType, data);
+        return status;
     }
 
     return MOS_STATUS_INVALID_PARAMETER;
 }
 
+bool MosUtilities::MosEnvVariableEqual(
+    const std::string            envName,
+    const std::string            targetVal)
+{
+    char *retVal = getenv(envName.c_str());
+    bool res = false;
+    if (retVal != nullptr)
+    {
+        res = strcmp(retVal, targetVal.c_str()) ? false : true;
+    }
+    return res;
+}
+
 MOS_STATUS MosUtilities::MosGetRegValue(
     UFKEY_NEXT keyHandle,
     const std::string &valueName,
-    uint32_t *type,
-    std::string &data,
-    uint32_t *size,
+    MOS_USER_FEATURE_VALUE_TYPE defaultType,
+    MediaUserSetting::Value &data,
     RegBufferMap &regBufferMap)
 {
-    MOS_OS_CHK_NULL_RETURN(size);
-    MOS_UNUSED(type);
-
     MOS_STATUS status = MOS_STATUS_SUCCESS;
 
     if (regBufferMap.end() == regBufferMap.find(keyHandle))
@@ -1726,8 +1705,7 @@ MOS_STATUS MosUtilities::MosGetRegValue(
         {
             return MOS_STATUS_USER_FEATURE_KEY_OPEN_FAILED;
         }
-
-        data = it->second;
+        status = MosUtilities::StrToMediaUserSettingValue(it->second, defaultType, data);
     }
     catch(const std::exception &e)
     {
@@ -1740,12 +1718,9 @@ MOS_STATUS MosUtilities::MosGetRegValue(
 MOS_STATUS MosUtilities::MosSetRegValue(
     UFKEY_NEXT keyHandle,
     const std::string &valueName,
-    uint32_t type,
-    const std::string &data,
+    const MediaUserSetting::Value &data,
     RegBufferMap &regBufferMap)
 {
-    MOS_UNUSED(type);
-
     if (regBufferMap.end() == regBufferMap.find(keyHandle))
     {
         return MOS_STATUS_INVALID_PARAMETER;
@@ -1756,7 +1731,7 @@ MOS_STATUS MosUtilities::MosSetRegValue(
     {
         auto &keys = regBufferMap[keyHandle];
 
-        keys[valueName] = data;
+        keys[valueName] = data.ConstString();
     }
     catch(const std::exception &e)
     {
@@ -1929,14 +1904,14 @@ MOS_STATUS MosUtilities::MosReadMediaSoloEnabledUserFeature(bool &mediasoloEnabl
     return eStatus;
 }
 
-MOS_STATUS MosUtilities::MosReadApoDdiEnabledUserFeature(uint32_t &userfeatureValue, char *path)
+MOS_STATUS MosUtilities::MosReadApoDdiEnabledUserFeature(uint32_t &userfeatureValue, char *path, MediaUserSettingSharedPtr userSettingPtr)
 {
     MOS_STATUS eStatus  = MOS_STATUS_SUCCESS;
     MOS_UNUSED(path);
 
     uint32_t enableApoDdi = 0;
     eStatus = ReadUserSetting(
-        nullptr,
+        userSettingPtr,
         enableApoDdi,
         "ApoDdiEnable",
         MediaUserSetting::Group::Device);
@@ -1950,7 +1925,7 @@ MOS_STATUS MosUtilities::MosReadApoDdiEnabledUserFeature(uint32_t &userfeatureVa
     return eStatus;
 }
 
-MOS_STATUS MosUtilities::MosReadApoMosEnabledUserFeature(uint32_t &userfeatureValue, char *path)
+MOS_STATUS MosUtilities::MosReadApoMosEnabledUserFeature(uint32_t &userfeatureValue, char *path, MediaUserSettingSharedPtr userSettingPtr)
 {
     MOS_STATUS eStatus  = MOS_STATUS_SUCCESS;
     MOS_USER_FEATURE_VALUE_DATA userFeatureData     = {};
@@ -1976,7 +1951,7 @@ MOS_STATUS MosUtilities::MosReadApoMosEnabledUserFeature(uint32_t &userfeatureVa
 
     uint32_t enableApoMos = 0;
     eStatus = ReadUserSetting(
-        nullptr,
+        userSettingPtr,
         enableApoMos,
         "ApoMosEnable",
         MediaUserSetting::Group::Device);
@@ -2399,12 +2374,40 @@ MOS_STATUS MosUtilities::MosGetLocalTime(
 void MosUtilities::MosTraceEventInit()
 {
     char *val = getenv("GFX_MEDIA_TRACE");
-    if (val == nullptr)
+    if (val)
     {
-        return;
+        MosUtilitiesSpecificNext::m_filterEnv = strtoll(val, nullptr, 0);
+        val = getenv("GFX_MEDIA_TRACE_LEVEL");
+        if (val)
+        {
+            MosUtilitiesSpecificNext::m_levelEnv = static_cast<uint32_t>(strtoll(val, nullptr, 0));
+        }
+        m_mosTraceEnable = true;
+        m_mosTraceFilter = &MosUtilitiesSpecificNext::m_filterEnv;
+        m_mosTraceLevel  = reinterpret_cast<uint8_t *>(&MosUtilitiesSpecificNext::m_levelEnv);
     }
-    char *tmp;
-    m_mosTraceFilter = strtoll(val, &tmp, 0);
+    else
+    {
+        int fd = open(TRACE_SETTING_PATH, O_RDONLY);
+        if (fd < 0)
+        {
+            return;
+        }
+        void *addr = mmap(NULL, TRACE_SETTING_SIZE, PROT_READ, MAP_SHARED, fd, 0);
+        close(fd); // close first, map addr still valid after close
+        if (addr == MAP_FAILED)
+        {
+            return;
+        }
+        m_mosTraceControlData = reinterpret_cast<const MtControlData *>(addr);
+
+        m_mosTraceEnable = &m_mosTraceControlData->enable;
+        m_mosTraceFilter = {
+                        m_mosTraceControlData->filter,
+                        sizeof(m_mosTraceControlData->filter) / sizeof(uint64_t)};
+        m_mosTraceLevel = &m_mosTraceControlData->level;
+    }
+
     // close first, if already opened.
     if (MosUtilitiesSpecificNext::m_mosTraceFd >= 0)
     {
@@ -2417,12 +2420,21 @@ void MosUtilities::MosTraceEventInit()
 
 void MosUtilities::MosTraceEventClose()
 {
+    m_mosTraceEnable.Reset();
+    m_mosTraceFilter.Reset();
+    m_mosTraceLevel.Reset();
+    if (m_mosTraceControlData)
+    {
+        munmap((void *)m_mosTraceControlData, TRACE_SETTING_SIZE);
+        m_mosTraceControlData = nullptr;
+    }
     if (MosUtilitiesSpecificNext::m_mosTraceFd >= 0)
     {
         close(MosUtilitiesSpecificNext::m_mosTraceFd);
         MosUtilitiesSpecificNext::m_mosTraceFd = -1;
     }
-    m_mosTraceFilter = 0;
+    MosUtilitiesSpecificNext::m_filterEnv = 0;
+    MosUtilitiesSpecificNext::m_levelEnv  = {};
     return;
 }
 
@@ -2439,19 +2451,24 @@ void MosUtilities::MosTraceEvent(
     const void       *pArg2,
     uint32_t         dwSize2)
 {
+    if (!m_mosTraceEnable)
+    {
+        return; // skip if trace not enabled from share memory
+    }
+
     if (MosUtilitiesSpecificNext::m_mosTraceFd >= 0 &&
         TRACE_EVENT_MAX_SIZE > dwSize1 + dwSize2 + TRACE_EVENT_HEADER_SIZE)
     {
         uint8_t traceBuf[256];
         uint8_t *pTraceBuf = traceBuf;
+
         // special handling for media runtime log, filter by component
         if (usId == EVENT_MEDIA_LOG && pArg1 != nullptr && dwSize1 >= 2*sizeof(int32_t))
         {
             int32_t comp = (*(int32_t*)pArg1) >> 24;
             int32_t level = *((int32_t*)pArg1 + 1);
-            uint64_t keyword = m_mosTraceFilter;
 
-            if ((m_mosTraceFilter & ((1ULL << TR_KEY_MOSMSG_ALL) | (1ULL << (comp + 16)))) == 0)
+            if (!m_mosTraceFilter(TR_KEY_MOSMSG_ALL) || !m_mosTraceFilter(MEDIA_EVENT_FILTER_KEYID(comp + 16)))
             {
                 // keyword not set for this component, skip it
                 return;
@@ -2475,12 +2492,12 @@ void MosUtilities::MosTraceEvent(
 
             if (pArg1 && dwSize1 > 0)
             {
-                memcpy(pTraceBuf+nLen, pArg1, dwSize1);
+                MOS_SecureMemcpy(pTraceBuf+nLen, dwSize1, pArg1, dwSize1);
                 nLen += dwSize1;
             }
             if (pArg2 && dwSize2 > 0)
             {
-                memcpy(pTraceBuf+nLen, pArg2, dwSize2);
+                MOS_SecureMemcpy(pTraceBuf+nLen, dwSize2, pArg2, dwSize2);
                 nLen += dwSize2;
             }
             size_t writeSize = write(MosUtilitiesSpecificNext::m_mosTraceFd, pTraceBuf, nLen);
@@ -2489,7 +2506,8 @@ void MosUtilities::MosTraceEvent(
                 MOS_FreeMemory(pTraceBuf);
             }
         }
-        if (m_mosTraceFilter & (1ULL << TR_KEY_CALL_STACK))
+#if Backtrace_FOUND
+        if (m_mosTraceFilter(TR_KEY_CALL_STACK))
         {
             // reserve space for header and stack size field.
             // max 32-2=30 layers call stack in 64bit driver.
@@ -2508,10 +2526,18 @@ void MosUtilities::MosTraceEvent(
                 size_t ret = write(MosUtilitiesSpecificNext::m_mosTraceFd, traceBuf, nLen);
             }
         }
+#endif
     }
     return;
 }
 
+bool MosUtilities::MosShouldTraceEventMsg(
+    uint8_t level,
+    uint8_t compID)
+{
+    return false;
+}
+
 void MosUtilities::MosTraceEventMsg(
     uint8_t          level,
     uint8_t          compID,
@@ -2641,6 +2667,16 @@ void MosUtilities::MosGfxInfo(
     // not implemented
 }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+void MosUtilities::MosMMPWriteFile(
+    const std::string &name,
+    const void        *data,
+    size_t             size)
+{
+    std::ofstream ofs(name);
+    ofs.write(static_cast<const char *>(data), size);
+}
+#endif  //(_DEBUG || _RELEASE_INTERNAL)
 void PerfUtility::startTick(std::string tag)
 {
     std::lock_guard<std::mutex> lock(perfMutex);
